<?php
/**
 * Initialize Theme functions for NOO Framework.
 * This file include the framework functions, it should remain intact between themes.
 * For theme specified functions, see file functions-<theme name>.php
 *
 * @package    NOO Framework
 * @version    1.0.0
 * @author     NooTheme Team
 * @copyright  Copyright (c) 2014, NooTheme
 * @license    http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link       https://www.nootheme.com
 */
// Enqueue style for admin
if (!function_exists('noo_enqueue_admin_assets')) :
    function noo_enqueue_admin_assets()
    {

        wp_register_style(
            'vendor-chosen-css',
            JM_FRAMEWORK_ADMIN_URI . '/assets/css/noo-chosen.css',
            null,
            null,
            'all'
        );
        wp_register_script(
            'vendor-chosen-js',
            JM_FRAMEWORK_ADMIN_URI . '/assets/js/chosen.jquery.min.js',
            array('jquery'),
            null,
            true
        );

        // wp_register_script(
        // 	'vendor-chosen-order-js',
        // 	JM_FRAMEWORK_ADMIN_URI . '/assets/js/chosen.order.jquery.min.js',
        // 	array( 'vendor-chosen-js' ),
        // 	null,
        // 	true
        // );

        wp_register_style(
            'vendor-datetimepicker',
            JM_ASSETS . '/vendor/datetimepicker/jquery.datetimepicker.css',
            '2.4.5'
        );
        wp_register_script(
            'vendor-datetimepicker',
            JM_ASSETS . '/vendor/datetimepicker/jquery.datetimepicker.js',
            array('jquery'),
            '2.4.5',
            true
        );

        wp_enqueue_style(
            'select2-css',
            JM_FRAMEWORK_ADMIN_URI . '/assets/js/select2/select2.min.css',
            null
        );
        wp_enqueue_script(
            'select2-js',
            JM_FRAMEWORK_ADMIN_URI . '/assets/js/select2/select2.min.js',
            null,
            null
        );

        wp_register_style(
            'noo-admin-css',
            JM_FRAMEWORK_ADMIN_URI . '/assets/css/noo-admin.css',
            array('vendor-chosen-css'),
            null,
            'all'
        );
        wp_enqueue_style('noo-admin-css');

        $datetimeL10n = array(
            'lang'       => substr(get_bloginfo('language'), 0, 2),
            'rtl'        => is_rtl(),
            'January'    => ucfirst(esc_html__('January', 'jmcore')),
            'February'   => ucfirst(esc_html__('February', 'jmcore')),
            'March'      => ucfirst(esc_html__('March', 'jmcore')),
            'April'      => ucfirst(esc_html__('April', 'jmcore')),
            'May'        => ucfirst(esc_html__('May', 'jmcore')),
            'June'       => ucfirst(esc_html__('June', 'jmcore')),
            'July'       => ucfirst(esc_html__('July', 'jmcore')),
            'August'     => ucfirst(esc_html__('August', 'jmcore')),
            'September'  => ucfirst(esc_html__('September', 'jmcore')),
            'October'    => ucfirst(esc_html__('October', 'jmcore')),
            'November'   => ucfirst(esc_html__('November', 'jmcore')),
            'December'   => ucfirst(esc_html__('December', 'jmcore')),
            'Sunday'     => ucfirst(esc_html__('Sunday', 'jmcore')),
            'Monday'     => ucfirst(esc_html__('Monday', 'jmcore')),
            'Tuesday'    => ucfirst(esc_html__('Tuesday', 'jmcore')),
            'Wednesday'  => ucfirst(esc_html__('Wednesday', 'jmcore')),
            'Thursday'   => ucfirst(esc_html__('Thursday', 'jmcore')),
            'Friday'     => ucfirst(esc_html__('Friday', 'jmcore')),
            'Saturday'   => ucfirst(esc_html__('Saturday', 'jmcore')),
        );
        wp_localize_script(
            'vendor-datetimepicker',
            'datetime',
            $datetimeL10n
        );

        // Main script
        wp_register_script(
            'noo-admin-js',
            JM_FRAMEWORK_ADMIN_URI . '/assets/js/noo-admin.js',
            array(
                'jquery',
                'jquery-ui-slider',
                'vendor-chosen-js',
            ),
            null,
            true
        );

        $noo_admin = array(
            'title_wpmedia'  => esc_html__('Select Image', 'jmcore'),
            'button_wpmedia' => esc_html__('Insert image', 'jmcore'),
            'ajax_url'       => admin_url('admin-ajax.php', 'relative'),
        );

        wp_localize_script(
            'noo-admin-js',
            'nooAdminJS',
            $noo_admin
        );
        wp_enqueue_script('noo-admin-js');

    }

    add_action('admin_enqueue_scripts', 'noo_enqueue_admin_assets');
endif;

// Deactivate libraries plugins
if (!function_exists('noo_deactivate_plugins')) :
    function noo_deactivate_plugins()
    {
        if (is_plugin_active('fitsica_libs/plugin.php')) {
            deactivate_plugins('fitsica_libs/plugin.php');
        }

        $indeed_plugin_path = defined(WP_PLUGIN_DIR) ? WP_PLUGIN_DIR . '/noo-import-indeed/noo-import-indeed.php' : ABSPATH . 'wp-content/plugins/noo-import-indeed/noo-import-indeed.php';
        if (file_exists($indeed_plugin_path)) {
            $plugin_data = get_plugin_data($indeed_plugin_path);
            if (version_compare($plugin_data['Version'], '1.1.0', '<')) {
                // deactivate_plugins( 'noo-import-indeed/noo-import-indeed.php' );
                add_action('admin_notices', 'noo_import_indeed_plugin_check_notice');
            }
        }
    }

    add_action('admin_init', 'noo_deactivate_plugins');
endif;

// Notice about updating Indeed plugins
if (!function_exists('noo_import_indeed_plugin_check_notice')) :
    function noo_import_indeed_plugin_check_notice()
    {
        $screen = get_current_screen();

        if ($screen->id != 'plugins') {
            return;
        }
        ?>
        <div class="update-nag">
            <p>
                <strong><?php echo nootheme_kses(__('An old version of Noo Indeed Integration plugin was detected, please <em>remove</em> it and reinstall the newer version included in this theme.', 'jmcore')); ?></strong>
            </p>
        </div>
        <?php
    }
endif;