<?php
/**
 * NOO Meta Boxes Package
 *
 * Setup NOO Meta Boxes for Page
 * This file add Meta Boxes to WP Page edit page.
 *
 * @package    NOO Framework
 * @subpackage NOO Meta Boxes
 * @version    1.0.0
 * @author     NooTheme Team
 * @copyright  Copyright (c) 2014, NooTheme
 * @license    http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link       https://www.nootheme.com
 */

if (!function_exists('noo_page_meta_boxes')):
    function noo_page_meta_boxes()
    {
        // Declare helper object
        $prefix = '_noo_wp_page';
        $helper = new NOO_Meta_Boxes_Helper($prefix, array(
            'page' => 'page'
        ));

        // Page Settings
        $meta_box = array(
            'id'          => "{$prefix}_meta_box_page",
            'title'       => esc_html__('Page Settings', 'jmcore'),
            'description' => esc_html__('Choose various setting for your Page.', 'jmcore'),
            'fields'      => array(
                // array(
                // 	'label' => esc_html__('Header Fullwidth', 'jmcore') ,
                // 	'id' => "{$prefix}_header_nav_fullwidth",
                // 	'type' => 'checkbox',
                // ),
                array(
                    'label'   => esc_html__('Header Fullwidth', 'jmcore'),
                    'id'      => "{$prefix}_header_nav_fullwidth",
                    'type'    => 'select',
                    'options' => array(
                        array(
                            'label' => esc_html__('Default - Customizer', 'jmcore'),
                            'value' => ''
                        ),
                        array(
                            'label' => esc_html__('Fullwidth', 'jmcore'),
                            'value' => 'fullwidth'
                        ),
                    ),
                ),
                array(
                    'label' => esc_html__('Header Float', 'jmcore'),
                    'id'    => "{$prefix}_header_nav_float",
                    'type'  => 'select',
                    'options' => array(
                        array(
                            'label' => esc_html__('Default - Customizer', 'jmcore'),
                            'value' => ''
                        ),
                        array(
                            'label' => esc_html__('Enable', 'jmcore'),
                            'value' => 'enable'
                        ),
                        array(
                            'label' => esc_html__('Disable', 'jmcore'),
                            'value' => 'disable'
                        ),
                    ),
                    'child-fields'  => array(
                        'enable'    => "{$prefix}_header_nav_float_color"
                    ),
                ),
                // array(
                // 	'label' => esc_html__('Header Float', 'jmcore') ,
                // 	'id' => "{$prefix}_header_nav_float",
                // 	'type' => 'checkbox',
                // 	'child-fields' => array(
                // 		'on'   => "{$prefix}_header_nav_float_color"
                // 	),
                // ),
                array(
                    'label' => esc_html__('Header Float Text Color', 'jmcore'),
                    'id'    => "{$prefix}_header_nav_float_color",
                    'type'  => 'color',
                ),
                array(
                    'type'  => 'divider'
                ),
                array(
                    'id'    => "{$prefix}_menu_logo",
                    'label' => esc_html__("Menu Logo", 'jmcore'),
                    'desc'  => esc_html__("Menu Logo", 'jmcore'),
                    'type'  => 'image',
                ),
                array(
                    'id'    => "{$prefix}_menu_logo_sticky",
                    'label' => esc_html__("Logo Sticky", 'jmcore'),
                    'desc'  => esc_html__("Logo Sticky", 'jmcore'),
                    'type'  => 'image',
                ),
                array(
                    'id'    => "{$prefix}_menu_mobile_logo",
                    'label' => esc_html__("Mobile Logo", 'jmcore'),
                    'desc'  => esc_html__("Mobile Logo", 'jmcore'),
                    'type'  => 'image',
                ),
                array(
                    'label' => esc_html__('Body Custom CSS Class', 'jmcore'),
                    'id'    => "_noo_body_css",
                    'type'  => 'text',
                ),
                array(
                    'label' => esc_html__('Hide Page Title', 'jmcore'),
                    'id'    => "{$prefix}_hide_page_title",
                    'type'  => 'checkbox',
                    'child-fields' => array(
                        'off' => "_heading_image"
                    ),
                ),
                array(
                    'id'    => '_heading_image',
                    'label' => esc_html__('Heading Background Image', 'jmcore'),
                    'desc'  => esc_html__('An unique heading image for this page', 'jmcore'),
                    'type'  => 'image',
                ),
                array(
                    'label' => esc_html__('Hide Footer', 'jmcore'),
                    'id'    => "_hide_footer",
                    'type'  => 'checkbox',
                    'child-fields'  => array(
                        'off' => "_footer_background",
                    ),
                ),
                array(
                    'id'    => '_footer_background',
                    'label' => esc_html__('Footer Background', 'jmcore'),
                    'type'  => 'image',
                ),
            )
        );

        $helper->add_meta_box($meta_box);

        // Page Sidebar
        $meta_box = array(
            'id'       => "{$prefix}_meta_box_sidebar",
            'title'    => esc_html__('Sidebar', 'jmcore'),
            'context'  => 'side',
            'priority' => 'default',
            'fields'   => array(
                array(
                    'label' => esc_html__('Page Sidebar', 'jmcore'),
                    'id'    => "{$prefix}_sidebar",
                    'type'  => 'sidebars',
                    'std'   => 'sidebar-main'
                ),
            )
        );

        $helper->add_meta_box($meta_box);
    }
endif;

add_action('add_meta_boxes', 'noo_page_meta_boxes');