<?php
/**
 * NOO Meta Boxes Package
 *
 * Setup NOO Meta Boxes for Post
 * This file add Meta Boxes to WP Post edit page.
 *
 * @package    NOO Framework
 * @subpackage NOO Meta Boxes
 * @version    1.0.0
 * @author     NooTheme Team
 * @copyright  Copyright (c) 2014, NooTheme
 * @license    http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link       https://www.nootheme.com
 */

if (!function_exists('noo_post_meta_boxes')):
	function noo_post_meta_boxes() {
		// Declare helper object
		$prefix = '_noo_wp_post';
		$helper = new NOO_Meta_Boxes_Helper($prefix, array(
			'page' => 'post'
		));

		// Post type: Gallery
		$meta_box = array(
			'id' => "{$prefix}_meta_box_gallery",
			'title' => esc_html__('Gallery Settings', 'jmcore'),
			'fields' => array(
				array(
					'id' => "{$prefix}_gallery",
					// 'label' => esc_html__( 'Your Gallery', 'jmcore' ),
					'type' => 'gallery',
				),
				array(
					'type' => 'divider',
				),
				array(
					'id' => "{$prefix}_gallery_preview",
					'label' => esc_html__('Preview Content', 'jmcore'),
					'type' => 'radio',
					'std' => 'featured',
					'options' => array(
						array(
							'label' => esc_html__('Featured Image', 'jmcore'),
							'value' => 'featured',
						),
						array(
							'label' => esc_html__('First Image on Gallery', 'jmcore'),
							'value' => 'first_image',
						),
						array(
							'label' => esc_html__('Image Slideshow', 'jmcore'),
							'value' => 'slideshow',
						),
					)
				)
			)
		);

		$helper->add_meta_box($meta_box);

		// Post type: Video
		$meta_box = array(
			'id' => "{$prefix}_meta_box_video",
			'title' => esc_html__('Video Settings', 'jmcore'),
			'fields' => array(
				array(
					'id' => "{$prefix}_video_embed",
					'label' => esc_html__('Embedded Video Code', 'jmcore'),
					'desc' => esc_html__('If you are using videos from online sharing sites (YouTube, Vimeo, etc.) paste the embedded code here. This field will override the above settings.', 'jmcore'),
					'type' => 'textarea',
					'std' => ''
				),
				array(
					'id' => "{$prefix}_video_ratio",
					'label' => esc_html__('Video Aspect Ratio', 'jmcore'),
					'desc' => esc_html__('Choose the aspect ratio for your video.', 'jmcore'),
					'type' => 'select',
					'std' => '16:9',
					'options' => array(
						array('value'=>'16:9','label'=>'16:9'),
						array('value'=>'5:3','label'=>'5:3'),
						array('value'=>'5:4','label'=>'5:4'),
						array('value'=>'4:3','label'=>'4:3'),
						array('value'=>'3:2','label'=>'3:2')
					)
				),
				array(
					'type' => 'divider',
				),
				array(
					'label' => esc_html__('Preview Content', 'jmcore'),
					'id' => "{$prefix}_video_preview",
					'type' => 'radio',
					'std' => 'both',
					'options' => array(
						array(
							'label' => esc_html__('Featured Image', 'jmcore'),
							'value' => 'featured',
						),
						array(
							'label' => esc_html__('Video', 'jmcore'),
							'value' => 'video',
						),
					)
				)
			)
		);
		
		$helper->add_meta_box($meta_box);

		// Post type: Audio
		$meta_box = array(
			'id' => "{$prefix}_meta_box_audio",
			'title' => esc_html__('Audio Settings', 'jmcore'),
			'fields' => array(
				array(
					'id' => "{$prefix}_audio_embed",
					'label' => esc_html__('Embedded Audio Code', 'jmcore'),
					'desc' => esc_html__('If you are using videos from online sharing sites (like Soundcloud) paste the embedded code here. This field will override above settings.', 'jmcore'),
					'type' => 'textarea',
					'std' => ''
				)
			)
		);

		$helper->add_meta_box($meta_box);
		// Post type: Quote
		$meta_box = array(
			'id' => "{$prefix}_meta_box_quote",
			'title' => esc_html__('Quote Settings', 'jmcore'),
			'fields' => array(
				array(
					'id' => "{$prefix}_quote",
					'label' => esc_html__('The Quote', 'jmcore'),
					'desc' => esc_html__('Input your quote.', 'jmcore'),
					'type' => 'textarea',
				),
				array(
					'id' => "{$prefix}_quote_citation",
					'label' => esc_html__('Citation', 'jmcore'),
					'desc' => esc_html__('Who originally said the quote?', 'jmcore'),
					'type' => 'text',
				)
			)
		);

		// $helper->add_meta_box($meta_box);
		// Post type: Link
		$meta_box = array(
			'id' => "{$prefix}_meta_box_link",
			'title' => esc_html__('Link Settings', 'jmcore'),
			'fields' => array(
				array(
					'id' => "{$prefix}_link",
					'label' => esc_html__('The Link', 'jmcore'),
					'type' => 'text',
					'std' => 'http://nootheme.com',
				)
			)
		);

		// $helper->add_meta_box($meta_box);
		// Post type: Quote
		$meta_box = array(
			'id' => "{$prefix}_meta_box_quote",
			'title' => esc_html__('Quote Settings', 'jmcore'),
			'fields' => array(
				array(
					'id' => "{$prefix}_quote",
					'label' => esc_html__('The Quote', 'jmcore'),
					'desc' => esc_html__('Input your quote.', 'jmcore'),
					'type' => 'textarea',
				),
				array(
					'id' => "{$prefix}_quote_citation",
					'label' => esc_html__('Citation', 'jmcore'),
					'desc' => esc_html__('Who originally said the quote?', 'jmcore'),
					'type' => 'text',
				)
			)
		);

		// $helper->add_meta_box($meta_box);
		// Post type: Link
		$meta_box = array(
			'id' => "{$prefix}_meta_box_link",
			'title' => esc_html__('Link Settings', 'jmcore'),
			'fields' => array(
				array(
					'id' => "{$prefix}_link",
					'label' => esc_html__('The Link', 'jmcore'),
					'type' => 'text',
					'std' => 'http://nootheme.com',
				)
			)
		);

		// $helper->add_meta_box($meta_box);

		// Page Settings: Single Post
		$meta_box = array(
			'id' => "{$prefix}_meta_box_single_page",
			'title' => esc_html__('Page Settings: Single Post', 'jmcore'),
			'description' => esc_html__('Choose various setting for your Single Post page.', 'jmcore'),
			'fields' => array(
				array(
					'label' => esc_html__('Body Custom CSS Class', 'jmcore'),
					'id' => "_noo_body_css",
					'type' => 'text',
				),
				array(
					'type' => 'divider'
				),
				array(
					'label' => esc_html__('Page Layout', 'jmcore'),
					'id' => "{$prefix}_global_setting",
					'type' => 'page_layout',
				),
				array(
					'label' => esc_html__('Override Global Settings?', 'jmcore'),
					'id' => "{$prefix}_override_layout",
					'type' => 'checkbox',
					'child-fields' => array(
						'on' => "{$prefix}_layout,{$prefix}_sidebar"
					),
				),
				array(
					'label' => esc_html__('Page Layout', 'jmcore'),
					'id' => "{$prefix}_layout",
					'type' => 'radio',
					'std' => 'sidebar',
					'options' => array(
						'fullwidth' => array(
							'label' => esc_html__('Full-Width', 'jmcore'),
							'value' => 'fullwidth',
						),
						'sidebar' => array(
							'label' => esc_html__('With Right Sidebar', 'jmcore'),
							'value' => 'sidebar',
						),
						'left_sidebar' => array(
							'label' => esc_html__('With Left Sidebar', 'jmcore'),
							'value' => 'left_sidebar',
						),
					),
				),
				array(
					'label' => esc_html__('Post Sidebar', 'jmcore'),
					'id' => "{$prefix}_sidebar",
					'type' => 'sidebars',
					'std' => 'sidebar-main'
				),
			)
		);

		$helper->add_meta_box( $meta_box );
	}
	
endif;

add_action('add_meta_boxes', 'noo_post_meta_boxes');
