<?php
/**
 * Register NOO testimonial.
 * This file register Item and Category for NOO testimonial.
 *
 * @package    NOO Framework
 * @subpackage NOO testimonial
 * @version    1.0.0
 * @author     NooTheme Team
 * @copyright  Copyright (c) 2014, NooTheme
 * @license    http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link       https://www.nootheme.com
 */

if ( ! function_exists( 'noo_init_testimonial' ) ) :
	function noo_init_testimonial() {

		// Text for NOO testimonial.
		$testimonial_labels = array(
			'name'               => esc_html__( 'Testimonial', 'jmcore' ),
			'singular_name'      => esc_html__( 'Testimonial', 'jmcore' ),
			'menu_name'          => esc_html__( 'Testimonial', 'jmcore' ),
			'add_new'            => esc_html__( 'Add New', 'jmcore' ),
			'add_new_item'       => esc_html__( 'Add New testimonial Item', 'jmcore' ),
			'edit_item'          => esc_html__( 'Edit testimonial Item', 'jmcore' ),
			'new_item'           => esc_html__( 'Add New testimonial Item', 'jmcore' ),
			'view_item'          => esc_html__( 'View testimonial', 'jmcore' ),
			'search_items'       => esc_html__( 'Search testimonial', 'jmcore' ),
			'not_found'          => esc_html__( 'No testimonial items found', 'jmcore' ),
			'not_found_in_trash' => esc_html__( 'No testimonial items found in trash', 'jmcore' ),
			'parent_item_colon'  => '',
		);

		$admin_icon = JM_FRAMEWORK_ADMIN_URI . '/assets/images/noo20x20.png';
		if ( floatval( get_bloginfo( 'version' ) ) >= 3.8 ) {
			$admin_icon = 'dashicons-testimonial';
		}

		$testimonial_page = noo_get_option( 'noo_testimonial_page', '' );
		$testimonial_slug = ! empty( $testimonial_page ) ? get_post( $testimonial_page )->post_name : 'testimonials';

		// Options
		$testimonial_args = array(
			'labels'          => $testimonial_labels,
			'public'          => false,
			'show_ui'         => true,
			'show_in_menu'    => true,
			'menu_position'   => 5,
			'menu_icon'       => $admin_icon,
			'capability_type' => 'post',
			'hierarchical'    => false,
			'supports'        => array(
				'title',
				'editor',
				'revisions',
			),
			'has_archive'     => true,
			'rewrite'         => array(
				'slug'       => $testimonial_slug,
				'with_front' => false,
			),
		);

		register_post_type( 'testimonial', $testimonial_args );

		// Register a taxonomy for Project Categories.
		$category_labels = array(
			'name'                       => esc_html__( 'Testimonial Categories', 'jmcore' ),
			'singular_name'              => esc_html__( 'Testimonial Category', 'jmcore' ),
			'menu_name'                  => esc_html__( 'Testimonial Categories', 'jmcore' ),
			'all_items'                  => esc_html__( 'All Testimonial Categories', 'jmcore' ),
			'edit_item'                  => esc_html__( 'Edit Testimonial Category', 'jmcore' ),
			'view_item'                  => esc_html__( 'View Testimonial Category', 'jmcore' ),
			'update_item'                => esc_html__( 'Update Testimonial Category', 'jmcore' ),
			'add_new_item'               => esc_html__( 'Add New Testimonial Category', 'jmcore' ),
			'new_item_name'              => esc_html__( 'New Testimonial Category Name', 'jmcore' ),
			'parent_item'                => esc_html__( 'Parent Testimonial Category', 'jmcore' ),
			'parent_item_colon'          => esc_html__( 'Parent Testimonial Category:', 'jmcore' ),
			'search_items'               => esc_html__( 'Search Testimonial Categories', 'jmcore' ),
			'popular_items'              => esc_html__( 'Popular Testimonial Categories', 'jmcore' ),
			'separate_items_with_commas' => esc_html__( 'Separate Testimonial Categories with commas', 'jmcore' ),
			'add_or_remove_items'        => esc_html__( 'Add or remove Testimonial Categories', 'jmcore' ),
			'choose_from_most_used'      => esc_html__( 'Choose from the most used Testimonial Categories', 'jmcore' ),
			'not_found'                  => esc_html__( 'No Testimonial Categories found', 'jmcore' ),
		);

		$category_args = array(
			'labels'            => $category_labels,
			'public'            => false,
			'show_ui'           => true,
			'show_in_nav_menus' => false,
			'show_tagcloud'     => true,
			'show_admin_column' => true,
			'hierarchical'      => true,
			'query_var'         => true,
			'rewrite'           => array(
				'slug'       => 'testimonial_category',
				'with_front' => false,
			),
		);

		register_taxonomy( 'testimonial_category', array(
			'testimonial',
		), $category_args );
	}
endif;

add_action( 'init', 'noo_init_testimonial' );
