<?php
/**
 * NOO Customizer Package.
 *
 * Register Options
 * This file register options used in NOO-Customizer
 *
 * @package    NOO Framework
 * @version    1.0.0
 * @author     NooTheme Team
 * @copyright  Copyright (c) 2014, NooTheme
 * @license    http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link       https://www.nootheme.com
 */
// =============================================================================


// 0. Remove Unused WP Customizer Sections
if (!function_exists('noo_customizer_remove_wp_native_sections')) :
    function noo_customizer_remove_wp_native_sections($wp_customize)
    {
        $wp_customize->remove_section('title_tagline');
        $wp_customize->remove_section('colors');
        $wp_customize->remove_section('nav');
    }

    add_action('customize_register', 'noo_customizer_remove_wp_native_sections');
endif;


//
// Register NOO Customizer Sections and Options
//

// 1. Site Enhancement options.
if (!function_exists('noo_customizer_register_options_general')) :
    function noo_customizer_register_options_general($wp_customize)
    {

        // declare helper object.
        $helper = new NOO_Customizer_Helper($wp_customize);

        // Section: Site Enhancement
        $helper->add_section(
            'noo_customizer_section_site_enhancement',
            esc_html__('Site Enhancement', 'jmcore'),
            esc_html__('Enable/Disable some features for your site.', 'jmcore')
        );

        // Control: Favicon
        $helper->add_control(
            'noo_custom_favicon',
            'noo_image',
            esc_html__('Custom Favicon', 'jmcore'),
            '',
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Back to Top
        $helper->add_control(
            'noo_back_to_top',
            'noo_switch',
            esc_html__('Back To Top Button', 'jmcore'),
            1,
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Back to Top
        $helper->add_control(
            'noo_css_loading',
            'noo_switch',
            esc_html__('Enable loading', 'jmcore'),
            1,
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Enable MailChimp Subscribe
        $helper->add_control(
            'noo_mailchimp',
            'noo_switch',
            esc_html__('Enable MailChimp Subscribe', 'jmcore'),
            1,
            array('json' => array('on_child_options' => 'noo_mailchimp_api_key')),
            array('transport' => 'postMessage')
        );

        // Control: MailChimp Settings
        $helper->add_control(
            'noo_mailchimp_api_key',
            'mailchimp',
            esc_html__('MailChimp Settings', 'jmcore'),
            '',
            array(),
            array('transport' => 'postMessage')
        );
    }

    add_action('customize_register', 'noo_customizer_register_options_general');
endif;

// 2. Design and Layout options.
if (!function_exists('noo_customizer_register_options_layout')) :
    function noo_customizer_register_options_layout($wp_customize)
    {

        // declare helper object.
        $helper = new NOO_Customizer_Helper($wp_customize);

        // Section: Layout
        $helper->add_section(
            'noo_customizer_section_layout',
            esc_html__('Design and Layout', 'jmcore'),
            esc_html__('Set Style and Layout for your site. Boxed Layout will come with additional setting options for background color and image.', 'jmcore')
        );

        // Control: Site Layout
        $helper->add_control(
            'noo_site_layout',
            'noo_radio',
            esc_html__('Site Layout', 'jmcore'),
            'fullwidth',
            array(
                'choices' => array('fullwidth' => esc_html__('Fullwidth', 'jmcore'), 'boxed' => esc_html__('Boxed', 'jmcore')),
                'json'    => array(
                    'child_options'  => array(
                        'boxed'      => 'noo_layout_site_width
                                        ,noo_layout_site_max_width
                                        ,noo_layout_bg_color
                                        ,noo_layout_bg_image_sub_section
                                        ,noo_layout_bg_image
                                        ,noo_layout_bg_repeat
                                        ,noo_layout_bg_align
                                        ,noo_layout_bg_attachment
                                        ,noo_layout_bg_cover'
                    )
                )
            ),
            array('transport' => 'postMessage')
        );

        $helper->add_control(
            'noo_enable_parallax',
            'noo_switch',
            esc_html__('Enable Parallax Background', 'jmcore'),
            0,
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Site Width (%)
        $helper->add_control(
            'noo_layout_site_width',
            'ui_slider',
            esc_html__('Site Width (%)', 'jmcore'),
            '90',
            array(
                'json' => array(
                    'data_min' => '60',
                    'data_max' => '100',
                )
            ),
            array('transport'  => 'postMessage')
        );

        // Control: Site Max Width (px)
        $helper->add_control(
            'noo_layout_site_max_width',
            'ui_slider',
            esc_html__('Site Max Width (px)', 'jmcore'),
            '1200',
            array(
                'json' => array(
                    'data_min'  => '980',
                    'data_max'  => '1600',
                    'data_step' => '10',
                )
            ),
            array('transport' => 'postMessage')
        );

        // Control: Background Color
        $helper->add_control(
            'noo_layout_bg_color',
            'color_control',
            esc_html__('Background Color', 'jmcore'),
            '#ffffff',
            array(),
            array('transport' => 'postMessage')
        );

        // Sub-section: Background Image
        $helper->add_sub_section(
            'noo_layout_bg_image_sub_section',
            esc_html__('Background Image', 'jmcore'),
            nootheme_kses(__('Upload your background image here, you have various settings for your image:<br/><strong>Repeat Image</strong>: enable repeating your image, you will need it when using patterned background.<br/><strong>Alignment</strong>: Set the position to align your background image.<br/><strong>Attachment</strong>: Make your image scroll with your site or fixed.<br/><strong>Auto resize</strong>: Enable it to ensure your background image always fit the windows.', 'jmcore'))
        );

        // Control: Background Image
        $helper->add_control(
            'noo_layout_bg_image',
            'noo_image',
            esc_html__('Background Image', 'jmcore'),
            null,
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Repeat Image
        $helper->add_control(
            'noo_layout_bg_repeat',
            'radio',
            esc_html__('Background Repeat', 'jmcore'),
            'no-repeat',
            array(
                'choices' => array(
                    'repeat'    => esc_html__('Repeat', 'jmcore'),
                    'no-repeat' => esc_html__('No Repeat', 'jmcore'),
                )
            ),
            array('transport'   => 'postMessage')
        );

        // Control: Align Image
        $helper->add_control(
            'noo_layout_bg_align',
            'select',
            esc_html__('BG Image Alignment', 'jmcore'),
            'left top',
            array(
                'choices' => array(
                    'left top'      => esc_html__('Left Top', 'jmcore'),
                    'left center'   => esc_html__('Left Center', 'jmcore'),
                    'left bottom'   => esc_html__('Left Bottom', 'jmcore'),
                    'center top'    => esc_html__('Center Top', 'jmcore'),
                    'center center' => esc_html__('Center Center', 'jmcore'),
                    'center bottom' => esc_html__('Center Bottom', 'jmcore'),
                    'right top'     => esc_html__('Right Top', 'jmcore'),
                    'right center'  => esc_html__('Right Center', 'jmcore'),
                    'right bottom'  => esc_html__('Right Bottom', 'jmcore'),
                )
            ),
            array('transport' => 'postMessage')
        );

        // Control: Enable Scrolling Image
        $helper->add_control(
            'noo_layout_bg_attachment',
            'radio',
            esc_html__('BG Image Attachment', 'jmcore'),
            'fixed',
            array(
                'choices' => array(
                    'fixed'   => esc_html__('Fixed Image', 'jmcore'),
                    'scroll'  => esc_html__('Scroll with Site', 'jmcore'),
                )
            ),
            array('transport' => 'postMessage')
        );

        // Control: Auto Resize
        $helper->add_control(
            'noo_layout_bg_cover',
            'noo_switch',
            esc_html__('Auto Resize', 'jmcore'),
            0,
            array(),
            array('transport' => 'postMessage')
        );

        // Sub-Section: Links Color
        $helper->add_sub_section(
            'noo_general_sub_section_links_color',
            esc_html__('Color', 'jmcore'),
            esc_html__('Here you can set the color for links and various elements on your site.', 'jmcore')
        );

        // Control: Site Links Color
        $helper->add_control(
            'noo_site_link_color',
            'color_control',
            esc_html__('Primary Color', 'jmcore'),
            noo_default_primary_color(),
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Site Links Color
        $helper->add_control(
            'noo_site_secondary_color',
            'color_control',
            esc_html__('Secondary Color', 'jmcore'),
            noo_default_secondary_color(),
            array(),
            array('transport' => 'postMessage')
        );
        // Control: Three color
        $helper->add_control(
            'noo_site_third_color',
            'color_control',
            esc_html__('Third Color', 'jmcore'),
            noo_default_third_color(),
            array(),
            array('transport' => 'postMessage')
        );
    }

    add_action('customize_register', 'noo_customizer_register_options_layout');
endif;

// 3. Typography options.
if (!function_exists('noo_customizer_register_options_typo')) :
    function noo_customizer_register_options_typo($wp_customize)
    {

        // declare helper object.
        $helper = new NOO_Customizer_Helper($wp_customize);

        // Section: Typography
        $helper->add_section(
            'noo_customizer_section_typo',
            esc_html__('Typography', 'jmcore'),
            nootheme_kses(__('Customize your Typography settings. Merito integrated all Google Fonts. See font preview at <a target="_blank" href="//fonts.google.com">Google Fonts</a>.', 'jmcore'))
        );

        // Control: Use Custom Fonts
        $helper->add_control(
            'noo_typo_use_custom_fonts',
            'noo_switch',
            esc_html__('Use Custom Fonts?', 'jmcore'),
            0,
            array('json' => array(
                'on_child_options' => 'noo_typo_headings_font,noo_typo_body_font'
            )
            ),
            array('transport'      => 'postMessage')
        );

        // Control: Use Custom Font Color
        $helper->add_control(
            'noo_typo_use_custom_fonts_color',
            'noo_switch',
            esc_html__('Custom Font Color?', 'jmcore'),
            0,
            array('json' => array(
                'on_child_options' => 'noo_typo_headings_font_color,noo_typo_body_font_color'
            )
            ),
            array('transport'      => 'postMessage')
        );

        // Sub-Section: Headings
        $helper->add_sub_section(
            'noo_typo_sub_section_headings',
            esc_html__('Headings', 'jmcore')
        );

        // Control: Headings font
        $helper->add_control(
            'noo_typo_headings_font',
            'google_fonts',
            esc_html__('Headings Font', 'jmcore'),
            noo_default_headings_font_family(),
            array(
                'weight'        => '600'
            ),
            array('transport'   => 'postMessage')
        );

        // Control: Headings Font Color
        $helper->add_control(
            'noo_typo_headings_font_color',
            'color_control',
            esc_html__('Font Color', 'jmcore'),
            noo_default_headings_color(),
            array(),
            array('transport'   => 'postMessage')
        );

        // Control: Headings Font Uppercase
        $helper->add_control(
            'noo_typo_headings_uppercase',
            'checkbox',
            esc_html__('Transform to Uppercase', 'jmcore'),
            0,
            array(),
            array('transport'   => 'postMessage')
        );

        // Sub-Section: Body
        $helper->add_sub_section(
            'noo_typo_sub_section_body',
            esc_html__('Body', 'jmcore')
        );

        // Control: Body font
        $helper->add_control(
            'noo_typo_body_font',
            'google_fonts',
            esc_html__('Body Font', 'jmcore'),
            noo_default_font_family(),
            array(),
            array('transport'  => 'postMessage')
        );

        // Control: Body Font Size
        $helper->add_control(
            'noo_typo_body_font_size',
            'font_size',
            esc_html__('Font Size (px)', 'jmcore'),
            noo_default_font_size(),
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Body Font Color
        $helper->add_control(
            'noo_typo_body_font_color',
            'color_control',
            esc_html__('Font Color', 'jmcore'),
            noo_default_text_color(),
            array(),
            array('transport' => 'postMessage')
        );
    }

    add_action('customize_register', 'noo_customizer_register_options_typo');
endif;

// 6. Header options.
if (!function_exists('noo_customizer_register_options_header')) :
    function noo_customizer_register_options_header($wp_customize)
    {

        // declare helper object.
        $helper = new NOO_Customizer_Helper($wp_customize);


        // Section: Header
        $helper->add_section(
            'noo_customizer_section_header',
            esc_html__('Header', 'jmcore'),
            esc_html__('Customize settings for your Header, including Navigation Bar (Logo and Navigation) and an optional Top Bar.', 'jmcore'),
            true
        );

        // Sub-section: General Options
        $helper->add_sub_section(
            'noo_header_sub_section_general',
            esc_html__('General Options', 'jmcore'),
            ''
        );

        // Sub-Section: Navigation Bar
        $helper->add_sub_section(
            'noo_header_sub_section_style',
            esc_html__('Header style', 'jmcore'),
            esc_html__('Options style for header', 'jmcore')
        );

        // Control: Header Style
        $helper->add_control(
            'noo_header_nav_fullwidth',
            'checkbox',
            esc_html__('Header Fullwidth', 'jmcore'),
            1,
            array(),
            array('transport' => 'postMessage')
        );
        $helper->add_control(
            'noo_header_nav_float',
            'checkbox',
            esc_html__('Header Float', 'jmcore'),
            1,
            array(
                'json' => array(
                    'on_child_options' => 'noo_header_nav_float_color'
                )
            ),
            array('transport' => 'postMessage')
        );
        $helper->add_control(
            'noo_header_nav_float_color',
            'color_control',
            esc_html__('Color', 'jmcore'),
            '#ffffff',
            array(),
            array('transport' => 'postMessage')
        );

        // Sub-Section: Navigation Bar
        $helper->add_sub_section(
            'noo_header_sub_section_nav',
            esc_html__('Navigation Bar', 'jmcore'),
            esc_html__('Adjust settings for Navigation Bar. You also can customize some settings for the Toggle Button on Mobile in this section.', 'jmcore')
        );

        // Control: NavBar Position
        $helper->add_control(
            'noo_header_nav_position',
            'noo_radio',
            esc_html__('NavBar Position', 'jmcore'),
            'static_top',
            array(
                'choices' => array(
                    'static_top' => esc_html__('Static Top', 'jmcore'),
                    'fixed_top'  => esc_html__('Fixed Top', 'jmcore'),
                )
            ),
            array('transport'    => 'postMessage')
        );

        // Control: Show Post Button
        $helper->add_control(
            'noo_header_nav_post_btn',
            'noo_switch',
            esc_html__('Show Post Job/Resume Button', 'jmcore'),
            0,
            array(
                'json' => array(
                    'on_child_options' => 'noo_header_nav_post_btn_type'
                )
            ),
            array('transport'=> 'postMessage')
        );

        // Control: Post Button
        $helper->add_control(
            'noo_header_nav_post_btn_type',
            'noo_radio',
            esc_html__('Use Button for', 'jmcore'),
            'post_job',
            array(
                'choices' => array(
                    'post_job'    => esc_html__('Post Job', 'jmcore'),
                    'post_resume' => esc_html__('Post Resume', 'jmcore'),
                    'custom_btn'  => esc_html__('Custom', 'jmcore')
                ),
                'json' => array(
                    'child_options'  => array(
                        'custom_btn' => 'noo_header_nav_custom_btn_link,noo_header_nav_custom_btn_text'
                    )
                ),
            ),
            array('transport' => 'postMessage')
        );
        $helper->add_control(
            'noo_header_nav_custom_btn_text',
            'text',
            esc_html__('Text', 'jmcore'),
            '',
            array(),
            array('transport' => 'postMessage')
        );
        $helper->add_control(
            'noo_header_nav_custom_btn_link',
            'text',
            esc_html__('Url', 'jmcore'),
            '',
            array(),
            array('transport' => 'postMessage')
        );
        // Control: Show User Menu
        $helper->add_control(
            'noo_header_nav_user_menu',
            'noo_switch',
            esc_html__('Show Button Login/Register', 'jmcore'),
            0,
            array(
                'json' => array(
                    'on_child_options' => 'noo_header_nav_use_form'
                ),
            ),
            array('transport' => 'postMessage')
        );
        // Control: choice button show at user_menu
        $helper->add_control(
            'noo_header_nav_use_form',
            'noo_radio',
            esc_html__('Display Form', 'jmcore'),
            'default',
            array(
                'choices' => array(
                    'login'    => esc_html__('Login Form', 'jmcore'),
                    'register' => esc_html__('Register Form', 'jmcore'),
                    'default'  => esc_html__('Show Both Login & Register Form', 'jmcore'),
                ),
            ),
            array('transport' => 'postMessage')
        );

        // Control: Divider 2
        $helper->add_control('noo_header_nav_divider_2', 'divider', '');

        // Control: Custom NavBar Font
        $helper->add_control(
            'noo_header_custom_nav_font',
            'noo_switch',
            esc_html__('Use Custom NavBar Font and Color?', 'jmcore'),
            0,
            array('json' => array(
                'on_child_options' => 'noo_header_nav_font,noo_header_nav_link_color,noo_header_nav_link_hover_color'
            )
            ),
            array('transport' => 'postMessage')
        );

        // Control: NavBar font
        $helper->add_control(
            'noo_header_nav_font',
            'google_fonts',
            esc_html__('NavBar Font', 'jmcore'),
            noo_default_headings_font_family(),
            array(),
            array('transport' => 'postMessage')
        );

        // Control: NavBar Font Size
        $helper->add_control(
            'noo_header_nav_font_size',
            'ui_slider',
            esc_html__('Font Size (px)', 'jmcore'),
            '18',
            array(
                'json' => array(
                    'data_min' => '9',
                    'data_max' => '30',
                )
            ),
            array('transport' => 'postMessage')
        );

        // Control: NavBar Link Color
        $helper->add_control(
            'noo_header_nav_link_color',
            'color_control',
            esc_html__('Link Color', 'jmcore'),
            '',
            array(),
            array('transport' => 'postMessage')
        );

        // Control: NavBar Link Hover Color
        $helper->add_control(
            'noo_header_nav_link_hover_color',
            'color_control',
            esc_html__('Link Hover Color', 'jmcore'),
            '',
            array(),
            array('transport' => 'postMessage')
        );

        // Control: NavBar Font Uppercase
        $helper->add_control(
            'noo_header_nav_uppercase',
            'checkbox',
            esc_html__('Transform to Uppercase', 'jmcore'),
            0,
            array(),
            array('transport' => 'postMessage')
        );
        // Sub-Section: Logo
        $helper->add_sub_section(
            'noo_header_sub_section_logo',
            esc_html__('Logo', 'jmcore'),
            esc_html__('All the settings for Logo go here. If you do not use Image for Logo, plain text will be used.', 'jmcore')
        );

        // Control: Use Image for Logo
        $helper->add_control(
            'noo_header_use_image_logo',
            'noo_switch',
            esc_html__('Use Image for Logo?', 'jmcore'),
            0,
            array(
                'json' => array(
                    'on_child_options'  =>  'noo_header_logo_image
                                            ,noo_header_logo_retina_image
                                            ,noo_header_logo_image_height',
                    'off_child_options' =>  'blogname
                                            ,noo_header_logo_font
                                            ,noo_header_logo_font_size
                                            ,noo_header_logo_font_color
                                            ,noo_header_logo_uppercase'
                )
            ),
            array('transport' => 'postMessage')
        );

        // Control: Blog Name
        $helper->add_control(
            'blogname',
            'text',
            esc_html__('Blog Name', 'jmcore'),
            get_bloginfo('name'),
            array(),
            array('transport' => 'postMessage', 'type' => 'option')
        );

        // Control: Logo font
        $helper->add_control(
            'noo_header_logo_font',
            'google_fonts',
            esc_html__('Logo Font', 'jmcore'),
            noo_default_logo_font_family(),
            array(
                'weight' => '700'
            ),
            array('transport' => 'postMessage')
        );

        // Control: Logo Font Size
        $helper->add_control(
            'noo_header_logo_font_size',
            'ui_slider',
            esc_html__('Font Size (px)', 'jmcore'),
            '30',
            array(
                'json' => array(
                    'data_min' => '15',
                    'data_max' => '80',
                )
            ),
            array('transport' => 'postMessage')
        );

        // Control: Logo Font Color
        $helper->add_control(
            'noo_header_logo_font_color',
            'color_control',
            esc_html__('Font Color', 'jmcore'),
            noo_default_logo_color(),
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Logo Font Uppercase
        $helper->add_control(
            'noo_header_logo_uppercase',
            'checkbox',
            esc_html__('Transform to Uppercase', 'jmcore'),
            0,
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Logo Image
        $helper->add_control(
            'noo_header_logo_image',
            'noo_image',
            esc_html__('Upload Your Logo', 'jmcore'),
            '',
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Logo Image
        $helper->add_control(
            'noo_header_sticky_logo_image',
            'noo_image',
            esc_html__('Sticky Logo', 'jmcore'),
            '',
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Logo Mobile Image
        $helper->add_control(
            'noo_header_logo_mobile_image',
            'noo_image',
            esc_html__('Mobile Logo', 'jmcore'),
            '',
            array(),
            array('transport' => 'postMessage')
        );
        // Control: Logo Image
        $helper->add_control(
            'noo_header_dashboard_logo',
            'noo_image',
            esc_html__('Dashboard Logo', 'jmcore'),
            '',
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Logo Image Height
        $helper->add_control(
            'noo_header_logo_image_height',
            'ui_slider',
            esc_html__('Image Height (px)', 'jmcore'),
            '90',
            array(
                'json' => array(
                    'data_min'  => '15',
                    'data_max'  => '120',
                    'data_step' => '5'
                )
            ),
            array('transport'   => 'postMessage')
        );

        // Sub-Section: NavBar Alignment
        $helper->add_sub_section(
            'noo_header_sub_section_alignment',
            esc_html__('NavBar Alignment', 'jmcore'),
            ''
        );

        // Control: NavBar Height (px)
        $helper->add_control(
            'noo_header_nav_height',
            'ui_slider',
            esc_html__('NavBar Height (px)', 'jmcore'),
            '100',
            array(
                'json' => array(
                    'data_min' => '20',
                    'data_max' => '150',
                )
            ),
            array('transport' => 'postMessage')
        );

        // Control: NavBar Link Spacing (px)
        $helper->add_control(
            'noo_header_nav_link_spacing',
            'ui_slider',
            esc_html__('NavBar Link Spacing (px)', 'jmcore'),
            '20',
            array(
                'json' => array(
                    'data_min' => '5',
                    'data_max' => '30',
                )
            ),
            array('transport' => 'postMessage')
        );

        // Control: Mobile Icon Size (px)
        $helper->add_control(
            'noo_header_nav_toggle_size',
            'ui_slider',
            esc_html__('Mobile Icon Size (px)', 'jmcore'),
            '25',
            array(
                'json' => array(
                    'data_min' => '15',
                    'data_max' => '100',
                )
            ),
            array('transport' => 'postMessage')
        );

        // Sub-Section: Top Bar
        $helper->add_sub_section(
            'noo_header_sub_section_top_bar',
            esc_html__('Top Bar', 'jmcore'),
            esc_html__('Top Bar lays on top of your site, above Navigation Bar. It is suitable for placing contact information and social media link. Enable to control its layout and content.', 'jmcore')
        );

        // Control: Header TopBar
        $helper->add_control(
            'noo_header_top_bar',
            'noo_switch',
            esc_html__('Enable Top Bar', 'jmcore'),
            0,
            array(
                'json' => array(
                    'on_child_options' => 'noo_top_bar_social,noo_top_bar_text,noo_header_top_bar_login_link'
                )
            ),
            array('transport' => 'postMessage')
        );

        //Control: Top bar Login link

        $helper->add_control(
            'noo_header_top_bar_login_link',
            'noo_switch',
            esc_html__('Enable Top Bar Login/Register Link', 'jmcore'),
            0,
            array(),
            array('transport' => 'postMessage')
        );


        // Control: Top bar layout
        $helper->add_control(
            'noo_top_bar_layout',
            'select',
            esc_html__('Top Bar Layout', 'jmcore'),
            'right_social',
            array(
                'choices' => array(
                    'right' => esc_html__('Socials on the Right', 'jmcore'),
                    'left'  => esc_html__('Social on the Left', 'jmcore'),
                )
            )
        );

        // Control: Show Top bar text
        $helper->add_control(
            'noo_top_bar_text',
            'text',
            esc_html__('Text', 'jmcore'),
            '<span class="text-primary">Hotline</span>',
            array(),
            array('transport' => 'postMessage')
        );
        // Control: Show Social List
        $helper->add_control(
            'noo_top_bar_social',
            'checkbox',
            esc_html__('Show Social List', 'jmcore'),
            1,
            array(
                'json' => array(
                    'on_child_options' => 'noo_header_top_facebook_url,noo_header_top_google_plus_url,noo_header_top_twitter_url,noo_header_top_linked_url'
                )
            ),
            array('transport' => 'postMessage')
        );

        $helper->add_control(
            'noo_header_top_facebook_url',
            'text',
            esc_html__('Facebook Url', 'jmcore'),
            '',
            array(),
            array('transport' => 'postMessage')
        );

        $helper->add_control(
            'noo_header_top_google_plus_url',
            'text',
            esc_html__('Google Plus Url', 'jmcore'),
            '',
            array(),
            array('transport' => 'postMessage')
        );

        $helper->add_control(
            'noo_header_top_twitter_url',
            'text',
            esc_html__('Twitter Url', 'jmcore'),
            '',
            array(),
            array('transport' => 'postMessage')
        );

        $helper->add_control(
            'noo_header_top_linked_url',
            'text',
            esc_html__('LinkedIn Url', 'jmcore'),
            '',
            array(),
            array('transport' => 'postMessage')
        );
        $helper->add_control(
            'noo_header_top_instagram_url',
            'text',
            esc_html__('Instagram Url', 'jmcore'),
            '',
            array(),
            array('transport' => 'postMessage')
        );
        $helper->add_control(
            'noo_header_top_pinterest_url',
            'text',
            esc_html__('Pinterest Url', 'jmcore'),
            '',
            array(),
            array('transport' => 'postMessage')
        );
        $helper->add_control(
            'noo_header_top_youtube_url',
            'text',
            esc_html__('Youtube Url', 'jmcore'),
            '',
            array(),
            array('transport' => 'postMessage')
        );
    }

    add_action('customize_register', 'noo_customizer_register_options_header');
endif;

// 7. Footer options.
if (!function_exists('noo_customizer_register_options_footer')) :
    function noo_customizer_register_options_footer($wp_customize)
    {

        // declare helper object.
        $helper = new NOO_Customizer_Helper($wp_customize);

        // Section: Footer
        $helper->add_section(
            'noo_customizer_section_footer',
            esc_html__('Footer', 'jmcore')
        );
        // Control: Footer Columns (Widgetized)
        $helper->add_control(
            'noo_footer_widgets',
            'select',
            esc_html__('Footer Columns (Widgetized)', 'jmcore'),
            '0',
            array(
                'choices' => array(
                    0 => esc_html__('None (No Footer Main Content)', 'jmcore'),
                    1 => esc_html__('One', 'jmcore'),
                    2 => esc_html__('Two', 'jmcore'),
                    3 => esc_html__('Three', 'jmcore'),
                    4 => esc_html__('Four', 'jmcore')
                )
            ),
            array('transport' => 'postMessage')
        );

        // Control: Bottom Bar Content
        $helper->add_control(
            'noo_bottom_bar_content',
            'textarea',
            esc_html__('Bottom Bar Content (HTML)', 'jmcore'),
            '&copy; 2019 Fitsica. Designed with <i class="fa linearicons-heart text-primary"></i> by NooTheme',
            array(),
            array('transport' => 'postMessage')
        );

        $helper->add_control(
            'noo_footer_heading_text_color',
            'color_control',
            esc_html__('Footer Heading Text Color', 'jmcore'),
            '#ffffff',
            array(),
            array('transport' => 'postMessage')
        );

        $helper->add_control(
            'noo_footer_text_color',
            'color_control',
            esc_html__('Footer Text Color', 'jmcore'),
            '#cccccc',
            array(),
            array('transport' => 'postMessage')
        );

        $helper->add_control(
            'noo_footer_bg_image',
            'noo_image',
            esc_html__('Footer Background Image', 'jmcore'),
            array(),
            array('transport' => 'postMessage')
        );

    }

    add_action('customize_register', 'noo_customizer_register_options_footer');
endif;

// 8. WP Sidebar options.
if (!function_exists('noo_customizer_register_options_sidebar')) :
    function noo_customizer_register_options_sidebar($wp_customize)
    {

        global $wp_version;
        if ($wp_version  >= 4.0) {
            // declare helper object.
            $helper       = new NOO_Customizer_Helper($wp_customize);

            // Change the sidebar panel priority
            $widget_panel = $wp_customize->get_panel('widgets');
            if (!empty($widget_panel)) {
                $widget_panel->priority = $helper->get_new_section_priority();
            }
        }
    }

    add_action('customize_register', 'noo_customizer_register_options_sidebar');
endif;

// 9. Blog options.
if (!function_exists('noo_customizer_register_options_blog')) :
    function noo_customizer_register_options_blog($wp_customize)
    {

        // declare helper object.
        $helper = new NOO_Customizer_Helper($wp_customize);

        // Section: Blog
        $helper->add_section(
            'noo_customizer_section_blog',
            esc_html__('Blog', 'jmcore'),
            esc_html__('In this section you have settings for your Blog page, Archive page and Single Post page.', 'jmcore'),
            true
        );

        // Sub-section: Blog Page (Index Page)
        $helper->add_sub_section(
            'noo_blog_sub_section_blog_page',
            esc_html__('Blog Page', 'jmcore'),
            esc_html__('Choose Layout settings for your Post List', 'jmcore')
        );

        // Control: Blog Layout
        $helper->add_control(
            'noo_blog_layout',
            'noo_radio',
            esc_html__('Blog Layout', 'jmcore'),
            'left_sidebar',
            array(
                'choices' => array(
                    'fullwidth'    => esc_html__('Full-Width', 'jmcore'),
                    'sidebar'      => esc_html__('With Right Sidebar', 'jmcore'),
                    'left_sidebar' => esc_html__('With Left Sidebar', 'jmcore')
                ),
                'json' => array(
                    'child_options' => array(
                        'fullwidth'    => '',
                        'sidebar'      => 'noo_blog_sidebar',
                        'left_sidebar' => 'noo_blog_sidebar'
                    )
                )
            ),
            array('transport' => 'postMessage')
        );

        // Blog style

        $helper->add_control(
            'noo_blog_style',
            'noo_radio',
            esc_html__('Blog Style', 'jmcore'),
            'listing_style',
            array(
                'choices' => array(
                    'listing_style' => esc_html__('Listing', 'jmcore'),
                    'grid_style'    => esc_html__('Grid', 'jmcore'),
                ),
            ),
            array('transport' => 'postMessage')
        );

        // Control: Blog Sidebar
        $helper->add_control(
            'noo_blog_sidebar',
            'widgets_select',
            esc_html__('Blog Sidebar', 'jmcore'),
            'sidebar-main',
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Heading Title
        $helper->add_control(
            'noo_blog_heading_title',
            'text',
            esc_html__('Blog Heading Title', 'jmcore'),
            esc_html__('Blog', 'jmcore'),
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Heading Image
        $helper->add_control(
            'noo_blog_heading_image',
            'noo_image',
            esc_html__('Blog Heading Background Image', 'jmcore'),
            '',
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Divider 1
        $helper->add_control('noo_blog_divider_1', 'divider', '');

        // Control: Show Post Meta
        $helper->add_control(
            'noo_blog_show_post_meta',
            'checkbox',
            esc_html__('Show Post Meta', 'jmcore'),
            1,
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Show Readmore link
        $helper->add_control(
            'noo_blog_show_readmore',
            'checkbox',
            esc_html__('Show Readmore link', 'jmcore'),
            1,
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Excerpt Length
        $helper->add_control(
            'noo_blog_excerpt_length',
            'text',
            esc_html__('Excerpt Length', 'jmcore'),
            '60',
            array(),
            array('transport' => 'postMessage')
        );

        // Sub-section: Single Post
        $helper->add_sub_section(
            'noo_blog_sub_section_post',
            esc_html__('Single Post', 'jmcore')
        );

        // Control: Post Layout
        $helper->add_control(
            'noo_blog_post_layout',
            'noo_same_as_radio',
            esc_html__('Post Layout', 'jmcore'),
            'same_as_blog',
            array(
                'choices' => array(
                    'same_as_blog' => esc_html__('Same as Blog Layout', 'jmcore'),
                    'fullwidth'    => esc_html__('Full-Width', 'jmcore'),
                    'sidebar'      => esc_html__('With Right Sidebar', 'jmcore'),
                    'left_sidebar' => esc_html__('With Left Sidebar', 'jmcore'),
                ),
                'json' => array(
                    'child_options' => array(
                        'fullwidth'    => '',
                        'sidebar'      => 'noo_blog_post_sidebar',
                        'left_sidebar' => 'noo_blog_post_sidebar',
                    )
                )
            ),
            array('transport' => 'postMessage')
        );

        // Control: Post Sidebar
        $helper->add_control(
            'noo_blog_post_sidebar',
            'widgets_select',
            esc_html__('Post Sidebar', 'jmcore'),
            'sidebar-main',
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Divider 1
        $helper->add_control('noo_blog_post_divider_1', 'divider', '');

        // Control: Show Post Meta
        $helper->add_control(
            'noo_blog_post_show_post_meta',
            'checkbox',
            esc_html__('Show Post Meta', 'jmcore'),
            1,
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Show Author Bio
        $helper->add_control(
            'noo_blog_post_author_bio',
            'checkbox',
            esc_html__('Show Author\'s Avatar', 'jmcore'),
            1,
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Divider 2
        $helper->add_control('noo_blog_post_divider_2', 'divider', '');

        // Control: Enable Social Sharing
        $helper->add_control(
            'noo_blog_social',
            'noo_switch',
            esc_html__('Enable Social Sharing', 'jmcore'),
            1,
            array(
                'json' => array('on_child_options' =>  'noo_blog_social_facebook,
		                                                noo_blog_social_twitter,
		                                                noo_blog_social_google,
		                                                noo_blog_social_pinterest,
		                                                noo_blog_social_linkedin'
                )
            ),
            array('transport' => 'postMessage')
        );

        // Control: Sharing Title
        $helper->add_control(
            'noo_blog_social_title',
            'text',
            esc_html__('Sharing Title', 'jmcore'),
            esc_html__('Share This Post', 'jmcore'),
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Facebook Share
        $helper->add_control(
            'noo_blog_social_facebook',
            'checkbox',
            esc_html__('Facebook Share', 'jmcore'),
            1,
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Twitter Share
        $helper->add_control(
            'noo_blog_social_twitter',
            'checkbox',
            esc_html__('Twitter Share', 'jmcore'),
            1,
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Google+ Share
        $helper->add_control(
            'noo_blog_social_google',
            'checkbox',
            esc_html__('Google+ Share', 'jmcore'),
            1,
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Pinterest Share
        $helper->add_control(
            'noo_blog_social_pinterest',
            'checkbox',
            esc_html__('Pinterest Share', 'jmcore'),
            0,
            array(),
            array('transport' => 'postMessage')
        );

        // Control: LinkedIn Share
        $helper->add_control(
            'noo_blog_social_linkedin',
            'checkbox',
            esc_html__('LinkedIn Share', 'jmcore'),
            0,
            array(),
            array('transport' => 'postMessage')
        );
    }

    add_action('customize_register', 'noo_customizer_register_options_blog');
endif;

// Job & Company options.
if (!function_exists('noo_customizer_register_options_job')) :
    function noo_customizer_register_options_job($wp_customize)
    {

        // declare helper object.
        $helper = new NOO_Customizer_Helper($wp_customize);

        // Section: Job List
        $helper->add_section(
            'noo_customizer_section_job',
            esc_html__('Job & Company', 'jmcore'),
            esc_html__('In this section you have settings for your Job List page, Archive page and Single Job page.', 'jmcore'),
            true
        );

        // Sub-section: Job List
        $helper->add_sub_section(
            'noo_job_sub_section_job_list',
            esc_html__('Job List', 'jmcore'),
            esc_html__('Choose Layout settings for your Job List', 'jmcore')
        );

        // Control: Job List Layout
        // Control: Resume List Layout
        $helper->add_control(
            'noo_jobs_layout',
            'noo_radio',
            esc_html__('Jobs Layout', 'jmcore'),
            'left_sidebar',
            array(
                'choices' => array(
                    'map_full_width' => esc_html__('With Map ', 'jmcore'),
                    'fullwidth'      => esc_html__('Full-Width', 'jmcore'),
                    'sidebar'        => esc_html__('with Right Sidebar', 'jmcore'),
                    'left_sidebar'   => esc_html__('with Left Sidebar', 'jmcore')
                ),
                'json' => array(
                    'child_options' => array(
                        'map_full_width' => 'noo_jobs_map_align,noo_jobs_map_sidebar_align,noo_jobs_sidebar',
                        'fullwidth'      => 'noo_jobs_show_search,noo_job_heading_image',
                        'sidebar'        => 'noo_jobs_sidebar,noo_jobs_show_search,noo_job_heading_image',
                        'left_sidebar'   => 'noo_jobs_sidebar,noo_jobs_show_search,noo_job_heading_image'
                    )
                )
            ),
            array('transport' => 'postMessage')
        );
        $helper->add_control(
            'noo_jobs_map_align',
            'noo_radio',
            esc_html__('Map Position', 'jmcore'),
            'right',
            array(
                'choices' => array(
                    'right'     => esc_html__('Map on Right', 'jmcore'),
                    'left'      => esc_html__('Map on Left', 'jmcore'),
                    'on_heading'=> esc_html__('Map on Heading','jmcore'),
                ),
            ),
            array('transport' => 'postMessage')
        );
        $helper->add_control(
            'noo_jobs_map_sidebar_align',
            'noo_radio',
            esc_html__('Sidebar Position on Map Layout', 'jmcore'),
            'pull-right',
            array(
                'choices' => array(
                    'pull-left'     => esc_html__('with Right sidebar', 'jmcore'),
                    'pull-right'    => esc_html__('width Left sidebar', 'jmcore'),
                ),
            ),
            array('transport' => 'postMessage')
        );
        // Control: Job Listing Display type
        $helper->add_control(
            'noo_jobs_display_type',
            'noo_radio',
            esc_html__('Jobs Style', 'jmcore'),
            'list',
            array(
                'choices' => array(
                    'grid' => esc_html__('Grid', 'jmcore'),
                    'list' => esc_html__('List', 'jmcore'),
                ),
                'json' => array(
                    'child_options' => array(
                        'list' => 'noo_jobs_list_style',
                    )
                )
            ),
            array('transport' => 'postMessage')
        );

        // Control: Job List Style
        $helper->add_control(
            'noo_jobs_list_style',
            'noo_radio',
            esc_html__('Jobs List Style', 'jmcore'),
            '',
            array(
                'choices' => array(
                    'list-1' => esc_html__('Jobs List Full', 'jmcore'),
                    'list-2' => esc_html__('Jobs List Minimal', 'jmcore'),
                )
            ),
            array('transport' => 'postMessage')
        );

        // Control: Job List Pagination Style
        $helper->add_control(
            'noo_jobs_list_pagination_style',
            'noo_radio',
            esc_html__('Job List Pagination Style', 'jmcore'),
            '',
            array(
                'choices' => array(
                    ''         => esc_html__('Page Numbers', 'jmcore'),
                    'loadmore' => esc_html__('Load More Button', 'jmcore'),
                )
            ),
            array('transport' => 'postMessage')
        );

        // Control: Job List Sidebar
        $helper->add_control(
            'noo_jobs_sidebar',
            'widgets_select',
            esc_html__('Jobs Sidebar', 'jmcore'),
            'sidebar-job',
            array(),
            array('transport' => 'postMessage')
        );
        // Control: Show search
        $helper->add_control(
            'noo_jobs_show_search',
            'noo_switch',
            esc_html__('Show Search Form', 'jmcore'),
            1,
            array(
                'json' => array('on_child_options' => 'noo_show_job_location_search,noo_show_job_category_search,noo_job_heading_text'),
            ),
            array('transport' => 'postMessage')
        );
        // show job location search
        $helper->add_control(
            'noo_show_job_location_search',
            'checkbox',
            esc_html__('Job Location Search Field', 'jmcore'),
            1,
            array(),
            array('transport' => 'postMessage')
        );
        // show job location search
        $helper->add_control(
            'noo_show_job_category_search',
            'checkbox',
            esc_html__('Job Category Search Field', 'jmcore'),
            1,
            array(),
            array('transport' => 'postMessage')
        );
        // Control: Show Button Count Job
        $helper->add_control(
            'noo_job_heading_total_job',
            'text',
            esc_html__('Total jobs', 'jmcore'),
            esc_html__('150k jobs', 'jmcore'),
            array(),
            array('transport' => 'postMessage')
        );
        // Control: Heading Title
        $helper->add_control(
            'noo_job_heading_text',
            'textarea',
            esc_html__('More Heading Text Info', 'jmcore'),
            '<label>Keywords:</label> <i>Html, Css, WordPress</i>',
            array(),
            array('transport' => 'postMessage')
        );
        // Background form search
        $helper->add_control(
            'noo_job_heading_form_background',
            'color_control',
            esc_html__('Background Search Form', 'jmcore'),
            esc_html__('#127a9c', 'jmcore'),
            array(),
            array('transport' => 'postMessage')
        );
        // Control: position form search
        $helper->add_control(
            'noo_job_form_search_position',
            'ui_slider',
            esc_html__('Position form search', 'jmcore'),
            '-170',
            array(
                'json' => array(
                    'data_min' => '-500',
                    'data_max' => '100',
                )
            ),
            array('transport' => 'postMessage')
        );
        // Control: Heading Image
        $helper->add_control(
            'noo_job_heading_image',
            'noo_image',
            esc_html__('Job Heading Background Image', 'jmcore'),
            '',
            array(),
            array('transport' => 'postMessage')
        );
        // Control: Google  Ads
        $helper->add_control(
            'noo_job_google_ads',
            'textarea',
            esc_html__('Insert Custom Content', 'jmcore'),
            array(),
            array('transport' => 'postMessage')
        );
        //
        $helper->add_control(
            'noo_job_google_ads_position',
            'select',
            esc_html__('Custom Content Position', 'jmcore'),
            'top',
            array(
                'choices' => array(
                    'top'    => esc_html__('Top Listing', 'jmcore'),
                    'bottom' => esc_html__('Bottom Listing', 'jmcore')
                )
            )
        );

        // Control: Enable Featured Jobs
        $helper->add_control(
            'noo_jobs_featured',
            'noo_switch',
            esc_html__('Show Featured Jobs', 'jmcore'),
            0,
            array(
                'json' => array('on_child_options' => 'noo_jobs_featured_num, noo_jobs_view_more')
            ),
            array('transport' => 'postMessage')
        );

        // Control: Featured Jobs Num
        $helper->add_control(
            'noo_jobs_featured_num',
            'ui_slider',
            esc_html__('Number of Featured Jobs', 'jmcore'),
            '4',
            array(
                'json' => array(
                    'data_min' => '2',
                    'data_max' => '15',
                )
            ),
            array('transport'  => 'postMessage')
        );

        // Control: Enable Order By Featured Jobs
        $helper->add_control(
            'noo_jobs_orderby_featured',
            'noo_switch',
            esc_html__('Order By Featured Jobs', 'jmcore'),
            0,
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Show/Hide Expired Job
        $helper->add_control(
            'noo_jobs_show_expired',
            'noo_switch',
            esc_html__('Show Expired Job', 'jmcore'),
            0,
            array(),
            array('transport' => 'postMessage')
        );
        $helper->add_control(
            'noo_captcha_send_to_friend',
            'noo_switch',
            esc_html__('Add the captcha to send to friend', 'jmcore'),
            0,
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Divider 1
        $helper->add_control('noo_jobs_divider_1', 'divider', '');

        // Control: Show quick view
        $helper->add_control(
            'noo_jobs_show_quick_view',
            'checkbox',
            esc_html__('Show Quick View Button', 'jmcore'),
            0,
            array(),
            array('transport' => 'postMessage')
        );
        // Control: Show Share
        $helper->add_control(
            'noo_jobs_show_share',
            'checkbox',
            esc_html__('Show Share Button', 'jmcore'),
            0,
            array(),
            array('transport' => 'postMessage')
        );
        // Control: Show Send to Friend
        $helper->add_control(
            'noo_jobs_show_send_to_friend',
            'checkbox',
            esc_html__('Show Send To Friend Button', 'jmcore'),
            0,
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Show Save
        $helper->add_control(
            'noo_jobs_show_bookmark',
            'checkbox',
            esc_html__('Show Bookmark Button', 'jmcore'),
            0,
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Show Company Logo
        $helper->add_control(
            'noo_jobs_show_company_logo',
            'checkbox',
            esc_html__('Show Company Logo', 'jmcore'),
            1,
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Show Company Name
        $helper->add_control(
            'noo_jobs_show_company_name',
            'checkbox',
            esc_html__('Show Company Name', 'jmcore'),
            1,
            array(),
            array('transport' => 'postMessage')
        );

        // custom field
        if (function_exists('jm_get_job_custom_fields')) {
            $custom_fields = jm_get_job_custom_fields();
        } else {
            $custom_fields = array();
        }
        $cf_choices        = array(
            'job_type'     => esc_html__('Job Type', 'jmcore'),
            'job_location' => esc_html__('Job Location', 'jmcore'),
            'job_date'     => esc_html__('Publish Date', 'jmcore'),
            'job_closing'  => esc_html__('Closing Date', 'jmcore'),
            'job_category' => esc_html__('Job Category', 'jmcore'),
        );
        foreach ($custom_fields as $field) {
            if ($field['name'] == 'cover_image') // reserve the _closing field
                continue;
            if (!isset($cf_choices[$field['name']]) && $field['name'] != 'job_tag') {
                $cf_choices[$field['name']] = $field['label'];
            }
        }
        $helper->add_control(
            'noo_jobs_list_fields',
            'checkbox_multiple',
            esc_html__('Show Fields on the listing: ', 'jmcore'),
            'job_type,job_location,job_date,job_closing',
            array(
                'choices' => $cf_choices
            ),
            array('transport' => 'postMessage')
        );

        // Sub-section: Single Job
        $helper->add_sub_section(
            'noo_job_sub_section_single_job',
            esc_html__('Single Job', 'jmcore')
        );

        // Control: Job Details Layout
        $helper->add_control(
            'noo_job_detail_layout',
            'noo_radio',
            esc_html__('Job Details Layout', 'jmcore'),
            'style-1',
            array(
                'choices' => array(
                    'style-1' => esc_html__('Style 1', 'jmcore'),
                    'style-2' => esc_html__('Style 2', 'jmcore'),
                    'style-3' => esc_html__('Style 3', 'jmcore'),
                    'style-4' => esc_html__('Style 4', 'jmcore'),
                    'style-5' => esc_html__('Style 5', 'jmcore'),
                    'style-6' => esc_html__('Style 6', 'jmcore'),
                    // 'style-7' => esc_html__('Style 7', 'jmcore'),
                    // 'style-8' => esc_html__('Style 8', 'jmcore'),
                ),
            ),
            array('transport' => 'postMessage')
        );


        $helper->add_control(
            'noo_company_info_in_jobs',
            'noo_switch',
            esc_html__('Show Company Information', 'jmcore'),
            1,
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Enable Schema.org/JobPosting
        $helper->add_control(
            'noo_job_schema',
            'noo_switch',
            esc_html__('Enable Schema JobPosting', 'jmcore'),
            1,
            array(),
            array('transport' => 'postMessage')
        );


        // Control: Enable Job Comment
        $helper->add_control(
            'noo_job_comment',
            'noo_switch',
            esc_html__('Enable Job Comment', 'jmcore'),
            0,
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Enable Related Jobs
        $helper->add_control(
            'noo_job_related',
            'noo_switch',
            esc_html__('Enable Related Jobs', 'jmcore'),
            1,
            array(
                'json' => array('on_child_options' => 'noo_job_related_num, noo_job_related_view_more')
            ),
            array('transport' => 'postMessage')
        );

        // Control: Number of Related Jobs
        $helper->add_control(
            'noo_job_related_num',
            'ui_slider',
            esc_html__('Number of Related Jobs', 'jmcore'),
            '4',
            array(
                'json' => array(
                    'data_min' => '2',
                    'data_max' => '10',
                )
            ),
            array('transport' => 'postMessage')
        );

        // Control: Enable Social Sharing
        $helper->add_control(
            'noo_job_social',
            'noo_switch',
            esc_html__('Enable Social Sharing', 'jmcore'),
            1,
            array(
                'json' => array('on_child_options' =>  'noo_job_social_facebook,
		                                                noo_job_social_twitter,
		                                                noo_job_social_google,
		                                                noo_job_social_pinterest,
		                                                noo_job_social_linkedin,
		                                                noo_job_social_email'
                )
            ),
            array('transport' => 'postMessage')
        );

        // Control: Facebook Share
        $helper->add_control(
            'noo_job_social_facebook',
            'checkbox',
            esc_html__('Facebook Share', 'jmcore'),
            1,
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Twitter Share
        $helper->add_control(
            'noo_job_social_twitter',
            'checkbox',
            esc_html__('Twitter Share', 'jmcore'),
            1,
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Google+ Share
        $helper->add_control(
            'noo_job_social_google',
            'checkbox',
            esc_html__('Google+ Share', 'jmcore'),
            1,
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Pinterest Share
        $helper->add_control(
            'noo_job_social_pinterest',
            'checkbox',
            esc_html__('Pinterest Share', 'jmcore'),
            0,
            array(),
            array('transport' => 'postMessage')
        );

        // Control: LinkedIn Share
        $helper->add_control(
            'noo_job_social_linkedin',
            'checkbox',
            esc_html__('LinkedIn Share', 'jmcore'),
            0,
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Email Share
        $helper->add_control(
            'noo_job_social_email',
            'checkbox',
            esc_html__('Email Share', 'jmcore'),
            0,
            array(),
            array('transport' => 'postMessage')
        );

        // custom field job detail
        if (function_exists('jm_get_job_custom_fields')) {
            $job_custom_fields = jm_get_job_custom_fields();
        } else {
            $job_custom_fields = array();
        }
        $featured_choices      = array();
        foreach ($job_custom_fields as $value) {
            if ($value['name'] == 'job_closing') // reserve the _closing field
                continue;
            if ($value['name'] == 'job_type') // reserve the _closing field
                continue;
            if ($value['name'] == 'job_category') // reserve the _closing field
                continue;
            if ($value['name'] == 'job_location') // reserve the _closing field
                continue;
            if ($value['name'] == 'cover_image') // reserve the _closing field
                continue;
            if ($value['name'] == 'full_address') // reserve the _closing field
                continue;
            if ($value['type'] == 'embed_video') // reserve the _closing field
                continue;
            if ($value['type'] == 'image_gallery') // reserve the _closing field
                continue;
            if ($value['type'] == 'single_image') // reserve the _closing field
                continue;
            if (!isset($featured_choices[$value['name']]) && $value['name'] != 'job_tag') {

                $featured_choices[$value['name']] = $value['label'];
            }
        }
        $helper->add_control(
            'noo_jobs_detail_fields',
            'checkbox_multiple',
            esc_html__('Show Featured Fields: ', 'jmcore'),
            'noo_jobs_detail_fields',
            array(
                'choices' => $featured_choices
            ),
            array('transport' => 'postMessage')
        );

        // Sub-section: Companies List
        $helper->add_sub_section(
            'noo_job_sub_section_companies_list',
            esc_html__('Companies List', 'jmcore'),
            esc_html__('Choose Layout settings for your Companies List', 'jmcore')
        );

        // Control: Companies List Layout
        $helper->add_control(
            'noo_companies_layout',
            'noo_radio',
            esc_html__('Companies Layout', 'jmcore'),
            'left_sidebar',
            array(
                'choices' => array(
                    'fullwidth'    => esc_html__('Full-Width', 'jmcore'),
                    'sidebar'      => esc_html__('with Right Sidebar', 'jmcore'),
                    'left_sidebar' => esc_html__('with Left Sidebar', 'jmcore')
                ),
                'json'    => array(
                    'child_options'    => array(
                        'fullwidth'    => '',
                        'sidebar'      => 'noo_companies_sidebar',
                        'left_sidebar' => 'noo_companies_sidebar'
                    )
                )
            ),
            array('transport' => 'postMessage')
        );

        // Control: Companies List Style
        $helper->add_control(
            'noo_companies_style',
            'noo_radio',
            esc_html__('Companies Style', 'jmcore'),
            'style1',
            array(
                'choices' => array(
                    'style1' => esc_html__('Alphabet', 'jmcore'),
                    'style2' => esc_html__('Grid', 'jmcore'),
                ),
                'json' => array(
                    'child_options' => array(
                        'style2' => 'noo_companies_style_count,noo_companies_grid'
                    )
                )
            ),
            array('transport' => 'postMessage')
        );

        // Control: Companies Grid Style
        $helper->add_control(
            'noo_companies_grid',
            'noo_radio',
            esc_html__('Grid Style', 'jmcore'),
            'style-1',
            array(
                'choices' => array(
                    'style-1' => esc_html__('Classic Style', 'jmcore'),
                    'style-2' => esc_html__('Cover Image Style', 'jmcore'),
                ),
            ),
            array('transport' => 'postMessage')
        );

        // Control: Companies List Style 2 - Count
        $helper->add_control(
            'noo_companies_style_count',
            'text',
            esc_html__('Companies Per Page', 'jmcore'),
            esc_html__('12', 'jmcore'),
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Companies List Sidebar
        $helper->add_control(
            'noo_companies_sidebar',
            'widgets_select',
            esc_html__('Companies Sidebar', 'jmcore'),
            'sidebar-companies',
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Heading Title
        $helper->add_control(
            'noo_companies_heading_title',
            'text',
            esc_html__('Archive Heading Title', 'jmcore'),
            esc_html__('Companies', 'jmcore'),
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Heading Image
        $helper->add_control(
            'noo_companies_heading_image',
            'noo_image',
            esc_html__('Archive Heading Background Image', 'jmcore'),
            '',
            array(),
            array('transport' => 'postMessage')
        );

        // Sub-section: Job List
        $helper->add_sub_section(
            'noo_job_sub_section_company_single',
            esc_html__('Single Company', 'jmcore'),
            esc_html__('Choose Layout settings for your Company', 'jmcore')
        );
        // Control: Single Company Layout
        $helper->add_control(
            'noo_single_company_layout',
            'noo_radio',
            esc_html__('Single Company Layout', 'jmcore'),
            '',
            array(
                'choices' => array(
                    ''    => esc_html__('Sidebar Information', 'jmcore'),
                    'two' => esc_html__('Full Information', 'jmcore'),
                ),
            ),
            array('transport' => 'postMessage')
        );

        // Control: Show Contact Company Form
        $helper->add_control(
            'noo_single_company_contact_form',
            'noo_switch',
            esc_html__('Show Contact Company Form', 'jmcore'),
            0,
            array(
                'json' => array('on_child_options' => 'noo_single_captcha_contact_form')
            ),
            array('transport' => 'postMessage')
        );

        // Control: Show CaptCha Contact Form
        $helper->add_control(
            'noo_single_captcha_contact_form',
            'noo_switch',
            esc_html__('Use CaptCha', 'jmcore'),
            0,
            array(
                'json' => array('on_child_options' => '')
            ),
            array('transport' => 'postMessage')
        );

    }

    add_action('customize_register', 'noo_customizer_register_options_job');
endif;

// Resume options.
if (!function_exists('noo_customizer_register_options_resume')) :
    function noo_customizer_register_options_resume($wp_customize)
    {

        // declare helper object.
        $helper = new NOO_Customizer_Helper($wp_customize);

        // Section: Resume List
        $helper->add_section(
            'noo_customizer_section_resume',
            esc_html__('Resume', 'jmcore'),
            esc_html__('In this section you have settings for your Resume  page.', 'jmcore'),
            true
        );

        // // Sub-section: Resume List
        $helper->add_sub_section(
            'noo_resume_sub_section_resume_list',
            esc_html__('Resume List', 'jmcore'),
            esc_html__('Choose Layout settings for your Resume List', 'jmcore')
        );
        // Control: Resume Layout
        $helper->add_control(
            'noo_resumes_layout',
            'noo_radio',
            esc_html__('Resumes Layout', 'jmcore'),
            'left_sidebar',
            array(
                'choices' => array(
                    'fullwidth_map' => esc_html__('with Map', 'jmcore'),
                    'fullwidth'     => esc_html__('Full-Width', 'jmcore'),
                    'sidebar'       => esc_html__('with Right Sidebar', 'jmcore'),
                    'left_sidebar'  => esc_html__('with Left Sidebar', 'jmcore')
                ),
                'json'    => array(
                    'child_options' => array(
                        'fullwidth_map' => 'noo_resume_map_align,noo_resume_map_sidebar_align,noo_resumes_sidebar',
                        'fullwidth'     => 'noo_resume_heading_image,resume_search_form',
                        'sidebar'       => 'noo_resumes_sidebar,noo_resume_heading_image,resume_search_form',
                        'left_sidebar'  => 'noo_resumes_sidebar,noo_resume_heading_image,resume_search_form'
                    )
                )
            ),
            array('transport' => 'postMessage')
        );
        $helper->add_control(
            'noo_resume_map_align',
            'noo_radio',
            esc_html__('Map Position', 'jmcore'),
            'right',
            array(
                'choices' => array(
                    'right'      => esc_html__('Map on Right', 'jmcore'),
                    'left'       => esc_html__('Map on Left', 'jmcore'),
                    'on_heading' => esc_html__('Map on Heading','jmcore')
                ),
            ),
            array('transport' => 'postMessage')
        );
        $helper->add_control(
            'noo_resume_map_sidebar_align',
            'noo_radio',
            esc_html__('Sidebar Position on Map Layout', 'jmcore'),
            'pull-right',
            array(
                'choices' => array(
                    'pull-left'=> esc_html__('with Right sidebar', 'jmcore'),
                    'pull-right' => esc_html__('with Left sidebar', 'jmcore'),
                ),
            ),
            array('transport' => 'postMessage')
        );

        // Control: Heading Image
        $helper->add_control(
            'noo_resume_heading_image',
            'noo_image',
            esc_html__('Archive Heading Background Image', 'jmcore'),
            '',
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Resume Listing Display type
        $helper->add_control(
            'noo_resume_display_type',
            'noo_radio',
            esc_html__('Resumes Type', 'jmcore'),
            'list',
            array(
                'choices' => array(
                    'grid' => esc_html__('Grid', 'jmcore'),
                    'list' => esc_html__('List', 'jmcore'),
                )
            ),
            array('transport' => 'postMessage')
        );
        // Control: Resumes List Pagination Style
        $helper->add_control(
            'noo_resumes_list_pagination_style',
            'noo_radio',
            esc_html__('Resume List Pagination Style', 'jmcore'),
            '',
            array(
                'choices' => array(
                    ''         => esc_html__('Page Numbers', 'jmcore'),
                    'loadmore' => esc_html__('Load More Button', 'jmcore'),
                )
            ),
            array('transport' => 'postMessage')
        );
        // Contron : Show Resume search form
        $helper->add_control(
            'resume_search_form',
            'noo_switch',
            esc_html__('Show Search Form on the heading', 'jmcore'),
            0,
            array(
                'json' => array('on_child_options' => 'noo_show_resume_location_search,noo_show_resume_category_search,noo_resume_heading_text'),
            ),
            array('transport' => 'postMessage')
        );
        // show resume location search
        $helper->add_control(
            'noo_show_resume_location_search',
            'checkbox',
            esc_html__('Resume Location Search Field', 'jmcore'),
            1,
            array(),
            array('transport' => 'postMessage')
        );
        // show resume location search
        $helper->add_control(
            'noo_show_resume_category_search',
            'checkbox',
            esc_html__('Resume Category Search Field', 'jmcore'),
            1,
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Show Button Count resume
        $helper->add_control(
            'noo_resume_heading_total_resume',
            'text',
            esc_html__('Total Resumes', 'jmcore'),
            esc_html__('150k Resumes', 'jmcore'),
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Heading Title
        $helper->add_control(
            'noo_resume_heading_text',
            'textarea',
            esc_html__('More Heading Text Info', 'jmcore'),
            '<label>Keywords:</label> <i>Html, Css, WordPress</i>',
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Background form search
         $helper->add_control(
            'noo_resume_heading_form_background',
            'color_control',
            esc_html__('Background Search Form', 'jmcore'),
            esc_html__('#127a9c', 'jmcore'),
            array(),
            array('transport' => 'postMessage')
        );

         // Control: position form search
        $helper->add_control(
            'noo_resume_form_search_position',
            'ui_slider',
            esc_html__('Position form search', 'jmcore'),
            '-170',
            array(
                'json' => array(
                    'data_min' => '-500',
                    'data_max' => '100',
                )
            ),
            array('transport' => 'postMessage')
        );


        // Resume custom field

        $resume_cf = (function_exists('jm_get_resume_custom_fields')) ? jm_get_resume_custom_fields() : array();
        $resume_cf_choices = array();
        foreach ($resume_cf as $field) {

            if ($field['name'] == 'positions') // reserve the _closing field
                continue;
            if ($field['name'] == 'portfolio') // reserve the _closing field
                continue;
            if ($field['name'] == 'cover_image') // reserve the _closing field
                continue;

            $resume_cf_choices[$field['name']] = $field['label'];

        }
        $helper->add_control(
            'noo_resume_list_fields',
            'select',
            esc_html__('Show Fields on the listing: ', 'jmcore'),
            'title,job_location,job_category',
            array(
                'choices' => $resume_cf_choices
            ),
            array('transport' => 'postMessage')
        );
        $helper->add_control(
            'noo_resume_google_ads',
            'textarea',
            esc_html__('Insert Custom Content', 'jmcore'),
            array(),
            array('transport' => 'postMessage')
        );
        //
        $helper->add_control(
            'noo_resume_google_ads_position',
            'select',
            esc_html__('Custom Content Position', 'jmcore'),
            'top',
            array(
                'choices' => array(
                    'top'    => esc_html__('Top Listing', 'jmcore'),
                    'bottom' => esc_html__('Bottom Listing', 'jmcore')
                )
            )
        );

        // add sub section Resume Single
        $helper->add_sub_section(
            'noo_job_sub_section_resume_single',
            esc_html__('Single Resume', 'jmcore'),
            esc_html__('Choose Layout settings for your Resume', 'jmcore')
        );
        // Control: Resume Details Layout
        $helper->add_control(
            'noo_resumes_detail_layout',
            'noo_radio',
            esc_html__('Resume Details Layout', 'jmcore'),
            'style-1',
            array(
                'choices' => array(
                    'style-1' => esc_html__('Style 1', 'jmcore'),
                    'style-2' => esc_html__('Style 2', 'jmcore'),
                    'style-3' => esc_html__('Style 3', 'jmcore'),
                    'style-4' => esc_html__('Style 4', 'jmcore'),
                    'style-5' => esc_html__('Style 5', 'jmcore'),
                ),
            ),
            array('transport' => 'postMessage')
        );

        // Control: Enable Social Sharing
        $helper->add_control(
            'noo_resume_social',
            'noo_switch',
            esc_html__('Enable Social Sharing ', 'jmcore'),
            1,
            array('transport' => 'postMessage')
        );

        // Custom field resume detail
        if (function_exists('jm_get_resume_custom_fields')) {
            $resume_custom_fields = jm_get_resume_custom_fields();
        } else {
            $resume_custom_fields = array();
        }
        $featured_choices         = array();
        foreach ($resume_custom_fields as $value) {
            if ($value['name'] == 'cover_image') // reserve the _closing field
                continue;
            if ($value['name'] == 'portfolio') // reserve the _closing field
                continue;
            if ($value['type'] == 'embed_video') // reserve the _closing field
                continue;
            if ($value['type'] == 'image_gallery') // reserve the _closing field
                continue;
            if ($value['type'] == 'single_image') // reserve the _closing field
                continue;
            if (!isset($featured_choices[$value['name']]) && $value['name'] != 'job_tag') {

                $featured_choices[$value['name']] = $value['label'];
            }
        }
        $helper->add_control(
            'noo_resumes_detail_fields',
            'checkbox_multiple',
            esc_html__('Show Resumes Fields: ', 'jmcore'),
            'noo_resumes_detail_fields',
            array(
                'choices' => $featured_choices
            ),
            array('transport' => 'postMessage')
        );

    }

    add_action('customize_register', 'noo_customizer_register_options_resume');
endif;

// 10. Portfolio options.

// 11. Page options.

//12. WooCommerce options.
if (class_exists('WooCommerce')) :
    if (!function_exists('noo_customizer_register_options_woocommerce')) :
        function noo_customizer_register_options_woocommerce($wp_customize)
        {

            // declare helper object.
            $helper = new NOO_Customizer_Helper($wp_customize);

            // Section: Revolution Slider
            $helper->add_section(
                'noo_customizer_section_shop',
                esc_html__('WooCommerce', 'jmcore'),
                '',
                true
            );

            // Sub-section: Shop Page
            $helper->add_sub_section(
                'noo_woocommerce_sub_section_shop_page',
                esc_html__('Shop Page', 'jmcore'),
                esc_html__('Choose Layout for your Shop Page.', 'jmcore')
            );

            // Control: Shop Layout
            $helper->add_control(
                'noo_shop_layout',
                'noo_radio',
                esc_html__('Shop Layout', 'jmcore'),
                'left_sidebar',
                array(
                    'choices' => array(
                        'fullwidth'     => esc_html__('Full-Width', 'jmcore'),
                        'sidebar'       => esc_html__('With Right Sidebar', 'jmcore'),
                        'left_sidebar'  => esc_html__('With Left Sidebar', 'jmcore')
                    ),
                    'json'    => array(
                        'child_options' => array(
                            'fullwidth'    => '',
                            'sidebar'      => 'noo_shop_sidebar',
                            'left_sidebar' => 'noo_shop_sidebar',
                        )
                    )
                ),
                array('transport' => 'postMessage')
            );

            // Control: Shop Sidebar
            $helper->add_control(
                'noo_shop_sidebar',
                'widgets_select',
                esc_html__('Shop Sidebar', 'jmcore'),
                '',
                array(),
                array('transport' => 'postMessage')
            );
            // Control: Result Count
            $helper->add_control(
                'noo_resul_count',
                'checkbox',
                esc_html__('Show Result Count', 'jmcore'),
                1,
                array(),
                array('transport' => 'postMessage')
            );
            // Control: Product OderBy
            $helper->add_control(
                'noo_product_orderby',
                'checkbox',
                esc_html__('Show Sorting Product', 'jmcore'),
                1,
                array(),
                array('transport' => 'postMessage')
            );
            // Control: Product Columns
            $helper->add_control(
                'noo_shop_column',
                'ui_slider',
                esc_html__('Products Columns', 'jmcore'),
                '4',
                array(
                    'json' => array(
                        'data_min'  => 1,
                        'data_max'  => 4,
                        'data_step' => 1
                    )
                ),
                array('transport' => 'postMessage')
            );

            // Control: Number of Product per Page
            $helper->add_control(
                'noo_shop_num',
                'ui_slider',
                esc_html__('Products Per Page', 'jmcore'),
                '12',
                array(
                    'json' => array(
                        'data_min'  => '4',
                        'data_max'  => '50',
                        'data_step' => '1'
                    )
                ),
                array('transport' => 'postMessage')
            );
            // Control: Heading Image
            $helper->add_control(
                'noo_shop_heading_image',
                'noo_image',
                esc_html__('Shop Heading Background Image', 'jmcore'),
                '',
                array(),
                array('transport' => 'postMessage')
            );
            // Control: Hidden Rating product
            $helper->add_control(
                'noo_product_hide_rating',
                'noo_switch',
                esc_html__('Hide Product Rating', 'jmcore'),
                0,
                array(),
                array('transport' => 'postMessage')
            );
            // Sub-section: Single Product
            $helper->add_sub_section(
                'noo_woocommerce_sub_section_product',
                esc_html__('Single Product', 'jmcore')
            );

            // Control: Product Layout
            $helper->add_control(
                'noo_woocommerce_product_layout',
                'noo_same_as_radio',
                esc_html__('Product Layout', 'jmcore'),
                'same_as_shop',
                array(
                    'choices' => array(
                        'same_as_shop'  => esc_html__('Same as Shop Layout', 'jmcore'),
                        'fullwidth'     => esc_html__('Full-Width', 'jmcore'),
                        'sidebar'       => esc_html__('With Right Sidebar', 'jmcore'),
                        'left_sidebar'  => esc_html__('With Left Sidebar', 'jmcore'),
                    ),
                    'json'    => array(
                        'child_options' => array(
                            'fullwidth'    => '',
                            'sidebar'      => 'noo_woocommerce_product_sidebar',
                            'left_sidebar' => 'noo_woocommerce_product_sidebar',
                        )
                    )
                ),
                array('transport' => 'postMessage')
            );

            // Control: Product Sidebar
            $helper->add_control(
                'noo_woocommerce_product_sidebar',
                'widgets_select',
                esc_html__('Product Sidebar', 'jmcore'),
                '',
                array(),
                array('transport' => 'postMessage')
            );

        }

        add_action('customize_register', 'noo_customizer_register_options_woocommerce');
    endif;
endif;

// 13. Custom Code
if (!function_exists('noo_customizer_register_options_custom_code')) :
    function noo_customizer_register_options_custom_code($wp_customize)
    {

        // declare helper object.
        $helper = new NOO_Customizer_Helper($wp_customize);

        // Section: Custom Code
        $helper->add_section(
            'noo_customizer_section_custom_code',
            esc_html__('Custom Code', 'jmcore'),
            nootheme_kses(__('In this section you can add custom JavaScript and CSS to your site.<br/>Your Google analytics tracking code should be added to Custom JavaScript field.', 'jmcore'))
        );

        // Control: Custom JS (Google Analytics)
        $helper->add_control(
            'noo_custom_javascript',
            'textarea',
            esc_html__('Custom JavaScript', 'jmcore'),
            '',
            array(),
            array('transport' => 'postMessage')
        );

        // Control: Custom CSS
        $helper->add_control(
            'noo_custom_css',
            'textarea',
            esc_html__('Custom CSS', 'jmcore'),
            '',
            array(),
            array('transport' => 'postMessage')
        );
    }

    add_action('customize_register', 'noo_customizer_register_options_custom_code');
endif;

// 16. Import/Export Settings.
if (!function_exists('noo_customizer_register_options_tools')) :
    function noo_customizer_register_options_tools($wp_customize)
    {

        // declare helper object.
        $helper = new NOO_Customizer_Helper($wp_customize);

        // Section: Custom Code
        $helper->add_section(
            'noo_customizer_section_tools',
            esc_html__('Import/Export Settings', 'jmcore'),
            esc_html__('All themes from NooTheme share the same theme setting structure so you can export then import settings from one theme to another conveniently without any problem.', 'jmcore')
        );

        // Sub-section: Import Settings
        $helper->add_sub_section(
            'noo_tools_sub_section_import',
            esc_html__('Import Settings', 'jmcore'),
            nootheme_kses(__('Click Upload button then choose a JSON file (.json) from your computer to import settings to this theme.<br/>All the settings will be loaded for preview here and will not be saved until you click button "Save and Publish".', 'jmcore'))
        );

        // Control: Upload Settings
        $helper->add_control(
            'noo_tools_import',
            'import_settings',
            esc_html__('Upload', 'jmcore')
        );

        // Sub-section: Export Settings
        $helper->add_sub_section(
            'noo_tools_sub_section_export',
            esc_html__('Export Settings', 'jmcore'),
            nootheme_kses(__('Simply click Download button to export all your settings to a JSON file (.json).<br/>You then can use that file to restore theme settings to any theme of NooTheme.', 'jmcore'))
        );

        // Control: Download Settings
        $helper->add_control(
            'noo_tools_export',
            'export_settings',
            esc_html__('Download', 'jmcore')
        );

    }

    add_action('customize_register', 'noo_customizer_register_options_tools');
endif;

