<?php
/**
 * Utilities Functions for NOO Framework.
 * This file contains various functions for getting and preparing data.
 *
 * @package    NOO Framework
 * @version    1.0.0
 * @author     NooTheme Team
 * @copyright  Copyright (c) 2014, NooTheme
 * @license    http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link       https://www.nootheme.com
 */
if ( ! function_exists( 'noo_get_endpoint_url' ) ) {
    function noo_get_endpoint_url( $endpoint, $value = '', $permalink = '' ) {
        if ( ! $permalink ) {
            $permalink = get_permalink();
        }

        if ( get_option( 'permalink_structure' ) ) {
            if ( strstr( $permalink, '?' ) ) {
                $query_string = '?' . parse_url( $permalink, PHP_URL_QUERY );
                $permalink    = current( explode( '?', $permalink ) );
            } else {
                $query_string = '';
            }
            $url = trailingslashit( $permalink ) . $endpoint . '/' . $value . $query_string;
        } else {
            $url = esc_url_raw( add_query_arg( $endpoint, $value, $permalink ) );
        }
        return apply_filters( 'noo_get_endpoint_url', $url, $endpoint );
    }
}
if ( ! function_exists( 'noo_mail' ) ) :
    function noo_mail( $to = '', $subject = '', $body = '', $headers = '', $key = '', $attachments = '' ) {

        if ( empty( $headers ) ) {
            $headers    = array();
            $from_name  = jm_et_get_setting( 'from_name', '' );
            $from_email = jm_et_get_setting( 'from_email', '' );

            if ( empty( $from_name ) ) {
                if ( is_multisite() ) {
                    $from_name = $GLOBALS[ 'current_site' ]->site_name;
                } else {
                    $from_name = wp_specialchars_decode( get_option( 'blogname' ), ENT_QUOTES );
                }
            }

            if ( ! empty( $from_name ) && ! empty( $from_email ) ) {
                $headers[] = 'From: ' . $from_name . ' <' . strtolower( $from_email ) . '>';
            }
        }

        $headers = apply_filters( $key . '_header', apply_filters( 'noo_mail_header', $headers ) );

        if ( ! empty( $key ) ) {
            $subject = apply_filters( $key . '_subject', apply_filters( 'noo_mail_subject', $subject ) );
            $body    = apply_filters( $key . '_body', apply_filters( 'noo_mail_body', $body ) );
        }

        // RTL HTML email
        if ( is_rtl() ) {
            $body = '<div dir="rtl">' . $body . '</div>';
        }

        add_filter( 'wp_mail_content_type', 'noo_mail_set_html_content' );

        $result = wp_mail( $to, $subject, $body, $headers, $attachments );

        // Reset content-type to avoid conflicts -- http://core.trac.wordpress.org/ticket/23578
        remove_filter( 'wp_mail_content_type', 'noo_mail_set_html_content' );

        return $result;
    }
endif;
// if ( ! function_exists( 'noo_current_url' ) ):
//     function noo_current_url( $encoded = false ) {
//         global $wp;
//         $current_url = esc_url( add_query_arg( $_SERVER[ 'QUERY_STRING' ], '', home_url( $wp->request ) ) );
//         if ( $encoded ) {
//             return urlencode( $current_url );
//         }

//         return $current_url;
//     }
// endif;
if ( ! function_exists( 'noo_mail_do_not_reply' ) ) :
    function noo_mail_do_not_reply() {
        $sitename = strtolower( $_SERVER[ 'SERVER_NAME' ] );
        if ( substr( $sitename, 0, 4 ) === 'www.' ) {
            $sitename = substr( $sitename, 4 );
        }

        return apply_filters( 'noo_mail_do_not_reply', 'noreply@' . $sitename );
    }
endif;
if(! function_exists('noo_get_profile_percent_company')) :
    function noo_get_profile_percent_company(){
        $company_id = jm_get_employer_company();
        $current_user = wp_get_current_user();
        $fields = jm_get_company_custom_fields();
        $all_socials = noo_get_social_fields();
        $socials  = jm_get_company_socials();
        $value_profile = array();
        $value_socials = array();
        foreach($fields as $field){
            $field_id = jm_company_custom_fields_name( $field['name'], $field );
            $value_profile[] = ! empty( $company_id ) ? get_post_meta( $company_id, $field_id, true ) : '';
        }
        foreach($socials as $social){
            if(isset( $all_socials[$social] )){
                $field = $all_socials[$social];
                $field['name'] = '_' . $social;
                $field['type'] = 'text';
                $field['value'] = $social == 'email' ? 'email@' . $_SERVER['HTTP_HOST'] : 'http://';
                $field_id = $field['name'];
                $value_socials[] = !empty( $company_id ) ? get_post_meta( $company_id, $field_id, true ) : '';
            }
        }
        $count_profile=0;
        $value = array_merge($value_socials,$value_profile);
        foreach ($value as $val){
            $count_profile = (!empty($val)) ? $count_profile+1 : $count_profile;
        }
        $profile_percent = floor((100*$count_profile)/(count($value)));
        return $profile_percent;
    }
endif;
if(! function_exists('noo_get_profile_percent_resume')):
    function noo_get_profile_percent_resume(){
        $candidate_id = get_current_user_id();
        $current_user = wp_get_current_user();
        $fields = jm_get_candidate_custom_fields();
        $all_socials = noo_get_social_fields();
        $socials = jm_get_candidate_socials();
        $value_profile = array();
        $value_socials = array();
        foreach ($fields as $field){
            if( $field['name'] == 'email' ) {
                $value_profile[] = $current_user->user_email;
            } elseif( $field['name'] == 'full_name' ) {
                $value_profile[] = $current_user->display_name;
            }else{
                $field_id = jm_candidate_custom_fields_name( $field['name'], $field );
                $value_profile[] = !empty( $candidate_id ) ? get_user_meta( $candidate_id, $field_id, true ) : '';
            }

        }
        foreach($socials as $social){
            if(isset( $all_socials[$social] )){
                $field = $all_socials[$social];
                $field['name'] = $social;
                $field['type'] = 'text';
                $field['value'] = $social == 'email' ? 'email@' . $_SERVER['HTTP_HOST'] : 'http://';
                $field_id = $field['name'];
                $value_socials[] = !empty( $candidate_id ) ? get_user_meta( $candidate_id, $field_id, true ) : '';
            }
        }
        $value = array_merge($value_socials,$value_profile);
        $count_profile=0;
        foreach ($value as $val){
            $count_profile = (!empty($val)) ? $count_profile+1 : $count_profile;
        }

        $profile_percent = floor((100*$count_profile)/(count($value)));
        return $profile_percent;
    }
endif;
/**
 * Get Location Long Lat from Addresss.
 */
if ( ! function_exists( 'noo_address_to_lng_lat' ) ):
    function noo_address_to_lng_lat( $address ) {

        $geo = file_get_contents( 'http://maps.googleapis.com/maps/api/geocode/json?address=' . urlencode( $address ) . '&sensor=false' );
        $geo = json_decode( $geo, true );

        if ( $geo[ 'status' ] == 'OK' ) {
            $location[ 'lat' ]  = $geo[ 'results' ][ 0 ][ 'geometry' ][ 'location' ][ 'lat' ];
            $location[ 'long' ] = $geo[ 'results' ][ 0 ][ 'geometry' ][ 'location' ][ 'lng' ];

            return $location;
        }

        return '';
    }
endif;