<?php
if ( ! function_exists( 'jm_register_job_post_type' ) ) :
	function jm_register_job_post_type() {
		if ( post_type_exists( 'noo_job' ) ) {
			return;
		}

		$job_slug    = jm_get_job_setting( 'archive_slug', 'jobs' );
		$job_rewrite = $job_slug ? array(
			'slug'       => sanitize_title( $job_slug ),
			'with_front' => true,
			'feeds'      => true
		) : false;

		register_post_type(
			'noo_job',
			array(
				'labels' => array(
					'name'               => esc_html__( 'Jobs', 'jmcore' ),
					'singular_name'      => esc_html__( 'Job', 'jmcore' ),
					'add_new'            => esc_html__( 'Add New Job', 'jmcore' ),
					'add_new_item'       => esc_html__( 'Add Job', 'jmcore' ),
					'edit'               => esc_html__( 'Edit', 'jmcore' ),
					'edit_item'          => esc_html__( 'Edit Job', 'jmcore' ),
					'new_item'           => esc_html__( 'New Job', 'jmcore' ),
					'view'               => esc_html__( 'View', 'jmcore' ),
					'view_item'          => esc_html__( 'View Job', 'jmcore' ),
					'search_items'       => esc_html__( 'Search Job', 'jmcore' ),
					'not_found'          => esc_html__( 'No Jobs found', 'jmcore' ),
					'not_found_in_trash' => esc_html__( 'No Jobs found in Trash', 'jmcore' ),
					'parent'             => esc_html__( 'Parent Job', 'jmcore' ),
					'all_items'          => esc_html__( 'Jobs', 'jmcore' ),
				),
				'description'         => esc_html__( 'This is a place where you can add new job.', 'jmcore' ),
				'public'              => true,
				'menu_icon'           => 'dashicons-portfolio',
				'show_ui'             => true,
				'capability_type'     => 'post',
				'map_meta_cap'        => true,
				'publicly_queryable'  => true,
				'exclude_from_search' => false,
				'hierarchical'        => false, // Hierarchical jobs memory issues - WP loads all records!
				'rewrite'             => apply_filters( 'jm_job_rewrite', $job_rewrite ),
				'query_var'           => true,
				'supports'            => noo_get_option( 'noo_job_comment', false ) ? array(
					'title',
					'editor',
					'comments'
				) : array( 'title', 'editor' ),
				'has_archive'         => true,
				'show_in_nav_menus'   => true,
				'delete_with_user'    => true,
				'can_export'          => true
			) );
		register_taxonomy(
			'job_category',
			array('noo_job'),
			array(
				'labels'       => array(
					'name'          => esc_html__( 'Job Categories', 'jmcore' ),
					'add_new_item'  => esc_html__( 'Add New Job Category', 'jmcore' ),
					'new_item_name' => esc_html__( 'New Job Category', 'jmcore' )
				),
				'hierarchical' => true,
				'query_var'    => true,
				'rewrite'      => array( 'slug' => _x( 'job-category', 'slug', 'jmcore' ) )
			) );
		register_taxonomy(
			'job_type',
			'noo_job',
			array(
				'labels'       => array(
					'name'          => esc_html__( 'Job Types', 'jmcore' ),
					'add_new_item'  => esc_html__( 'Add New Job Type', 'jmcore' ),
					'new_item_name' => esc_html__( 'New Job Type', 'jmcore' )
				),
				'hierarchical' => true,
				'query_var'    => true,
				'rewrite'      => array( 'slug' => _x( 'job-type', 'slug', 'jmcore' ) )
			) );
		register_taxonomy(
			'job_tag',
			'noo_job',
			array(
				'labels'       => array(
					'name'          => esc_html__( 'Job Tags', 'jmcore' ),
					'add_new_item'  => esc_html__( 'Add New Job Tag', 'jmcore' ),
					'new_item_name' => esc_html__( 'New Job Tag', 'jmcore' )
				),
				'hierarchical' => false,
				'query_var'    => true,
				'rewrite'      => array( 'slug' => _x( 'job-tag', 'slug', 'jmcore' ) )
			) );
		register_taxonomy(
			'job_location',
			'noo_job',
			array(
				'labels'       => array(
					'name'          => esc_html__( 'Job Locations', 'jmcore' ),
					'add_new_item'  => esc_html__( 'Add New Job Location', 'jmcore' ),
					'new_item_name' => esc_html__( 'New Job Location', 'jmcore' )
				),
				'hierarchical' => true,
				'query_var'    => true,
				'rewrite'      => array( 'slug' => _x( 'job-location', 'slug', 'jmcore' ) )
			) );

		register_post_status( 'expired', array(
			'label'                     => _x( 'Expired', 'Job status', 'jmcore' ),
			'public'                    => false,
			'exclude_from_search'       => true,
			'show_in_admin_all_list'    => false,
			'show_in_admin_status_list' => true,
			'label_count'               => _n_noop( 'Expired <span class="count">(%s)</span>', 'Expired <span class="count">(%s)</span>', 'jmcore' )
		) );
		register_post_status( 'pending_payment', array(
			'label'                     => _x( 'Pending Payment', 'Job status', 'jmcore' ),
			'public'                    => false,
			'exclude_from_search'       => true,
			'show_in_admin_all_list'    => false,
			'show_in_admin_status_list' => true,
			'label_count'               => _n_noop( 'Pending Payment <span class="count">(%s)</span>', 'Pending Payment <span class="count">(%s)</span>', 'jmcore' )
		) );
		register_post_status( 'inactive', array(
			'label'                     => esc_html__( 'Inactive', 'jmcore' ),
			'public'                    => false,
			'exclude_from_search'       => true,
			'show_in_admin_all_list'    => false,
			'show_in_admin_status_list' => true,
			'label_count'               => _n_noop( 'Inactive <span class="count">(%s)</span>', 'Inactive <span class="count">(%s)</span>', 'jmcore' ),
		) );
	}

	add_action( 'init', 'jm_register_job_post_type', 0 );
endif;

if ( ! function_exists( 'jm_job_switch_theme_hook' ) ) :
	function jm_job_switch_theme_hook( $newname = '', $newtheme = '' ) {
		_job_insert_default_data();
	}

	add_action( 'after_switch_theme', 'jm_job_switch_theme_hook' );

	if ( ! function_exists( '_job_insert_default_data' ) ) :
		function _job_insert_default_data() {
			if ( get_option( 'noo_job_insert_default_data' ) == '1' ) {
				return;
			}
			$taxonomies     = array(
				'job_type' => array(
					'Full Time',
					'Part Time',
					'Freelance',
					'Contract'
				)
			);
			$default_colors = array( '#f14e3b', '#458cce', '#e6b707', '#578523' );

			foreach ( $taxonomies as $taxonomy => $terms ) {
				foreach ( $terms as $index => $term ) {
					if ( ! get_term_by( 'slug', sanitize_title( $term ), $taxonomy ) ) {
						$result = wp_insert_term( $term, $taxonomy );
						if ( ! is_wp_error( $result ) && $taxonomy == 'job_type' ) {
							if ( function_exists( 'update_term_meta' ) ) {
								update_term_meta( $result['term_id'], '_color', $default_colors[ $index ] );
							}
						}
					}
				}
			}

			delete_option( 'noo_job_insert_default_data' );
			update_option( 'noo_job_insert_default_data', '1' );
		}
	endif;
endif;

/**
 * Custom column Job type
 *
 * @package       Fitsica
 * @author        NooTeam <suppport@nootheme.com>
 * @version       1.0
 */

if ( ! function_exists( 'noo_add_table_columns_job_category' ) ) :

	function noo_add_table_columns_job_category( $columns ) {

		unset( $columns[ 'name' ] );
		unset( $columns[ 'description' ] );
		unset( $columns[ 'slug' ] );
		unset( $columns[ 'posts' ] );
		$columns[ 'icon' ]        = esc_html__( 'Icon', 'jmcore' );
		$columns[ 'name' ]        = esc_html__( 'Type', 'jmcore' );
		$columns[ 'slug']         = esc_html__('Slug', 'jmcore');
        $columns['background'] 	  = esc_html__('Background Cover', 'jmcore');
		$columns[ 'description' ] = esc_html__( 'Description', 'jmcore' );
		$columns[ 'posts' ]       = esc_html__( 'Count', 'jmcore' );

		return apply_filters( 'noo_add_table_columns_job_category', $columns );
	}

	add_filter( 'manage_edit-job_category_columns', 'noo_add_table_columns_job_category' );

endif;

/**
 * Show custom column to Job type
 *
 * @package       Fitsica
 * @author        NooTeam <suppport@nootheme.com>
 * @version       1.0
 */

if ( ! function_exists( 'noo_show_table_columns_job_category' ) ) :

	function noo_show_table_columns_job_category( $c, $column_name, $term_id ) {

		global $post;
		switch ( $column_name ) {
            case 'background':
                $image_id = get_term_meta($term_id,'background_cover',true);
                if(!empty($image_id)){
                    $image    = wp_get_attachment_image( $image_id, 'thumbnail' );
                    echo '<div class="noo-thumb-taxonomy-background ">' . $image . '</div>';
                }
                break;
			case 'icon':

				$icon = get_term_meta( $term_id, 'icon_type', true );
				if ( empty( $icon ) ) {
					$icon = 'fa fa-home';
				}
				echo '<i class="fa ' . esc_attr( $icon ) . '"></i>';
				break;
		}
	}

	add_action( 'manage_job_category_custom_column', 'noo_show_table_columns_job_category', 10, 3 );

endif;

/**
 * Add custom field to Listing type
 *
 * @package       Fitsica
 * @author        NooTeam <suppport@nootheme.com>
 * @version       1.0
 */

if ( ! function_exists( 'noo_add_field_job_category' ) ) :

	function noo_add_field_job_category() {
		wp_enqueue_style( 'vendor-fontawesome', JM_ASSETS . '/vendor/fontawesome/css/font-awesome.min.css');
		wp_enqueue_script( 'noo-iconpicker', JM_FRAMEWORK_ADMIN_URI . '/assets/js/noo-iconpicker.js', null, null, false );
		?>
		<div id="noo-item-icon_type-wrap" class="noo-item-wrap" style="margin-bottom: 30px;">
            <label><?php echo esc_html__( 'Icon', 'jmcore' ) ?></label>
			<div class="noo-iconpicker">
				<div class="noo-iconpicker-group">
					<input data-placement="bottomRight" class="noo-iconpicker-input" type="text" name="icon_type" id="noo-field-item-icon_type" value=""/>
					<span class="input-group-addon"></span>
				</div>
			</div>
		</div>
        <?php
        if ( function_exists( 'wp_enqueue_media' ) ) {
        wp_enqueue_media();
        } else {
        wp_enqueue_style( 'thickbox' );
        wp_enqueue_script( 'media-upload' );
        wp_enqueue_script( 'thickbox' );
        }
        $image_id = '';
        $image    = wp_get_attachment_image( $image_id, 'thumbnail' );

        $image_id = ! empty( $image ) ? $image_id : '';
        $id = 'background_cover';
        $output   = ! empty( $image_id ) ? $image : '';
        $btn_text = ! empty( $image_id ) ? esc_html__( 'Change Image', 'jmcore' ) : esc_html__( 'Select Image', 'jmcore' );
        echo'<label>'.esc_html__('Background Cover', 'jmcore').'</label>';
        echo '<input type="hidden" name="' . $id . '" id="' . $id . '" value="' . ( $image_id ) . '" />';
        echo '<input type="button" class="button button-primary" name="' . $id . '_button_upload" id="' . $id . '_upload" value="' . $btn_text . '" style="margin-bottom:30px"/>';
        if ( ! empty( $image_id ) ):
        echo '<input type="button" class="button" name="' . $id . '_button_clear" id="' . $id . '_clear" value="' . esc_html__( 'Clear Image', 'jmcore' ) . '" />';
        endif;
        echo '<div class="noo-thumb-wrapper ">' . $output . '</div>';
        ?>
        <script>
            jQuery(document).ready(function ($) {

                <?php if ( empty ( $image_id ) ) : ?> $('#<?php echo esc_attr( $id ); ?>_clear').css('display', 'none'); <?php endif; ?>

                $('#<?php echo esc_attr( $id ); ?>_upload').on('click', function (event) {
                    event.preventDefault();

                    var noo_upload_btn = $(this);

                    // if media frame exists, reopen
                    if (wp_media_frame) {
                        wp_media_frame.open();
                        return;
                    }

                    // create new media frame
                    // I decided to create new frame every time to control the selected images
                    var wp_media_frame = wp.media.frames.wp_media_frame = wp.media({
                        title: "<?php echo esc_html__( 'Select or Upload your Image', 'jmcore' ); ?>",
                        button: {
                            text: "<?php echo esc_html__( 'Select', 'jmcore' ); ?>"
                        },
                        library: {type: 'image'},
                        multiple: false
                    });

                    // when open media frame, add the selected image
                    wp_media_frame.on('open', function () {
                        var selected_id = noo_upload_btn.siblings('#<?php echo esc_attr( $id ); ?>').val();
                        if (!selected_id)
                            return;
                        var selection = wp_media_frame.state().get('selection');
                        var attachment = wp.media.attachment(selected_id);
                        attachment.fetch();
                        selection.add(attachment ? [attachment] : []);
                    });

                    // when image selected, run callback
                    wp_media_frame.on('select', function () {
                        var attachment = wp_media_frame.state().get('selection').first().toJSON();
                        noo_upload_btn.siblings('#<?php echo esc_attr( $id ); ?>').val(attachment.id);

                        noo_thumb_wraper = noo_upload_btn.siblings('.noo-thumb-wrapper');
                        noo_thumb_wraper.html('');
                        noo_thumb_wraper.append('<img src="' + attachment.url + '" alt="" />');

                        noo_upload_btn.attr('value', '<?php echo esc_html__( 'Change Image', 'jmcore' ); ?>');
                        $('#<?php echo esc_attr( $id ); ?>_clear').css('display', 'inline-block');
                    });

                    // open media frame
                    wp_media_frame.open();
                });

                $('#<?php echo esc_attr( $id ); ?>_clear').on('click', function (event) {
                    var noo_clear_btn = $(this);
                    noo_clear_btn.hide();
                    $('#<?php echo esc_attr( $id ); ?>_upload').attr('value', '<?php echo esc_html__( 'Select Image', 'jmcore' ); ?>');
                    noo_clear_btn.siblings('#<?php echo esc_attr( $id ); ?>').val('');
                    noo_clear_btn.siblings('.noo-thumb-wrapper').html('');
                });
            });
        </script>

        <?php
	}

	add_action( apply_filters( 'noo_job_category', 'job_category' ) . '_add_form_fields', 'noo_add_field_job_category' );

endif;

/**
 * Process data when edit custom field to Listing type
 *
 * @package       Fitsica
 * @author        NooTeam <suppport@nootheme.com>
 * @version       1.0
 */

if ( ! function_exists( 'noo_edit_field_job_category' ) ) :

	function noo_edit_field_job_category( $term, $taxonomy ) {
		/**
		 * VAR
		 */
		$transient_name = 'noo_edit_field_job_category' . $term->term_id;
		if ( false === ( $icon = get_transient( $transient_name ) ) ) {

			$icon = get_term_meta( $term->term_id, 'icon_type', true );

			if ( empty( $icon ) ) {
				$icon = 'fa-home';
			}

			set_transient( $transient_name, $icon, YEAR_IN_SECONDS );
		}

		$args_icon = array(
			'name' => 'icon_type',
			'type' => 'icon',
		);

		wp_enqueue_style( 'vendor-fontawesome', JM_ASSETS . '/vendor/fontawesome/css/font-awesome.min.css');
		wp_enqueue_script( 'noo-iconpicker', JM_FRAMEWORK_ADMIN_URI . '/assets/js/noo-iconpicker.js', null, null, false );
		?>
		<tr class="form-field">
			<th scope="row" valign="top"><label><?php echo esc_html__( 'Icon', 'jmcore' ); ?></label></th>
			<td>
                <div class="noo-iconpicker">
                    <div class="noo-iconpicker-group">
                        <input data-placement="bottomRight" class="noo-iconpicker-input" type="text" name="icon_type" id="noo-field-item-icon_type" value="<?php echo esc_attr( $icon ) ?>"/>
                        <span class="input-group-addon"></span>
                    </div>
                </div>
			</td>
		</tr>
        <tr class="form-field">
            <th scope="row" valign="top"><label><?php echo esc_html__('Background Cover', 'jmcore') ?></label></th>
            <td>
                <?php
                $transient_name = 'rp_edit_field_background_job_category_' . $term->term_id;
                if ( false === ( $image_id = get_transient( $transient_name ) ) ) {

                    $image_id = get_term_meta( $term->term_id, 'background_cover', true );

                    set_transient( $transient_name, $image_id, YEAR_IN_SECONDS );
                }
                if ( function_exists( 'wp_enqueue_media' ) ) {
                    wp_enqueue_media();
                } else {
                    wp_enqueue_style( 'thickbox' );
                    wp_enqueue_script( 'media-upload' );
                    wp_enqueue_script( 'thickbox' );
                }
                $image    = wp_get_attachment_image( $image_id, 'thumbnail' );

                $image_id = ! empty( $image ) ? $image_id : '';
                $id = 'background_cover';
                $output   = ! empty( $image_id ) ? $image : '';
                $btn_text = ! empty( $image_id ) ? esc_html__( 'Change Image', 'jmcore' ) : esc_html__( 'Select Image', 'jmcore' );
                echo '<input type="hidden" name="' . $id . '" id="' . $id . '" value="' . ( $image_id ) . '" />';
                echo '<input type="button" class="button button-primary" name="' . $id . '_button_upload" id="' . $id . '_upload" value="' . $btn_text . '" style="margin-bottom:30px"/>';
                if ( ! empty( $image_id ) ):
                    echo '<input type="button" class="button" name="' . $id . '_button_clear" id="' . $id . '_clear" value="' . esc_html__( 'Clear Image', 'jmcore' ) . '" />';
                endif;
                echo '<div class="noo-thumb-wrapper ">' . $output . '</div>';
                ?>
                <script>
                    jQuery(document).ready(function ($) {

                        <?php if ( empty ( $image_id ) ) : ?> $('#<?php echo esc_attr( $id ); ?>_clear').css('display', 'none'); <?php endif; ?>

                        $('#<?php echo esc_attr( $id ); ?>_upload').on('click', function (event) {
                            event.preventDefault();

                            var noo_upload_btn = $(this);

                            // if media frame exists, reopen
                            if (wp_media_frame) {
                                wp_media_frame.open();
                                return;
                            }

                            // create new media frame
                            // I decided to create new frame every time to control the selected images
                            var wp_media_frame = wp.media.frames.wp_media_frame = wp.media({
                                title: "<?php echo esc_html__( 'Select or Upload your Image', 'jmcore' ); ?>",
                                button: {
                                    text: "<?php echo esc_html__( 'Select', 'jmcore' ); ?>"
                                },
                                library: {type: 'image'},
                                multiple: false
                            });

                            // when open media frame, add the selected image
                            wp_media_frame.on('open', function () {
                                var selected_id = noo_upload_btn.siblings('#<?php echo esc_attr( $id ); ?>').val();
                                if (!selected_id)
                                    return;
                                var selection = wp_media_frame.state().get('selection');
                                var attachment = wp.media.attachment(selected_id);
                                attachment.fetch();
                                selection.add(attachment ? [attachment] : []);
                            });

                            // when image selected, run callback
                            wp_media_frame.on('select', function () {
                                var attachment = wp_media_frame.state().get('selection').first().toJSON();
                                noo_upload_btn.siblings('#<?php echo esc_attr( $id ); ?>').val(attachment.id);

                                noo_thumb_wraper = noo_upload_btn.siblings('.noo-thumb-wrapper');
                                noo_thumb_wraper.html('');
                                noo_thumb_wraper.append('<img src="' + attachment.url + '" alt="" />');

                                noo_upload_btn.attr('value', '<?php echo esc_html__( 'Change Image', 'jmcore' ); ?>');
                                $('#<?php echo esc_attr( $id ); ?>_clear').css('display', 'inline-block');
                            });

                            // open media frame
                            wp_media_frame.open();
                        });

                        $('#<?php echo esc_attr( $id ); ?>_clear').on('click', function (event) {
                            var noo_clear_btn = $(this);
                            noo_clear_btn.hide();
                            $('#<?php echo esc_attr( $id ); ?>_upload').attr('value', '<?php echo esc_html__( 'Select Image', 'jmcore' ); ?>');
                            noo_clear_btn.siblings('#<?php echo esc_attr( $id ); ?>').val('');
                            noo_clear_btn.siblings('.noo-thumb-wrapper').html('');
                        });
                    });
                </script>
            </td>
        </tr>

<?php
        }

	add_action( apply_filters( 'noo_property_job_category', 'job_category' ) . '_edit_form_fields', 'noo_edit_field_job_category', 10, 2 );

endif;

/**
 * Process data when save custom field to Listing type
 *
 * @package       Fitsica
 * @author        NooTeam <suppport@nootheme.com>
 * @version       1.0
 */

if ( ! function_exists( 'rp_save_field_job_category' ) ) :

	function rp_save_field_job_category( $term_id, $tt_id, $taxonomy ) {

		if ( isset( $_POST[ 'icon_type' ] ) ) {

			$transient_name = 'noo_edit_field_job_category_' . $term_id;

			delete_transient( $transient_name );

			update_term_meta( $term_id, 'icon_type', esc_attr( $_POST[ 'icon_type' ] ) );
		}
		if(isset($_POST['background_cover'])){
		    $transient_name='rp_edit_field_background_job_category_' . $term_id;
		    delete_transient($transient_name);
		    update_term_meta($term_id,'background_cover',esc_attr($_POST['background_cover']));
        }
	}

	add_action( 'created_term', 'rp_save_field_job_category', 10, 3 );
	add_action( 'edit_term', 'rp_save_field_job_category', 10, 3 );

endif;

if ( ! function_exists( 'noo_get_list_job_category' ) ) :

	function noo_get_list_job_category() {

		$job_categorys = get_categories( array( 'orderby' => 'NAME', 'order' => 'ASC', 'taxonomy' => 'job_category' ) );
		$list = array();
		foreach ( (array)$job_categorys as $job_category ) {
			$list[ $job_category->name ] = $job_category->term_id;
		}

		return $list;
	}

endif;

if ( ! function_exists( 'noo_heding_shortcode' ) ) :
    
    function noo_heding_shortcode( $title = '', $sub_title = '', $align = 'text-center' ) {
        ?>
        <div class="noo-heading-sc <?php echo esc_attr( $align ) ?>">
            <?php if ( !empty( $title ) ) : ?>
                <h3 class="noo-title-sc">
                    <?php echo $title ?>
                </h3>
            <?php endif; ?>

	        <?php if ( !empty( $title ) ) : ?>
                <p class="noo-subtitle-sc">
			        <?php echo esc_html( $sub_title ) ?>
                </p>
	        <?php endif; ?>
        </div>
        <?php
    }
    
endif;

if ( !function_exists( 'noo_job_category_query' ) ) {
	function noo_job_category_query($query){
        if(is_tax('job_category') && $query->is_main_query()){
            $query->set('post_type', 'noo_job');
        }
    }
    add_action( 'pre_get_posts', 'noo_job_category_query' );
}
