<?php

if( !function_exists( 'jm_get_job_default_fields' ) ) :
	function jm_get_job_default_fields() {
		$default_fields = array(
				'cover_image' => array(
					'name' => 'cover_image',
					'label' => esc_html__('Cover Image', 'jmcore'),
					'is_default' => true,
					'type' => 'single_image',
					'value'      => esc_html__( 'Recommend size: 1400x600px', 'jmcore' ),
					'allowed_type' => array(
						'single_image' => esc_html__( 'Single Image', 'jmcore' ),
					),
					'required' => false
				),
				'job_category' => array(
					'name' => 'job_category',
					'label' => esc_html__('Job Category', 'jmcore'),
					'is_default' => true,
                    'is_tax' => true,
					'type' => 'multiple_select',
					'allowed_type' => array(
						'select'			=> esc_html__('Select', 'jmcore'),
						'multiple_select'	=> esc_html__( 'Multiple Select', 'jmcore' ),
					),
					'required' => true
				),
                'job_location' => array(
                    'name' => 'job_location',
                    'label' => esc_html__('Job Location', 'jmcore'),
                    'is_default' => true,
                    'is_tax' => true,
                    'type' => 'multi_location_input',
                    'allowed_type' => array(
                        'multi_location_input'	=> esc_html__('Multiple Location with Input', 'jmcore'),
                        'multi_location'		=> esc_html__('Multiple Location', 'jmcore'),
                        'single_location_input'	=> esc_html__('Single Location with Input', 'jmcore'),
                        'single_location'		=> esc_html__('Single Location', 'jmcore'),
                    ),
                    'required' => true
                ),
				'job_type' => array(
					'name' => 'job_type',
					'label' => esc_html__('Job Type', 'jmcore'),
					'is_default' => true,
                    'is_tax' => true,
					'type' => 'select',
					'allowed_type' => array(
						'select'			=> esc_html__('Select', 'jmcore'),
						'multiple_select'	=> esc_html__( 'Multiple Select', 'jmcore' ),
						'radio'				=> esc_html__( 'Radio', 'jmcore' ),
						'checkbox'			=> esc_html__( 'Checkbox', 'jmcore' )
					),
					'required' => true
				),
				'full_address' => array(
					'name' => 'full_address',
					'label' => esc_html__('Address', 'jmcore'),
					'is_default' => true,
					'type' => 'text',
					'desc' => esc_html__('Enter Streets, Region, Locality, Country. eg: 1600 Chestnut Street, Philadelphia, PA, USA ', 'jmcore'),
					'allowed_type' => array(
						'text'			=> esc_html__('Text', 'jmcore'),
						'location_picker'			=> esc_html__('Map Picker', 'jmcore'),
					),
					'required' => false
				),
				'postalcode' => array(
					'name' => 'postalcode',
					'label' => esc_html__('Postal Code', 'jmcore'),
					'is_default' => true,
					'type' => 'text',
					'allowed_type' => array(
						'text'			=> esc_html__('Text', 'jmcore'),
						'number'	    => esc_html__('Number', 'jmcore'),
					),
					'required' => false
				),
				'job_tag' => array(
					'name' => 'job_tag',
					'label' => esc_html__('Job Tag', 'jmcore'),
					'is_default' => true,
                    'is_tax' => true,
					'type' => 'multiple_select',
					'allowed_type' => array(
						'select'			    => esc_html__('Select', 'jmcore'),
						'multiple_select'	    => esc_html__( 'Multiple Select', 'jmcore' ),
						'radio'				    => esc_html__( 'Radio', 'jmcore' ),
						'checkbox'			    => esc_html__( 'Checkbox', 'jmcore' ),
                        'multi_job_tag_input'   => esc_html__('Multiple Job_Tag with Input'),
					),
					'is_disabled' => 'yes',
					'required' => false
				),
                'job_salary' => array(
                    'name' => 'job_salary',
                    'label' => esc_html__('Salary Offer', 'jmcore'),
                    'is_default' => true,
                    'type' => 'text',
                    'allowed_type' => array(
                        'price_range'	=> esc_html__('Price Range', 'jmcore'),
                    ),
                    'required' => false
                ),
				'job_closing' => array(
					'name' => 'job_closing',
					'label' => esc_html__('Closing Date', 'jmcore'),
					'desc' => esc_html__('Set a date or leave blank to automatically use the Expired date', 'jmcore'),
					'is_default' => true,
					'type' => 'datepicker',
					'allowed_type' => array(
						'datepicker'			=> esc_html__('Date Picker', 'jmcore')
					),
					'required' => false
				),
			);

		return apply_filters( 'jm_job_default_fields', $default_fields );
	}
endif;

if( !function_exists( 'jm_get_job_taxonomies' ) ) :
	function jm_get_job_taxonomies() {
		return apply_filters( 'jm_job_taxonomies', array( 'job_category', 'job_location', 'job_type', 'job_tag' ) );
	}
endif;

if( !function_exists( 'jm_job_tax_field_params' ) ) :
	function jm_job_tax_field_params( $args = array(), $job_id = 0 )  {
		extract($args);

		if( in_array( $field['name'], jm_get_job_taxonomies() ) ) {
			$field_id = str_replace('job_', '', $field['name']);
			$field_value = array();
			$terms = get_terms( $field['name'], array( 'hide_empty' => 0 ) );
			foreach ($terms as $term) {
				if( is_taxonomy_hierarchical( $field['name'] ) ) {
					$field_value[] = $term->term_id . '|' . $term->name;
				} else {
					$field_value[] = $term->slug . '|' . $term->name;
				}
			}

			$field['value'] = $field_value;
			$field['no_translate'] = true;

			$value = array();
			if( !empty( $job_id ) ) {
				if( is_taxonomy_hierarchical( $field['name'] ) ) {
					$value = wp_get_object_terms( $job_id, $field['name'], array( 'fields' => 'ids' ) );
				} else {
					$value = wp_get_object_terms( $job_id, $field['name'], array( 'fields' => 'slugs' ) );
				}
			}

			if( empty( $field['type'] ) || $field['type'] == 'text' ) {
				$default_fields = jm_get_job_default_fields();
				$field['type'] = $default_fields[$field['name']]['type'];
			}
		}

		return compact( 'field', 'field_id', 'value' );
	}
	
	add_filter( 'jm_job_render_form_field_params', 'jm_job_tax_field_params', 10, 2 );
endif;

if( !function_exists( 'jm_job_tax_search_field_params' ) ) :
	function jm_job_tax_search_field_params( $args = array(), $job_id = 0 )  {
		extract($args);
		$hide_empty_tax = jm_get_job_setting( 'hide_empty_tax','');
		if( in_array( $field['name'], jm_get_job_taxonomies() ) ) {
			$field_id = str_replace('job_', '', $field['name']);
			$field_value = array();
			$terms = get_terms( $field['name'], array( 'hide_empty' => (int)$hide_empty_tax) );
			foreach ($terms as $term) {
				$field_value[] = $term->slug . '|' . $term->name;
			}
			$field['value'] = $field_value;
			$field['no_translate'] = true;
			if( isset( $_GET[$field_id] ) && !empty( $_GET[$field_id] ) ) {
				$value = $_GET[$field_id];
			} else {
				if( is_tax( $field['name'] ) ) {
					global $wp_query;
					$term_id = $wp_query->get_queried_object_id();
					$term = get_term( $term_id, $field['name'] );
					$value = !empty( $term ) && !is_wp_error( $term ) ? $term->slug : '';
				}
			}

			if( empty( $field['type'] ) || $field['type'] == 'text' ) {
				$default_fields = jm_get_job_default_fields();
				$field['type'] = $default_fields[$field['name']]['type'];
			}
		}

		return compact( 'field', 'field_id', 'value' );
	}
	
	add_filter( 'jm_job_render_search_field_params', 'jm_job_tax_search_field_params' );
endif;

if( !function_exists( 'jm_job_get_tax_value' ) ) :
	function jm_job_get_tax_value( $job_id = 0, $field_id = 'job_category' )  {
		if( empty( $job_id ) ) return array();

		$value = array();
		$terms = get_the_terms( $job_id, $field_id );
		if( !empty( $terms ) && !is_wp_error( $terms ) ) {
			foreach ($terms as $term) {
				$value[] = '<a href="' . get_term_link($term->term_id,$field_id) . '">' . $term->name . '</a>';
			}
		}

		return $value;
	}
endif;