<?php
if (!function_exists('jm_job_template_loader')) :
    function jm_job_template_loader($template)
    {
        $job_taxes = jm_get_job_taxonomies();
        if (is_post_type_archive('noo_job') || is_tax($job_taxes)) {
            $template = locate_template('archive-noo_job.php');
        }

        return $template;
    }

    add_filter('template_include', 'jm_job_template_loader');
endif;

if (!function_exists('jm_job_post_class')) :
    function jm_job_post_class($output)
    {

        $post_id = get_the_ID();
        if ('noo_job' == get_post_type($post_id)) {
            if ('yes' == noo_get_post_meta($post_id, '_featured', '')) {
                $output[] = 'featured-job';
            }
            if ($closing = noo_get_post_meta($post_id, 'job_closing', '')) {
                if (absint($closing) < time()) {
                    $output[] = 'closed-job';
                }
            }
            if (noo_get_option('noo_jobs_list_style', '') == 'two') {
                $output[] = 'noo_job-style-2';
            }elseif (noo_get_option('noo_job_list_style','') == ''){
                $output[] = 'noo_job-style-1';
            }
        }

        return $output;
    }

    add_filter('post_class', 'jm_job_post_class');
endif;

if (!function_exists('jm_job_social_media')) :
    function jm_job_social_media()
    {
        if (!is_singular('noo_job')) {
            return;
        }

        // Facebook media
        if (noo_get_option('noo_job_social_facebook', true)) {
            $job_id = get_the_ID();
            $thumbnail_id = noo_get_post_meta($job_id, 'cover_image', '');

            if (empty($thumbnail_id)) {
                $company_id = jm_get_job_company($job_id);
                $thumbnail_id = noo_get_post_meta($company_id, 'logo', '');
            }
            $social_share_img = wp_get_attachment_url($thumbnail_id);
            if (!empty($social_share_img)) :
                ?>
                <meta property="og:url" content="<?php echo get_permalink($job_id); ?>"/>
                <meta property="og:image" content="<?php echo $social_share_img; ?>"/>
                <?php if (is_ssl()) : ?>
                <meta property="og:image:secure_url" content="<?php echo $social_share_img; ?>"/>
            <?php endif; ?>
            <?php endif;
        }
    }

    add_filter('wp_head', 'jm_job_social_media');
endif;

if (!function_exists('jm_job_loop')) :
    function jm_job_loop($args = '')
    {
        $defaults = array(
            'paginate' => 'normal',
            'class' => '',
            'item_class' => 'loadmore-item',
            'query' => '',
            'title_type' => 'text',
            'title' => '',
            'pagination' => 1,
            'excerpt_length' => 30,
            'posts_per_page' => '',
            'ajax_item' => false,
            'featured' => 'recent',
            'no_content' => 'text',
            'display_style' => noo_get_option('noo_jobs_display_type', 'list'),
            'list_style' => noo_get_option('noo_jobs_list_style', 'list-1'),
            'list_job_meta' => array(),
            'paginate_data' => array(),
            'show_view_more' => 'yes',
            'show_job_tool' => 'yes',
            'show_autoplay' => 'on',
            'is_shortcode' => false,
            'style' => 'style-1', // Use for Noo Job elementor widget
            'is_widget' => false,
            'related_job' => false,
            'list_column' => '4',
            'grid_isotope' => false,
        );
        $loop_args = wp_parse_args($args, $defaults);

        extract($loop_args);

        global $wp_query;

        if (!empty($loop_args['query'])) {
            $wp_query = $loop_args['query'];
        }
        $content_meta = array();

        $content_meta['show_company'] =get_theme_mod('noo_jobs_show_company_name', true);
        $settings_fields = get_theme_mod('noo_jobs_list_fields', 'job_type,job_location,job_date,_closing');

        $content_meta['fields'] = !is_array($settings_fields) ? explode(',', $settings_fields) : $settings_fields;

        $list_job_meta = array_merge($content_meta, $list_job_meta);
        $paginate_data = apply_filters('noo-job-loop-paginate-data', $paginate_data, $loop_args);

        $item_class = array($item_class);
        $item_class[] = 'noo_job';
        $item_class[] = $style;
        if ($is_widget) {
            remove_action('job_list_before', 'noo_job_list_before');
            $pagination = false;
        }
        ob_start();
        if ($is_shortcode || $is_widget) {
            remove_action('job_list_before', 'noo_job_list_before');
            // Use for Noo Job elementor widget
            if ($display_style == 'slider') {
                include(locate_template("layouts/job/loop/slider.php"));
            }elseif ($display_style == 'list') {
                if('style-1' == $style){
                    include(locate_template("layouts/job/loop/list2.php"));
                }else{
                    include(locate_template("layouts/job/loop/list_full.php"));
                }
                
            }elseif ($display_style == 'grid') {
                include(locate_template("layouts/job/loop/grid2.php"));
            } else {
                include(locate_template("layouts/job/loop/loop.php"));
            }
        } else {
            add_action('job_list_before', 'noo_job_list_before');
            // User for archive job
            if ($display_style == 'grid') {
                include(locate_template("layouts/job/loop/grid.php"));
            }else {
                include(locate_template("layouts/job/loop/loop.php"));
            }
        }
        wp_reset_query();
        echo ob_get_clean();
    }
endif;

if (!function_exists('jm_job_detail')) :
    function jm_job_detail($query = null, $in_preview = false)
    {
        if (empty($query)) {
            global $wp_query;
            $query = $wp_query;
        }
        /* add code select detail layout job */
        $layout = noo_get_option('noo_job_detail_layout', 'style-1');

        while ($query->have_posts()): $query->the_post();
            global $post;

            $job_id = $post->ID;
            $company_id = jm_get_job_company($post);

            $template = get_post_meta($job_id,'_job_detail_templates',true);
            $template = is_array($template) ? implode('',$template) : $template;

            $layout = (!empty($template)) ? $template : $layout;
            $layout = isset($_GET['layout']) ? sanitize_text_field($_GET['layout']) : $layout;
            
            ob_start();
            if (!$in_preview) {
                if (jm_can_view_job($job_id)) {
                    if ('style-1' == $layout) {
                        include(locate_template("layouts/job/single/details.php"));
                    } 
                    elseif('style-2' == $layout) {
                        include(locate_template("layouts/job/single/details-2.php"));
                    }
                    elseif('style-3' == $layout)
                    {
                        include(locate_template("layouts/job/single/details-3.php"));
                    } 
                    elseif('style-4' == $layout)
                    {
                        include(locate_template("layouts/job/single/details-4.php"));
                    }
                    elseif('style-5' == $layout)
                    {
                        include(locate_template("layouts/job/single/details-5.php"));
                    }
                    elseif('style-6' == $layout)
                    {
                        include(locate_template("layouts/job/single/details-6.php"));
                    }
                    elseif('style-7' == $layout)
                    {
                        include(locate_template("layouts/job/single/details-7.php"));
                    }
                    elseif('style-8' == $layout)
                    {
                        include(locate_template("layouts/job/single/details-8.php"));
                    }

                } else {
                    include(locate_template("layouts/job/cannot-view-job.php"));
                }
            } else {
                include(locate_template("layouts/forms/noo_job-preview.php"));
            }
            echo ob_get_clean();

        endwhile;
        wp_reset_query();
    }
endif;

if (!function_exists('jm_the_job_meta')) :
    function jm_the_job_meta($args = '', $job = null)
    {
        $defaults = array(
            'show_company' => true,
            'fields' => null,
            'job_id' => '',
            'schema' => false,
        );
        $args = wp_parse_args($args, $defaults);

        if (empty($job) || !is_object($job)) {
            $job = get_post(get_the_ID());
        }

        $job_id = $job->ID;

        $html = array();
        $html[] = '<p class="content-meta">';

        // Company Name
        $company_id = jm_get_job_company($job);
        $company_logo_id = noo_get_post_meta($company_id, 'logo', '');
        $company_logo_url = wp_get_attachment_image_url($company_logo_id);
        if ($args['show_company']) {

            if (!empty($company_id)) {
                $schema = $schema_image = $schema_name = $schema_url = '';
                if($args['schema']){
                    $schema = 'itemprop="hiringOrganization" itemscope itemtype="http://schema.org/Organization"';
                    $schema_name = ' itemprop="name"';
                    $schema_url = ' itemprop="url"';
                    $schema_image = '<span class="company-logo" itemprop="logo"><img src="'.$company_logo_url.'"></span>';

                }

                $html[] = '<span class="job-company" '.$schema.'> <a '.$schema_url.' href="' . get_permalink($company_id) . '" '.$schema_url.'>'.$schema_image.'<span '.$schema_name.'>' . get_the_title($company_id) . '</span></a>';
                $html[] = '</span>';
                if($args['schema']){
                    $html[] = '</span>';
                }
            }
        }
        $current_user_role = Noo_Member::get_user_role(get_current_user_id());
        $settings_fields = get_theme_mod('noo_jobs_list_fields','job_location,job_category');
        $settings_fields = !is_array($settings_fields) ? explode(',', $settings_fields) : $settings_fields;
        $fields_define = jm_get_job_custom_fields();

        if (!empty($args['fields'])) {
            $fields = (array)$args['fields'];
            $user_per = noo_get_user_permission();
            foreach ($fields as $field_id) {
                $icon_class = isset($fields_define[$field_id]['icon']) ? $fields_define[$field_id]['icon'] : '';
                $icon = str_replace("|", " ", $icon_class);
                if (in_array($field_id, $settings_fields)) {
                    $permission = isset($fields_define[$field_id]['permission']) ? $fields_define[$field_id]['permission'] : '';
                    $is_can_view = false;
                    if (empty($permission) or 'public' == $permission or $user_per == 'candidate_with_package' or $user_per == 'true' or 'administrator' == $current_user_role) {
                        $is_can_view = true;
                    } elseif ($permission == $user_per) {
                        $is_can_view = true;
                    }
                    if ($field_id == 'job_location') {
                        $locations_html = '';
                        $separator = ', ';
                        $location_name = '';
                        $locations = get_the_terms($job_id, 'job_location');
                        if (!empty($locations) && !is_wp_error($locations)) {
                            foreach ($locations as $location) {
                                $locations_html .= '<a href="' . get_term_link($location->term_id, 'job_location') . '">' . $location->name . '</a>' . $separator;
                                $location_name  .= $location->name . ', ';
                            }
                            if($is_can_view == false){
                                $locations_html = '**********';
                            }
                            $html[] = '<span class="job-location">';
                            $html[] = '<i class="' . $icon . '"></i>';
                            $html[] = trim($locations_html, $separator);
                            $html[] = '</span>';
                        }
                    } elseif ($field_id == 'job_type') {
                        $allow_multiple_type = (isset($fields_define['job_type'])) ? (strpos($fields_define[$field_id]['type'], 'multi') !== false) : false;
                        $type = jm_get_job_type($job_id, $allow_multiple_type);
                        if (!empty($type)) {
                            foreach ($type as $typ) {
                                $schema = $args['schema'] ? ' itemprop="employmentType"' : '';
                                $html[] = '<span class="job-type"><a href="' . get_term_link($typ, 'job_type') . '" style="color: ' . $typ->color . '"><i class="linearicons-bookmark2" style="color: ' . $typ->color . '"></i> <span' . $schema . '>' . $typ->name . '</span></a></span>';
                            }
                        }
                    } elseif (($field_id == 'full_address')) {
                        $value = get_post_meta(get_the_ID(), $field_id, true);
                        if (!empty($value)) {
                            $address_html = '';
                            $separator = ', ';
                            $schema1 = $schema2 = $schema4 = $schema_address = '';
                            $schema3 = array();

                            if ($args['schema']) {
                                $schema1 = ' itemprop="jobLocation" itemscope itemtype="http://schema.org/Place"';
                                $schema2 = ' itemprop="address" itemscope itemtype="http://schema.org/PostalAddress"';
                                $schema3[] = ' itemprop="streetAddress"';
                                $schema3[] = ' itemprop="addressRegion"';
                                $schema3[] = ' itemprop="addressLocality"';
                                $schema3[] = ' itemprop="addressCountry"';
                                $schema4 = ' itemprop="postalCode"';
                            }
                            $postalCode = noo_get_post_meta($job_id, 'postalcode', '');
                            if($is_can_view == false){
                                $value        = '**********';
                                $postalCode   = '**********';
                            }
                            $full_address = explode(',', $value);
                            $html[] = '<span class="job-full-address" ' . $schema1 . '>';
                            $html[] = $args['schema'] ? '<span' . $schema2 . ' class="schema-local">' : '';

                            $html[] = '<i class="' . $icon . '"></i>';

                            if (is_array($full_address) && count($full_address) > 0) {
                                $i = 0;
                                foreach ($full_address as $value) {
                                    if ($args['schema']) $schema_address = $schema3[$i];
                                    if (!empty($value)) {
                                        $address_html .= '<span' . $schema_address . '>' . $value . '</span>' . $separator;
                                    }
                                    $i++;

                                };
                                $html[] = trim($address_html, $separator);
                            }

                            if ($postalCode) {
                                $html[] = ', <span' . $schema4 . '>' . $postalCode . '</span>';
                            }

                            $html[] = $args['schema'] ? '</span>' : '';
                            $html[] = '</span>';
                        }
                    } elseif ($field_id == 'job_category') {
                        $categories_html = '';
                        $separator = ' - ';

                        $categories = get_the_terms($job_id, 'job_category');
                        if (!empty($categories) && !is_wp_error($categories)) {
                            foreach ($categories as $category) {
                                $categories_html .= '<a href="' . get_term_link($category->term_id, 'job_category') . '" title="' . esc_attr(sprintf(__("View all jobs in: &ldquo;%s&rdquo;", 'jmcore'), $category->name)) . '">' . ' ' . $category->name . '</a>' . $separator;
                            }
                            if($is_can_view == false){
                                $categories_html = '**********';
                            }
                            $schema = $args['schema'] ? ' itemprop="occupationalCategory"' : '';
                            $html[] = '<span class="job-category"' . $schema . '>';
                            $html[] = '<i class="' . $icon . '"></i>';
                            $html[] = trim($categories_html, $separator);
                            $html[] = '</span>';
                        }
                    } elseif ($field_id == 'job_date') {
                        $html[] = '<span class="job-date">';
                        $html[] = '<time class="entry-date" datetime="' . esc_attr(get_the_date('c', $job_id)) . '">';
                        $html[] = '<i class="fa fa-calendar-o" aria-hidden="true"></i>';
                        $schema = $args['schema'] ? ' itemprop="datePosted"' : '';
                        $html[] = '<span' . $schema . '>';
                        $html[] = esc_html(get_the_date(get_option('date_format'), $job_id));
                        $html[] = '</span>';

                        $separator = ' - ';
                        if (in_array('job_closing', $fields)) {
                            $closing_date = noo_get_post_meta($job_id, 'job_closing', '');
                            $closing_date = is_numeric($closing_date) ? $closing_date : strtotime($closing_date);
                            if (!empty($closing_date)) {
                                $schema = $args['schema'] ? ' itemprop="validThrough"' : '';
                                $html[] = '<span ' . $schema . '>';
                                $html[] = $separator . esc_html(date_i18n(get_option('date_format'), $closing_date));
                                $html[] = '</span>';
                            }
                        }
                        $html[] = '</time>';
                        $html[] = '</span>';
                    } elseif ($field_id == 'job_closing') {
                        if (in_array('job_date', $fields)) {
                            continue;
                        } else {
                            $closing_date = noo_get_post_meta($job_id, 'job_closing', '');
                            if($is_can_view == false){
                                $closing_date = '**********';
                            }
                            if (!empty($closing_date)) {
                                $html[] = '<span class="job-date">';
                                $html[] = '<time class="entry-date" datetime="' . esc_attr(get_the_date('c', $job_id)) . '">';
                                $html[] = '<i class="' . $icon . '"></i>';
                                $html[] = '<span>';
                                $closing_date = is_numeric($closing_date) ? $closing_date : strtotime($closing_date);
                                $html[] = esc_html(date_i18n(get_option('date_format'), $closing_date));
                                $html[] = '</span>';
                                $html[] = '</time>';
                                $html[] = '</span>';
                            }
                        }
                    } else {
                        $field = jm_get_job_field($field_id);
                        if (empty($field)) {
                            continue;
                        }

                        if (isset($field['is_default'])) {
                            if (isset($field['is_tax'])) {
                                continue;
                            }
                            if ($field['name'] == 'job_closing') // reserve the _closing field
                            {
                                continue;
                            }
                        }
                        $id = jm_job_custom_fields_name($field['name'], $field);
                        $value = get_post_meta(get_the_ID(), $id, true);
                        $value = noo_convert_custom_field_value($field, $value);
                        if($is_can_view == false){
                            $value = '**********';
                        }
                        $custom_date = noo_get_post_meta($job_id, '_noo_job_field__customdate', '');
                        $date_format = esc_html(date_i18n(get_option('date_format'), strtotime($custom_date)));
                        if ($field['type'] == 'datepicker') {
                            $date = date($date_format, strtotime($value));
                        }
                        if (!empty($date)) {
                            $html[] = '<span class="job-' . $field['name'] . '">';
                            $html[] = '<i class="' . $icon . '"></i>';
                            $html[] = is_array($date) ? implode(', ', $date) : $date;
                            $html[] = '</span>';
                        }elseif($field_id == 'job_salary') {
                            $min = noo_get_post_meta(get_the_ID(), $id . '_min', '');
                            $max = noo_get_post_meta(get_the_ID(), $id . '_max', '');
                            $united = get_post_meta(get_the_ID(), $id, true);
                            $unit = isset($field['value']) && !empty($field['value']) ? explode("\n", $field['value']) : '';

                            $united = $unit[$united];
                            $value = $min . $united . ' - ' . $max . $united;
                            $html[] = '<span class="job-salary">';
                            $html[] = '<i class="' . $icon . '"></i>';
                            // $html[] = '<em>' . $field['label'] . ': </em>';
                            $html[] = is_array($value) ? implode(', ', $value) : $value;
                            $html[] = '</span>';
                        }elseif (!empty($value)) {
                            $html[] = '<span class="job-' . $field['name'] . '">';
                            $html[] = '<i class="' . $icon . '"></i>';
                            $html[] = is_array($value) ? implode(', ', $value) : $value;
                            $html[] = '</span>';
                        }
                    }
                }
            }
        }

        do_action('job_list_after_meta');

        echo implode("\n",$html);
    }
endif;

if (!function_exists('jm_the_job_tag')) :
    function jm_the_job_tag($job = null)
    {
        if (empty($job) || !is_object($job)) {
            $job = get_post(get_the_ID());
        }
        $job_id = $job->ID;
        $html = array();

        $tags = get_the_terms($job_id, 'job_tag');
        if (!empty($tags)) {
            $html[] = '<div class="entry-tags pt25 pb25">';
            $html[] = '<span><i class="fa fa-tag"></i>Tags:</span>';
            foreach ($tags as $tag) {
                $html[] = '<a href="' . get_term_link($tag->term_id, 'job_tag') . '" title="' . esc_attr(sprintf(__("View all jobs in: &ldquo;%s&rdquo;", 'jmcore'), $tag->name)) . '">' . ' ' . $tag->name . '</a>';
            }
            $html[] = '</div>';
        }

       echo implode("\n",$html);
    }
endif;

if (!function_exists('jm_the_job_social')) :
    function jm_the_job_social($job_id = null, $title = '')
    {
        if (!noo_get_option('noo_job_social', true)) {
            return;
        }

        $job_id = (null === $job_id) ? get_the_ID() : $job_id;
        if (get_post_type($job_id) != 'noo_job') {
            return;
        }

        $facebook = noo_get_option('noo_job_social_facebook', true);
        $twitter = noo_get_option('noo_job_social_twitter', true);
        $google = noo_get_option('noo_job_social_google', true);
        $pinterest = noo_get_option('noo_job_social_pinterest', false);
        $linkedin = noo_get_option('noo_job_social_linkedin', false);
        $email = noo_get_option('noo_job_social_email', false);

        $share_url = urlencode(get_permalink());
        $share_title = urlencode(get_the_title());
        $share_source = urlencode(get_bloginfo('name'));
        // $share_content = urlencode( get_the_content() );
        $thumbnail_id = noo_get_post_meta($job_id, 'cover_image', '');

        if (empty($thumbnail_id)) {
            $company_id = jm_get_job_company($job_id);
            $thumbnail_id = noo_get_post_meta($company_id, 'logo', '');
        }
        $share_media = !empty($thumbnail_id) ? wp_get_attachment_url($thumbnail_id, 'full') : '';

        $popup_attr = 'resizable=0, toolbar=0, menubar=0, status=0, location=0, scrollbars=0';

        $html = array();

        if ($facebook || $twitter || $google || $pinterest || $linkedin || $email) {
            $html[] = '<div class="job-social clearfix b-dashed-hv">';
            $html[] = '<h4 class="noo-social-title">';
            $html[] = empty($title) ? esc_html__("Share this job", 'jmcore') : $title;
            $html[] = '</h4>';
            if ($facebook) {
                $html[] = '<a href="#share" class="noo-icon "' . ' title="' . esc_html__('Share on Facebook', 'jmcore') . '"' . ' onclick="window.open(' . "'http://www.facebook.com/sharer.php?u={$share_url}&amp;t={$share_title}','popupFacebook','width=650,height=270,{$popup_attr}');" . ' return false;">';
                $html[] = noo_get_social_network('facebook');
                $html[] = '</a>';
            }

            if ($twitter) {
                $html[] = '<a href="#share" class="noo-icon "' . ' title="' . esc_html__('Share on Twitter', 'jmcore') . '"' . ' onclick="window.open(' . "'https://twitter.com/intent/tweet?text={$share_title}&amp;url={$share_url}','popupTwitter','width=500,height=370,{$popup_attr}');" . ' return false;">';
                $html[] = noo_get_social_network('twitter');
                $html[] = '</a>';
            }

            if ($google) {
                $html[] = '<a href="#share" class="noo-icon"' . ' title="' . esc_html__('Share on Google+', 'jmcore') . '"' . ' onclick="window.open(' . "'https://plus.google.com/share?url={$share_url}','popupGooglePlus','width=650,height=226,{$popup_attr}');" . ' return false;">';
                $html[] = noo_get_social_network('google-plus');
                $html[] = '</a>';
            }

            if ($pinterest) {
                $html[] = '<a href="#share" class="noo-icon"' . ' title="' . esc_html__('Share on Pinterest', 'jmcore') . '"' . ' onclick="window.open(' . "'http://pinterest.com/pin/create/button/?url={$share_url}&amp;media={$share_media}&amp;description={$share_title}','popupPinterest','width=750,height=265,{$popup_attr}');" . ' return false;">';
                $html[] = noo_get_social_network('pinterest');
                $html[] = '</a>';
            }

            if ($linkedin) {
                $html[] = '<a href="#share" class="noo-icon"' . ' title="' . esc_html__('Share on LinkedIn', 'jmcore') . '"' . ' onclick="window.open(' . "'http://www.linkedin.com/shareArticle?mini=true&amp;url={$share_url}&amp;title={$share_title}&amp;source={$share_source}','popupLinkedIn','width=610,height=480,{$popup_attr}');" . ' return false;">';
                $html[] = noo_get_social_network('linkedin');
                $html[] = '</a>';
            }

            if ($email) {
                $html[] = '<a href="mailto:?subject=' . $share_title . '&amp;body=' . $share_url . '" class="noo-icon "' . ' title="' . esc_html__('Share on email', 'jmcore') . '">';
                $html[] = noo_get_social_network('email');
                $html[] = '</a>';
            }

            $html[] = '</div>'; // .noo-social.social-share
        }

        echo implode("\n", $html);
    }
endif;

if (!function_exists('jm_related_jobs')) :
    function jm_related_jobs($job_id, $title = '')
    {
        global $wp_query;
        //  -- args query

        $args = array(
            'post_type' => 'noo_job',
            'post_status' => 'publish',
            'posts_per_page' => (int)noo_get_option('noo_job_related_num', 8),
            'post__not_in' => array($job_id),
        );

        //  -- tax_query

        $job_categorys = get_the_terms($job_id, 'job_category');
        $job_types = get_the_terms($job_id, 'job_type');
        $job_locations = get_the_terms($job_id, 'job_location');

        $args['tax_query'] = array('relation' => 'AND');
        if ($job_categorys) {
            $term_job_category = array();
            foreach ($job_categorys as $job_category) {
                $term_job_category = array_merge($term_job_category, (array)$job_category->slug);
            }
            $args['tax_query'][] = array(
                'taxonomy' => 'job_category',
                'field' => 'slug',
                'terms' => $term_job_category,
            );
        }

        if ($job_types) {
            $term_job_type = array();
            foreach ($job_types as $job_type) {
                $term_job_type = array_merge($term_job_type, (array)$job_type->slug);
            }
            $args['tax_query'][] = array(
                'taxonomy' => 'job_type',
                'field' => 'slug',
                'terms' => $term_job_type,
            );
        }

        if ($job_locations) {
            $term_job_location = array();
            foreach ($job_locations as $job_location) {
                $term_job_location = array_merge($term_job_location, (array)$job_location->slug);
            }
            $args['tax_query'][] = array(
                'taxonomy' => 'job_location',
                'field' => 'slug',
                'terms' => $term_job_location,
            );
        }

        // --- new query
        $wp_query = new WP_Query($args);

        $loop_args = array(
            'title' => $title,
            'paginate' => null,
            'class' => 'related-jobs hidden-print',
            'item_class' => '',
            'query' => $wp_query,
            'pagination' => false,
            'ajax_item' => null,
            'no_content' => 'none',
            'display_style' => 'list',
            'related_job' => true,
        );

        jm_job_loop($loop_args);
    }
endif;

if (!function_exists('noo_job_list_display_type')) :

    function noo_job_list_display_type()
    {

        $arr_type = array('list', 'grid');

        $defaut = noo_get_option('noo_jobs_display_type', 'list');

        $type = isset($_GET['display']) && in_array($_GET['display'], $arr_type) ? $_GET['display'] : $defaut;

        return $type;
    }

endif;

if (!function_exists('noo_share_social')) :
    function noo_share_social($post_id = null)
    {

        $facebook = noo_get_option('noo_job_social_facebook', true);
        $twitter = noo_get_option('noo_job_social_twitter', true);
        $google = noo_get_option('noo_job_social_google', true);
        $pinterest = noo_get_option('noo_job_social_pinterest', false);
        $linkedin = noo_get_option('noo_job_social_linkedin', false);
        $email = noo_get_option('noo_job_social_email', false);

        $share_url = urlencode(get_permalink());
        $share_title = urlencode(get_the_title());
        $share_source = urlencode(get_bloginfo('name'));

        $thumbnail_id = noo_get_post_meta($post_id, 'cover_image', '');

        if (empty($thumbnail_id)) {
            $company_id = jm_get_job_company($post_id);
            $thumbnail_id = noo_get_post_meta($company_id, 'logo', '');
        }
        $share_media = !empty($thumbnail_id) ? wp_get_attachment_url($thumbnail_id) : '';

        $popup_attr = 'resizable=0, toolbar=0, menubar=0, status=0, location=0, scrollbars=0';

        $html = array();

        if ($facebook || $twitter || $google || $pinterest || $linkedin || $email) {
            $html[] = '<div class="noo-social-share transition300">';
            if ($facebook) {
                $html[] = '<a href="#share" class="noo-icon fa fa-facebook b-all m3 br3"' . ' title="' . esc_html__('Share on Facebook', 'jmcore') . '"' . ' onclick="window.open(' . "'http://www.facebook.com/sharer.php?u={$share_url}&amp;t={$share_title}','popupFacebook','width=650,height=270,{$popup_attr}');" . ' return false;">';
                $html[] = '</a>';
            }

            if ($twitter) {
                $html[] = '<a href="#share" class="noo-icon fa fa-twitter b-all m3 br3"' . ' title="' . esc_html__('Share on Twitter', 'jmcore') . '"' . ' onclick="window.open(' . "'https://twitter.com/intent/tweet?text={$share_title}&amp;url={$share_url}','popupTwitter','width=500,height=370,{$popup_attr}');" . ' return false;">';
                $html[] = '</a>';
            }

            if ($google) {
                $html[] = '<a href="#share" class="noo-icon fa fa-google-plus b-all m3 br3"' . ' title="' . esc_html__('Share on Google+', 'jmcore') . '"' . ' onclick="window.open(' . "'https://plus.google.com/share?url={$share_url}','popupGooglePlus','width=650,height=226,{$popup_attr}');" . ' return false;">';
                $html[] = '</a>';
            }

            if ($pinterest) {
                $html[] = '<a href="#share" class="noo-icon fa fa-pinterest b-all m3 br3"' . ' title="' . esc_html__('Share on Pinterest', 'jmcore') . '"' . ' onclick="window.open(' . "'http://pinterest.com/pin/create/button/?url={$share_url}&amp;media={$share_media}&amp;description={$share_title}','popupPinterest','width=750,height=265,{$popup_attr}');" . ' return false;">';
                $html[] = '</a>';
            }

            if ($linkedin) {
                $html[] = '<a href="#share" class="noo-icon fa fa-linkedin b-all m3 br3"' . ' title="' . esc_html__('Share on LinkedIn', 'jmcore') . '"' . ' onclick="window.open(' . "'http://www.linkedin.com/shareArticle?mini=true&amp;url={$share_url}&amp;title={$share_title}&amp;source={$share_source}','popupLinkedIn','width=610,height=480,{$popup_attr}');" . ' return false;">';
                $html[] = '</a>';
            }

            if ($email) {
                $html[] = '<a href="mailto:?subject=' . $share_title . '&amp;body=' . $share_url . '" class="noo-icon fa fa-envelope-o b-all m3 br3"' . ' title="' . esc_html__('Share on email', 'jmcore') . '">';
                $html[] = '</a>';
            }

            $html[] = '</div>'; // .noo-social.social-share
        }

        echo implode("\n", $html);
    }
endif;
if (!function_exists('noo_job_list_before')) {
    function noo_job_list_before()
    {
        noo_get_layout('job/job_archive_before');
    }
}
if(!function_exists('noo_job_list_customRSS')){
    function noo_job_list_customRSS(){
        noo_get_layout('job/job_feed');
    }
}

if (!function_exists('noo_job_featured_field')) {
    function noo_job_featured_field(){
        $layout =  noo_get_option('noo_job_detail_layout','style-1');
        
        $template = get_post_meta(get_the_ID(),'_job_detail_templates',true);
        $template = is_array($template) ? implode('',$template) : $template;
        $layout = (!empty( $template)) ? $template : $layout;
        $layout = !empty( $_GET['layout'] ) ? sanitize_text_field( $_GET['layout'] ) : $layout;

        $settings_fields = get_theme_mod('noo_jobs_detail_fields','');
        $settings_fields = !is_array($settings_fields) ? explode(',', $settings_fields) : $settings_fields;
        $fields = jm_get_job_custom_fields();
        $user_per = noo_get_user_permission();
        $current_user_role = Noo_Member::get_user_role(get_current_user_id());
        if(!empty($fields)) {
            $html = array();
            $field_skipped = 0;
            foreach ( $fields as $field ) {
                if( $field['name'] == 'job_closing' ) // reserve the _closing field
                    continue;
                if( $field['name'] == 'cover_image' ) // reserve the _closing field
                    continue;
                if( $field['name'] == 'full_address' ) // reserve the _closing field
                    continue;
                if( $field['type'] == 'embed_video' ) // reserve the _closing field
                    continue;
                if( $field['type'] == 'image_gallery' ) // reserve the _closing field
                    continue; 
                if( $field['type'] == 'single_image' ) // reserve the _closing field
                    continue;  
                  
                 if(in_array($field['name'], $settings_fields)){

                     $id = jm_job_custom_fields_name($field['name'], $field);
                 
                    if( isset( $field['is_tax'] ) ) {
                        $value = jm_job_get_tax_value();
                        $value = implode( ',', $value );
                    } else {
                        $value = noo_get_post_meta(get_the_ID(), $id, '');
                    }
                    $icon = isset($field['icon']) ? $field['icon'] : '';
                    $icon_class = str_replace("|", " ", $icon);
                    $current_user_id = get_current_user_id();
                    $permission = isset($field['permission']) ? $field['permission'] : '';
                    $is_can_view = false;
                    if (empty($permission) or 'public' == $permission or $user_per == 'candidate_with_package' or $user_per=='true' or 'administrator' == $current_user_role) {
                        $is_can_view = true;
                    } elseif($permission ==  $user_per){
                        $is_can_view = true;
                    }

                    if ($is_can_view== false) {
                        $field_skipped++;
                        continue;
                    }
                    if ( $value != '' ) { 

                        if ( $layout == 'style-1' || $layout == 'style-4' || $layout == 'style-6'):

                            $html[] = '<div class="col-ov noo-grid-item">' . noo_display_field( $field, $id, $value, array( 'label_tag' => 'h5', 'label_class' => '', 'value_tag' => 'span' ), false) . '</div>';

                        elseif ($layout == 'style-7'  ):

                                $html[] = '<li class="b-b p25 col-md-12 col-sm-6 col-xs-12 b-shadow ">' . noo_display_field( $field, $id, $value, array( 'label_tag' => 'h6', 'label_class' => '', 'value_tag' => 'span' ), false) . '</li>';

                        elseif ( $layout == 'style-5' ||  $layout == 'style-2' || $layout == 'style-3' || $layout == 'style-8') :

                                $html[] = '<li class=" col-md-12 col-sm-6 col-xs-12 "><i class="'.$icon_class.'"></i><div class="ov-label">' . noo_display_field( $field, $id, $value, array( 'label_tag' => 'h5', 'label_class' => '', 'value_tag' => 'span' ), false) . '</div></li>';
                        endif;
                    }
                }    
            }
            if( !empty( $html ) && count( $html ) > 0 ) :
                   $border_class =$grid_class= '';
                if($layout=='style-2' || $layout == 'style-3' || $layout == 'style-8'  || $layout == 'style-5'){
                    $border_class = 'b-dashed-hv';
                }
                if ( $layout == 'style-1' || $layout == 'style-4' || $layout == 'style-6'){
                    $grid_class = 'noo-desktop-3 noo-tablet-2 noo-mobile-1' ;
                }
                ?>
                <div class="job-featured-fields <?php echo esc_attr($border_class).' '.esc_attr($grid_class);?> transition300">
                        <?php if($layout == 'style-1' || $layout == 'style-4' || $layout == 'style-6'):  ?>
                            <?php echo implode("\n", $html); ?>
                        <?php elseif( $layout == 'style-7' ): ?>
                        <ul class="list-ov b-all">
                            <?php echo implode("\n", $html); ?>
                        </ul>
                        <?php elseif( $layout == 'style-5'|| $layout == 'style-2' || $layout == 'style-3' || $layout == 'style-8'): ?>
                        <ul class="list-ov-2 p15">
                            <?php echo implode("\n", $html); ?>
                        </ul>
                        <div class="cs_field_show_more  arrow_carrot-down b-all"></div>
                        <?php endif; ?>
                </div>
            <?php endif;
        }
    }
}