<?php

if ( ! function_exists( 'jm_action_control_admin_init' ) ) :
	function jm_action_control_admin_init() {
		register_setting( 'jm_action_control', 'jm_action_control' );
	}

	add_filter( 'admin_init', 'jm_action_control_admin_init' );
endif;

if ( ! function_exists( 'jm_get_action_list' ) ) :
	function jm_get_action_list() {
		$default_post_job = defined( 'WOOCOMMERCE_VERSION' ) ? 'package' : 'employer';
		$actions          = array(
			'post_job'               => array(
				'label'   => esc_html__( 'Post Job', 'jmcore' ),
				'default' => $default_post_job,
				'options' => array(
					'employer' => esc_html__( 'Employers', 'jmcore' ),
					'package'  => esc_html__( 'Employers with Paid Packages', 'jmcore' ),
				),
			),
            'complete_profile_pre_post_job' =>array(
                 'label'    => esc_html__('Require complete profile before posting job or resume', 'jmcore'),
                 'default'  => 'disable',
                 'options'  => array(
                     'enable'   => esc_html__('Enable', 'jmcore'),
                     'disable'  => esc_html__('Disable', 'jmcore'),
                 ),
            ),
            'view_and_search_resume' => array(
                'label' => esc_html__('View and Search Resume Listing', 'jmcore'),
                'default' => 'public',
                'options' => array(
                    'public' => esc_html__('Public', 'jmcore'),
                    'user' => esc_html__('Logged-in User', 'jmcore'),
                    'employer' => esc_html__('Employers', 'jmcore'),
                    'package' => esc_html__('Employers with Paid Package', 'jmcore'),
                ),
            ),
			'view_resume'            => array(
				'label'   => esc_html__( 'View Resume Details', 'jmcore' ),
				'default' => 'employer',
				'options' => array(
					'public'   => esc_html__( 'Public', 'jmcore' ),
					'user'     => esc_html__( 'Logged-in Users', 'jmcore' ),
					'employer' => esc_html__( 'Employers', 'jmcore' ),
					'package'  => esc_html__( 'Employers with Paid Packages', 'jmcore' ),
				),
                'desc'    => esc_html__('In all cases, users who have viewed the resume can review it ')
			),
			'enable_block_company' => array(
			        'label'  => esc_html__('Enable Block Company', 'jmcore'),
                'default' => 'enable',
                'options' => array(
                    'enable'  => esc_html__( 'Enable', 'jmcore' ),
                    'disable' => esc_html__( 'Disable', 'jmcore' ),
                ),
                'desc'   => esc_html__('This feature is used when the user chooses to view the details resume as the employer or employer with the package ', 'jmcore')
            ),

			'view_candidate_contact' => array(
				'label'   => esc_html__( 'View Candidate Contact', 'jmcore' ),
				'default' => '',
				'options' => array(
					''         => esc_html__( 'All who can View Resume', 'jmcore' ),
					'public'   => esc_html__( 'Public', 'jmcore' ),
					'employer' => esc_html__( 'Employers', 'jmcore' ),
					'package'  => esc_html__( 'Employers with Paid Packages', 'jmcore' ),
					'none'    => esc_html__( 'Private', 'jmcore' ),
				),
				'desc'    => esc_html__( 'In any case, employers who received resumes from applications can view contact information.', 'jmcore' ),
			),
			'post_resume'            => array(
				'label'   => esc_html__( 'Post Resume', 'jmcore' ),
				'default' => 'candidate',
				'options' => array(
					'candidate' => esc_html__( 'Candidates', 'jmcore' ),
					'package'   => esc_html__( 'Candidates with Paid Packages', 'jmcore' ),
				),
			),
			'view_job'               => array(
				'label'   => esc_html__( 'View Job Details', 'jmcore' ),
				'default' => 'public',
				'options' => array(
					'public'    => esc_html__( 'Public', 'jmcore' ),
					'user'      => esc_html__( 'Logged-in Users', 'jmcore' ),
					'candidate' => esc_html__( 'Candidates', 'jmcore' ),
					'package'   => esc_html__( 'Candidates with Paid Packages', 'jmcore' ),
				),
			),
			'follow'                 =>array(
			    'label'     => esc_html__('Who can Follow Employer?', 'jmcore'),
                'default'   =>'public',
                'options'   => array(
                    'public'    => esc_html__('Both Employer & Candidate', 'jmcore'),
                    'employer'  => esc_html__('Only Employer', 'jmcore'),
                    'candidate' => esc_html__('Only Candidate', 'jmcore'),
                    'disable'   => esc_html__('Disable Follow', 'jmcore'),
                ),

            ),
			'shortlist'              =>array(
			    'label'     => esc_html__('Who can Shortlist Resume?'),
                'default'   =>'public',
                'options'   =>array(
                    'public'    => esc_html__('Both Employer & Candidate', 'jmcore'),
                    'employer'  => esc_html__('Only Employer ', 'jmcore'),
                    'candidate' => esc_html__('Only Candidate ', 'jmcore'),
                    'disable'   => esc_html__('Disable Shortlist', 'jmcore')
                ),
            ),
			'apply_job'              => array(
				'label'   => esc_html__( 'Apply Job', 'jmcore' ),
				'default' => 'public',
				'options' => array(
					'public'    => esc_html__( 'Public', 'jmcore' ),
					'candidate' => esc_html__( 'Candidates', 'jmcore' ),
					'package'   => esc_html__( 'Candidates with Paid Packages', 'jmcore' ),
				),
			),
			'bookmark_job'           => array(
				'label'   => esc_html__( 'Bookmark Job', 'jmcore' ),
				'default' => 'enable',
				'options' => array(
					'enable'  => esc_html__( 'Enable', 'jmcore' ),
					'disable' => esc_html__( 'Disable', 'jmcore' ),
				),
			),

		);

		return apply_filters( 'jm_action_control_list', $actions );
	}
endif;

if ( ! function_exists( 'jm_get_action_control' ) ) :
	function jm_get_action_control( $action = '' ) {
		$actions = jm_get_action_list();
		if ( ! array_key_exists( $action, $actions ) ) {
			return null;
		}

		return jm_get_setting( 'jm_action_control', $action, $actions[ $action ][ 'default' ] );
	}
endif;

if ( ! function_exists( 'jm_action_control_settings_tabs' ) ) :
	function jm_action_control_settings_tabs( $tabs = array() ) {
		$index  = 0; //array_search('job_package', array_keys( $tabs ) ) + 1;
		$before = array_slice( $tabs, 0, $index );
		$after  = array_slice( $tabs, $index );

		$action_control_tab = array( 'action_control' => esc_html__( 'Action Control', 'jmcore' ) );

		return array_merge( $before, $action_control_tab, $after );
	}

	add_filter( 'noo_job_settings_tabs_array', 'jm_action_control_settings_tabs', 99 );
endif;

if ( ! function_exists( 'jm_action_control_setting_form' ) ) :
	function jm_action_control_setting_form() {
		jm_action_control_correct_settings();
		$actions = jm_get_action_list();

		?>
		<?php settings_fields( 'jm_action_control' ); ?>
		<h3><?php echo esc_html__( 'Action and Permissions', 'jmcore' ) ?></h3>
		<p><?php echo esc_html__( 'This page consists of setting related to the main actions of users on your site. Depending on the actions, you can select if the user is allowed freely or require purchasing the packages.', 'jmcore' ); ?></p>
		<p><?php echo esc_html__( 'With action requires buying packages, you will see proper settings on the package product edit page.', 'jmcore' ); ?></p>
		<table class="form-table" cellspacing="0">
			<tbody>
			<?php if ( ! empty( $actions ) ) : foreach ( $actions as $key => $action ) : ?>
				<tr>
					<th>
						<?php echo $action[ 'label' ]; ?>
					</th>
					<td>
						<select name="jm_action_control[<?php echo $key; ?>]">
							<?php $setting = jm_get_action_control( $key ); ?>
							<?php foreach ( $action[ 'options' ] as $opt_key => $opt_label ) : ?>
								<option <?php selected( $setting, $opt_key ); ?>
									value="<?php echo $opt_key; ?>"><?php echo $opt_label; ?></option>
							<?php endforeach; ?>
						</select>
						<?php if ( isset( $action[ 'desc' ] ) ) : ?>
							<p><?php echo $action[ 'desc' ]; ?></p>
						<?php endif; ?>
					</td>
				</tr>
			<?php endforeach; endif; ?>
            <tr>
                <th>
                    <?php esc_html_e('Limit field select for Multi Select field', 'jmcore') ?>
                </th>
                <td>
                    <?php $limit_multi_select_field = jm_get_setting( 'jm_action_control','limit_multi_select_field',5);
                    ?>
                    <input type="number" name="jm_action_control[limit_multi_select_field]"
                           value="<?php echo($limit_multi_select_field ? $limit_multi_select_field : '5') ?>">
                    <p>
                        <small><?php echo esc_html__('Limit the number of selected options.') ?></small>
                    </p>
                </td>
            </tr>
			</tbody>
		</table>
		<?php
	}

	add_action( 'noo_job_setting_action_control', 'jm_action_control_setting_form' );
endif;

if ( ! function_exists( 'jm_action_control_correct_settings' ) ) :
	function jm_action_control_correct_settings() {
		if ( $action_settings = jm_get_setting( 'jm_action_control' ) ) {
			return;
		}
		$default_post_job = defined( 'WOOCOMMERCE_VERSION' ) ? 'package' : 'employer';
		if ( $setting = jm_get_job_setting( 'job_posting_mode' ) ) {
			$default_post_job = ( $setting == 'woo' ) ? 'package' : 'employer';
		}
		$default_view_resume = 'employer';
		if ( $setting = jm_get_resume_setting( 'can_view_resume' ) ) {
			$default_view_resume = ( $setting == 'premium_package' ) ? 'package' : $setting;
		}
		$default_view_candidate = '';
		if ( $setting = jm_get_resume_setting( 'can_view_candidate_contact' ) ) {
			$default_view_candidate = ( $setting == 'premium_package' ) ? 'package' : $setting;
		}
		$default_post_resume = 'candidate';
		if ( $setting = jm_get_resume_setting( 'resume_posting_mode' ) ) {
			$default_post_resume = ( $setting == 'woo' ) ? 'package' : 'candidate';
		}
		$default_apply_job = 'public';
		if ( $setting = jm_get_application_setting( 'member_apply' ) ) {
			$default_apply_job = 'candidate';
		}
		$action_settings = array(
			'post_job'               => $default_post_job,
			'view_resume'            => $default_view_resume,
			'view_candidate_contact' => $default_view_candidate,
			'post_resume'            => $default_post_resume,
			'view_job'               => 'public',
			'apply_job'              => $default_apply_job,
			'view_company_contact'   => '',
		);

		update_option( 'jm_action_control', $action_settings );
	}
endif;