<?php

if ( ! function_exists( 'jm_get_company_default_fields' ) ) :
	function jm_get_company_default_fields() {
		$default_fields = array(
			'logo'        => array(
				'name'       => 'logo',
				'label'      => esc_html__( 'Company Logo', 'jmcore' ),
				'type'       => 'single_image',
				'value'      => esc_html__( 'Recommend size: 160x160px', 'jmcore' ),
				'allowed_type' => array(
					'single_image' => esc_html__( 'Single Image', 'jmcore' ),
				),
				'is_default' => true,
				'required'   => false
			),
			'cover_image' => array(
				'name'       => 'cover_image',
				'label'      => esc_html__( 'Company Cover Image', 'jmcore' ),
				'type'       => 'single_image',
				'value'      => esc_html__( 'Recommend size: 1400x600px', 'jmcore' ),
				'allowed_type' => array(
					'single_image' => esc_html__( 'Single Image', 'jmcore' ),
				),
				'is_default' => true,
				'required'   => false
			),
			'portfolio' => array(
				'name'       => 'portfolio',
				'label'      => esc_html__( 'Portfolio', 'jmcore' ),
				'type'       => 'image_gallery',
				'value'      => esc_html__( 'Recommend size: 145x180px', 'jmcore' ),
				'allowed_type' => array(
					'image_gallery' => esc_html__( 'Image Gallery', 'jmcore' ),
				),
				'is_default' => true,
				'required'   => false
			),
            'job_category' => array(
                'name' => 'job_category',
                'label' => esc_html__('Category', 'jmcore'),
                'type' => 'multiple_select',
                'allowed_type' => array(
                    'select'			=> esc_html__('Select', 'jmcore'),
                    'multiple_select'	=> esc_html__( 'Multiple Select', 'jmcore' ),
                ),
                'value' => '',
                'std' => '',
                'is_default' => true,
                'is_tax' => true,
                'required' => true
            ),
			'slogan' => array(
				'name'       => 'slogan',
				'label'      => esc_html__( 'Slogan', 'jmcore' ),
				'type'       => 'text',
			),
			'location'     => array(
				'name'         => 'location',
				'label'        => esc_html__( 'Location', 'jmcore' ),
				'type'         => 'single_tax_location_input',
				'allowed_type' => array(
					'single_tax_location_input' => esc_html__( 'Single Location with Input', 'jmcore' ),
					'single_tax_location'       => esc_html__( 'Single Location', 'jmcore' ),
				),
				'value'        => '',
				'is_default'   => true,
				'required'     => true
			),
			'full_address'     => array(
				'name'         => 'full_address',
				'label'        => esc_html__( 'Full Address', 'jmcore' ),
				'type'         => 'location_picker',
				'is_tax' => true,
				'allowed_type' => array(
					'location_picker' => esc_html__( 'Location Picker', 'jmcore' ),
				),
				'value'        => '',
				'is_default'   => true,
				'required'     => true
			),
		);

		return apply_filters( 'jm_company_default_fields', $default_fields );
	}
endif;

if ( ! function_exists( 'jm_company_location_field_params' ) ) :
	function jm_company_location_field_params( $args = array(), $company_id = 0 ) {
		extract( $args );
		$location_tax_field_types = array(
			'company_location',
			'single_tax_location',
			'single_tax_location_input',
			'multi_tax_location',
			'multi_tax_location_input'
		);
		if ( in_array( $field['type'], $location_tax_field_types ) ) {
			$field_id = $field['name'];

			$field_value = array();
			$terms       = get_terms( 'job_location', array( 'hide_empty' => 0 ) );
			foreach ( $terms as $term ) {
				$field_value[] = $term->term_id . '|' . $term->name;
			}
			$field['value']        = $field_value;
			$field['no_translate'] = true;

			if ( ! empty( $company_id ) ) {
				$value = jm_resume_get_tax_value( $company_id, $field_id );
			}
		}

		return compact( 'field', 'field_id', 'value' );
	}

	add_filter( 'jm_company_render_form_field_params', 'jm_company_location_field_params', 10, 2 );
endif;

if ( ! function_exists( 'jm_location_render_field_tax_location' ) ) :
	function jm_location_render_field_tax_location( $field = array(), $field_id = '', $value = array(), $form_type = '', $object = array() )
    {
        $allow_user_input = strpos($field['type'], 'input') !== false || $field['type'] == 'company_location';

        $field['type'] = (strpos($field['type'], 'single') !== false || $field['type'] == 'company_location') ? 'select' : 'multiple_select';
        if ($field['name'] == 'location') {

            $company_id = jm_get_employer_company();

            $selected = array();
            // if ($company_id) {
            //     $selected = get_post_meta($company_id, 'location', true);
            //     $selected = json_decode($selected);
            // }
            $selected = isset($_GET[$field_id]) ? $_GET[$field_id] : '';
            $location_args = array(
                'hide_empty' => 0,
                'echo' => 1,
                'selected' => $selected,
                'hierarchical' => 1,
                'name' => $field_id,
                'id' => 'noo-field-job_location',
                'class' => 'form-control noo-select form-control-chosen',
                'depth' => 0,
                'taxonomy' => 'job_location',
                'value_field' => 'term_id',
                'walker' => new Noo_Walker_TaxonomyDropdown(),
            ); ?>
            <?php 
            $label = isset( $field['label_translated'] ) ? $field['label_translated'] : $field['label'];
            $location_args['show_option_none'] = sprintf(esc_html__('All %s', 'noo'), $label);
            $location_args['option_none_value'] = '';
            wp_dropdown_categories($location_args); ?>
            <?php
        } else {
            noo_render_select_field($field, $field_id, $value, $form_type);
        }
        if ($form_type != 'search' && $allow_user_input) {
            jm_job_add_new_location();
        }
    }

	add_filter( 'noo_render_field_company_location', 'jm_location_render_field_tax_location', 10, 5 );
	add_filter( 'noo_render_field_single_tax_location', 'jm_location_render_field_tax_location', 10, 5 );
	add_filter( 'noo_render_field_single_tax_location_input', 'jm_location_render_field_tax_location', 10, 5 );
	add_filter( 'noo_render_field_multi_tax_location', 'jm_location_render_field_tax_location', 10, 5 );
	add_filter( 'noo_render_field_multi_tax_location_input', 'jm_location_render_field_tax_location', 10, 5 );
endif;