<?php

if ( ! function_exists( 'jm_member_menu_admin_init' ) ) :
	function jm_member_menu_admin_init() {
		register_setting( 'jm_member_menu', 'jm_member_menu' );
	}

	add_filter( 'admin_init', 'jm_member_menu_admin_init' );
endif;

if ( ! function_exists( 'jm_get_member_menu' ) ) :
	function jm_get_member_menu( $action = '', $default = '' ) {

		return jm_get_setting( 'jm_member_menu', $action, $default );
	}
endif;

if ( ! function_exists( 'jm_member_menu_settings_tabs' ) ) :
	function jm_member_menu_settings_tabs( $tabs = array() ) {

		$temp1 = array_slice($tabs, 0, 9);
		$temp2 = array_slice($tabs, 4);

		$member_tab = array( 'member_menu' => esc_html__('Member Menu', 'jmcore') );
		return array_merge($temp1, $member_tab, $temp2);
	}

	add_filter( 'noo_job_settings_tabs_array', 'jm_member_menu_settings_tabs', 99 );
endif;

if ( ! function_exists( 'jm_member_menu_setting_form' ) ) :
	function jm_member_menu_setting_form() {
		jm_member_menu_correct_settings();

		$other_menus = jm_member_menu_other_items();

		$employer_menus = jm_member_menu_employer_items();
		$employer_menus = array_merge( $employer_menus, $other_menus );

		$candidate_menus = jm_member_menu_candidate_items();
		$candidate_menus = array_merge( $candidate_menus, $other_menus );

		$employer_menu_values    = jm_get_member_menu( 'employer_menu', array() );
		$employer_heading_values = jm_get_member_menu( 'employer_heading', array() );

		$candidate_menu_values    = jm_get_member_menu( 'candidate_menu', array() );
		$candidate_heading_values = jm_get_member_menu( 'candidate_heading', array() );

		?>
		<?php settings_fields( 'jm_member_menu' ); ?>
		<h3><?php echo esc_html__( 'Member Menu', 'jmcore' ); ?></h3>
		<p><?php echo esc_html__( 'This page allows you to set up the Member Dashboard Menu and Sub Menu.', 'jmcore' ); ?></p>
		<table class="form-table" cellspacing="0">
			<tbody>
			<tr>
				<th>
					<?php echo esc_html__( 'Employer Sub Menu', 'jmcore' ); ?>
				</th>
				<td>
					<select class="noo-admin-chosen" name="jm_member_menu[employer_menu][]" multiple="multiple"
					        style="width: 500px;max-width: 100%;">
						<?php foreach ( $employer_menus as $key => $text ) : ?>
							<option <?php selected( in_array( $key, $employer_menu_values ), true ); ?>
								value="<?php echo $key; ?>"><?php echo $text; ?></option>
						<?php endforeach; ?>
					</select>
				</td>
			</tr>
			<tr>
				<th>
					<?php echo esc_html__( 'Employer Heading Menu', 'jmcore' ); ?>
				</th>
				<td>
					<select class="noo-admin-chosen" name="jm_member_menu[employer_heading][]" multiple="multiple"
					        style="width: 500px;max-width: 100%;">
						<?php foreach ( $employer_menus as $key => $text ) : ?>
							<option <?php selected( in_array( $key, $employer_heading_values ), true ); ?>
								value="<?php echo $key; ?>"><?php echo $text; ?></option>
						<?php endforeach; ?>
					</select>
				</td>
			</tr>
			<tr>
				<th>
					<?php echo esc_html__( 'Candidate Sub Menu', 'jmcore' ); ?>
				</th>
				<td>
					<select class="noo-admin-chosen" name="jm_member_menu[candidate_menu][]" multiple="multiple"
					        style="width: 500px;max-width: 100%;">
						<?php foreach ( $candidate_menus as $key => $text ) : ?>
							<option <?php selected( in_array( $key, $candidate_menu_values ), true ); ?>
								value="<?php echo $key; ?>"><?php echo $text; ?></option>
						<?php endforeach; ?>
					</select>
				</td>
			</tr>
			<tr>
				<th>
					<?php echo esc_html__( 'Candidate Heading Menu', 'jmcore' ); ?>
				</th>
				<td>
					<select class="noo-admin-chosen" name="jm_member_menu[candidate_heading][]" multiple="multiple"
					        style="width: 500px;max-width: 100%;">
						<?php foreach ( $candidate_menus as $key => $text ) : ?>
							<option <?php selected( in_array( $key, $candidate_heading_values ), true ); ?>
								value="<?php echo $key; ?>"><?php echo $text; ?></option>
						<?php endforeach; ?>
					</select>
				</td>
			</tr>
			</tbody>
		</table>
		<?php
	}

	add_action( 'noo_job_setting_member_menu', 'jm_member_menu_setting_form' );
endif;

if ( ! function_exists( 'jm_member_menu_correct_settings' ) ) :
	function jm_member_menu_correct_settings() {
		if ( $action_settings = jm_get_setting( 'jm_member_menu' ) ) {
			return;
		}
		$default_settings = array(
			'manage-job' => 'yes',
		);

		update_option( 'jm_member_menu', $default_settings );
	}
endif;

if ( ! function_exists( 'jm_member_menu_employer_items' ) ) :

	function jm_member_menu_employer_items() {
		$menus = array(
			'manage-job'         => esc_html__( 'Manage Jobs', 'jmcore' ),
			'manage-application' => esc_html__( 'Manage Applications', 'jmcore' ),
			'viewed-resume'      => esc_html__( 'Viewed Resumes', 'jmcore' ),
			'company_profile'    => esc_html__( 'Company Profile', 'jmcore' ),
            'resume-suggest'     => esc_html__( 'Resume Suggest', 'jmcore'),
            'resume-alert'       => esc_html__( 'Resume Alerts', 'jmcore'),
		);

		return $menus;
	}

endif;

if ( ! function_exists( 'jm_member_menu_candidate_items' ) ) :

	function jm_member_menu_candidate_items() {
		$menus = array(
			'manage-resume'      => esc_html__( 'Manage Resumes', 'jmcore' ),
			'manage-job-applied' => esc_html__( 'Manage Job Applied', 'jmcore' ),
			'bookmark-job'       => esc_html__( 'Job Applied Bookmarked', 'jmcore' ),
			'job-alert'          => esc_html__( 'Manage Jobs Alert', 'jmcore' ),
			'candidate_profile'  => esc_html__( 'My Profile', 'jmcore' ),
            'job-suggest'        => esc_html__( 'Jobs Suggest', 'jmcore'),
            'block-company'      => esc_html__( 'Block Companies', 'jmcore'),
		);

		return $menus;
	}

endif;

if ( ! function_exists( 'jm_member_menu_other_items' ) ) :

	function jm_member_menu_other_items() {
		$menus = array(
			'manage-plan'   => esc_html__( 'Manage Plan', 'jmcore' ),
			'manage-follow' => esc_html__( 'Manage Follow', 'jmcore' ),
			'job-follow'    => esc_html__( 'Job Follow', 'jmcore' ),
			'shortlist'     => esc_html__( 'Shortlist', 'jmcore' ),
			'signout'       => esc_html__( 'Sign Out', 'jmcore' ),
		);

		return $menus;
	}

endif;