<?php
if( !function_exists( 'jm_get_resume_setting' ) ) :
	function jm_get_resume_setting($id = null ,$default = null){
		return jm_get_setting('noo_resume_general', $id, $default);
	}
endif;
if(!function_exists('jm_get_resume_alert_setting')):
    function jm_get_resume_alert_setting($id=null,$default =null){
        return jm_get_setting('noo_resume_alert',$id,$default);
    }
endif;
if( !function_exists( 'jm_resume_enabled' ) ) :
	function jm_resume_enabled(){
		return (bool) jm_get_resume_setting('enable_resume', 1);
	}
endif;

if( !function_exists( 'jm_get_resume_status' ) ) :
	function jm_get_resume_status() {
		return apply_filters('noo_resume_status', array(
			'draft'           => _x( 'Draft', 'Job status', 'jmcore' ),
			// 'preview'         => _x( 'Preview', 'Job status', 'jmcore' ),
			'pending'         => _x( 'Pending Approval', 'Job status', 'jmcore' ),
			'pending_payment' => _x( 'Pending Payment', 'Job status', 'jmcore' ),
			'publish'         => _x( 'Published', 'Job status', 'jmcore' ),
		));
	}
endif;

if( !function_exists( 'jm_get_allowed_file_types' ) ) :
	function jm_get_allowed_file_types( $is_display = false ) {
		$allowed_file_types = jm_get_resume_setting('extensions_upload_resume', 'doc,docx,pdf');
		$allowed_file_types = !empty( $allowed_file_types ) ? explode(',', $allowed_file_types ) : array();
		$allowed_exts = array();
		foreach ($allowed_file_types as $type) {
			$type = trim($type);
			if( empty( $type ) ) continue;

			if( $type[0] == '.' && !$is_display ) {
				$type = substr( $type, 1 );
			} elseif( $is_display ) {
				$type = '.' . $type;
			}

			$allowed_exts[] = $type;
		}

		return apply_filters( 'jm_allowed_upload_file_types', $allowed_exts );
	}
endif;

if ( ! function_exists( 'noo_resume_time_ago' ) ) :

    function noo_resume_time_ago( $resume_id = '' ) {
		if ( empty( $resume_id ) ) {
			return false;
		}
	    return sprintf( esc_html__( '% ago', 'jmcore' ), human_time_diff(get_post_time('U', false, $resume_id), current_time('timestamp')) );
    }

endif;

if ( ! function_exists( 'noo_shortlist_status' ) ) :

    function noo_shortlist_status( $resume_id, $user_id ) {

        if ( empty( $user_id ) || empty( $resume_id ) ) {
            return esc_html__( 'Save Candidate', 'jmcore' );
        }

        $list_resume_shortlist = get_user_meta( $user_id, 'list_resume_shortlist', true );

        if ( empty( $list_resume_shortlist ) || !is_array( $list_resume_shortlist ) ) {
            $list_resume_shortlist = array();
        }

        if ( in_array( $resume_id, $list_resume_shortlist ) ) {
            return esc_html__( 'Saved', 'jmcore' );
        }

        return esc_html__( 'Save Candidate', 'jmcore' );
    }

endif;

if ( ! function_exists( 'noo_shortlist_icon' ) ) :

	function noo_shortlist_icon( $resume_id, $user_id ) {

		if ( empty( $user_id ) || empty( $resume_id ) ) {
			return '<span class="icon_heart" aria-hidden="true"></span>';
		}

		$list_resume_shortlist = get_user_meta( $user_id, 'list_resume_shortlist', true );

		if ( empty( $list_resume_shortlist ) || !is_array( $list_resume_shortlist ) ) {
			$list_resume_shortlist = array();
		}

		if ( in_array( $resume_id, $list_resume_shortlist ) ) {
			return '<span aria-hidden="true" class="icon_heart"></span>';
		}

		return '<span aria-hidden="true" class="icon_heart_alt"></span>';
	}

endif;

if ( ! function_exists( 'noo_shortlist' ) ) :

    function noo_shortlist() {

	    $response = array();
	    if ( !empty( $_POST['resume_id'] ) && !empty( $_POST['user_id'] ) && !empty( $_POST['type'] ) ) {
		    $resume_id = absint( $_POST['resume_id'] );
		    $user_id = absint( $_POST['user_id'] );
		    $type = sanitize_text_field( $_POST['type'] );

		    $list_shortlist = get_post_meta( $resume_id, 'list_user_shortlist', true );
		    if ( empty( $list_shortlist ) || !is_array( $list_shortlist ) ) {
			    $list_shortlist = array();
		    }

		    $list_resume_shortlist = get_user_meta( $user_id, 'list_resume_shortlist', true );
		    if ( empty( $list_resume_shortlist ) || !is_array( $list_resume_shortlist ) ) {
			    $list_resume_shortlist = array();
		    }

		    if ( in_array( $user_id, $list_shortlist ) ) {
			    $item = array_search($user_id, $list_shortlist);
			    unset($list_shortlist[$item]);

			    update_post_meta( $resume_id, 'list_user_shortlist', $list_shortlist );

			    $item_company = array_search($resume_id, $list_resume_shortlist);
			    unset($list_resume_shortlist[$item_company]);

			    update_user_meta( $user_id, 'list_resume_shortlist', $list_resume_shortlist );

			    $response['status']  = 'success';
			    $response['message'] = esc_html__( 'You are add shortlist success', 'jmcore' );
			    $response['label'] = ($type == 'text' ? '<span class="icon_heart_alt" aria-hidden="true"></span>': '<span class="icon_heart_alt" aria-hidden="true"></span>' );
		    } else {
			    $list_shortlist = array_merge( $list_shortlist, array( $user_id ) );
			    $list_shortlist = array_unique( $list_shortlist );

			    update_post_meta( $resume_id, 'list_user_shortlist', $list_shortlist );

			    $list_resume_shortlist = array_merge( $list_resume_shortlist, array( $resume_id ) );
			    $list_resume_shortlist = array_unique( $list_resume_shortlist );

			    update_user_meta( $user_id, 'list_resume_shortlist', $list_resume_shortlist );
			    $response['status']  = 'success';
			    $response['message'] = esc_html__( 'You are add shortlist success', 'jmcore' );
			    $response['label'] = ( $type == 'text' ? '<span class="icon_heart" aria-hidden="true"></span>' : '<span class="icon_heart" aria-hidden="true"></span>' );
		    }
	    } else {
		    $response['status'] = 'error';
		    $response['message'] = esc_html__( 'Please login to add resumes shortlist.', 'jmcore' );
	    }

	    wp_send_json( $response );

    }

    add_action( 'wp_ajax_noo_shortlist', 'noo_shortlist' );
    add_action( 'wp_ajax_nopriv_noo_shortlist', 'noo_shortlist' );

endif;

if ( ! function_exists( 'noo_resume_contact' ) ) :

    function noo_resume_contact() {

	    $response = array();
	    if(isset($_POST[ 'email_rehot' ]) && !empty($_POST[ 'email_rehot' ])){
			$response[ 'status' ]  = 'error';
			$response[ 'message' ] = '<span class="error-response">' . esc_html__('You can not perform this action.', 'jmcore') . '</span>';
			wp_send_json( $response );
			die;
		}
        if (isset($_POST['name']) && empty( $_POST['name'])) {
            $response['status'] = 'error';
            $response['message'] = '<span class="error-response">' . esc_html__('Please enter your name.', 'jmcore') . '</span>';
            wp_send_json( $response );
            die;
        }
        if (isset($_POST['mail']) && empty( $_POST['mail'])) {
            $response['status'] = 'error';
            $response['message'] = '<span class="error-response">' . esc_html__('Please enter your email.', 'jmcore') . '</span>';
            wp_send_json( $response );
            die;
        } 
        if (isset($_POST['phone']) && empty( $_POST['phone'])) {
            $response['status'] = 'error';
            $response['message'] = '<span class="error-response">' . esc_html__('Please enter your phone.', 'jmcore') . '</span>';
            wp_send_json( $response );
            die;
        }
        if (isset($_POST['message']) && empty( $_POST['message'])) {
            $response['status'] = 'error';
            $response['message'] = '<span class="error-response">' . esc_html__('Please enter your message.', 'jmcore') . '</span>';
            wp_send_json( $response );
            die;
        }
        if (isset($_POST['g-recaptcha-response']) && !noo_recaptcha_verification()) {
            $response['status'] = 'error';
            $response['message'] = '<span class="error-response">' . esc_html__('Please complete the Recaptcha challenge.', 'jmcore') . '</span>';
            wp_send_json( $response );
            die;
        }
	    if ( !empty( $_POST['candidate_id'] )) {
		    $name         = sanitize_text_field( $_POST['name'] );
		    $mail         = sanitize_text_field( $_POST['mail'] );
		    $phone        = sanitize_text_field( $_POST['phone'] );
		    $message_content      = sanitize_text_field( $_POST['message'] );
		    $candidate_id = sanitize_text_field( $_POST['candidate_id'] );

		    $candidate = ! empty( $candidate_id ) ? get_userdata( $candidate_id ) : false;
		    if ( $candidate ) {
			    $email = $candidate ? $candidate->user_email : '';
			    $subject = sprintf( esc_html__( 'New message from %s', 'jmcore' ), get_bloginfo( 'name' ) );
			    $message = '';
			    $message .= sprintf( esc_html__( 'You get a contact from %s', 'jmcore' ), $name ) . '<br/><br/>';
			    $message .= sprintf( esc_html__( 'From email %s', 'jmcore' ), $mail ) . '<br/><br/>';
			    $message .= sprintf( esc_html__( 'From phone %s', 'jmcore' ), $phone ) . '<br/><br/>';
			    $message .= sprintf( esc_html__( 'Message :', 'jmcore' ) ) . '<br/><br/>';
			    $message .= $message_content . '<br/><br/>';
			    $result = noo_mail( $email, $subject, $message, array(), 'noo_send_contact_resume' );
			    if ( $result ) {
				    $response['status'] = 'success';
				    $response['message'] = esc_html__( 'Send contact success', 'jmcore' );
				    wp_send_json( $response );
			    }
			    $response['status'] = 'error';
			    $response['message'] = esc_html__( 'Send contact error', 'jmcore' );
			    wp_send_json( $response );
		    } else {
			    $response['status'] = 'error';
			    $response['message'] = esc_html__( 'Candidate not exits', 'jmcore' );
	        }
	    } else {
		    $response['status'] = 'error';
		    $response['message'] = esc_html__( 'Do not support this action', 'jmcore' );
	    }

	    wp_send_json( $response );

    }

    add_action( 'wp_ajax_resume_contact', 'noo_resume_contact' );
    add_action( 'wp_ajax_nopriv_resume_contact', 'noo_resume_contact' );

endif;
if(!function_exists('noo_resume_list_customRSS')):
    function noo_resume_list_customRSS(){
        noo_get_layout('resume/resume_feed');
    }
endif;

add_action('init','resume_customRSS');
function resume_customRSS(){
    add_feed('resume_feed','noo_resume_list_customRSS');
}

if(!function_exists('noo_get_general_info_resume_detail')):
    function noo_get_general_info_resume_detail($resume_id,$class_item,$args_display)
    {
        if (empty($resume_id)) {
            return;
        }
        $user_per = noo_get_user_permission();
        $fields = jm_get_resume_custom_fields();
        $field_skipped = 0;
        if (Noo_Member::get_user_role(get_current_user_id()) == 'employer') {
            $package = jm_get_job_posting_info();
            $package_id = (!empty($package)&&(isset($package['product_id']))) ? $package['product_id'] : '';
            $package_resume_cfs = !empty($package_id) ? jm_get_job_package_resume_cf($package_id) : array();
            $resume_cfs_add_to_package = jm_get_resume_custom_fields_option('job_package_resume_fields', array());
            $remove_fields = array_diff($resume_cfs_add_to_package, $package_resume_cfs);
            foreach ($fields as $index => $field) {
                if (in_array($field['name'], $remove_fields)) {
                    unset($fields[$index]);
                    $field_skipped++;
                }
            }
        }
        $settings_fields = get_theme_mod('noo_resumes_detail_fields', '');
        $settings_fields = !is_array($settings_fields) ? explode(',', $settings_fields) : $settings_fields;


        if ($fields) : foreach ($fields as $field) :

            if ($field['name'] == 'cover_image') // reserve the _closing field
                continue;
            if ($field['name'] == 'portfolio') // reserve the _closing field
                continue;
            if ($field['type'] == 'embed_video') // reserve the _closing field
                continue;
            if ($field['type'] == 'image_gallery') // reserve the _closing field
                continue;
            if ($field['type'] == 'single_image') // reserve the _closing field
                continue;

            if (in_array($field['name'], $settings_fields)) {

                $field_id = jm_resume_custom_fields_name($field['name'], $field);

                $label = isset($field['label_translated']) ? $field['label_translated'] : $field['label'];
                $value = jm_get_resume_field_value($resume_id, $field);

                $icon = isset($field['icon']) ? $field['icon'] : '';
                $icon_class = str_replace("|", " ", $icon);

                $permission = isset($field['permission']) ? $field['permission'] : '';
                $is_can_view = false;

                if ($user_per == 'true') {
                    $is_can_view = true;
                } else {
                    if (empty($permission) or 'public' == $permission) {
                        $is_can_view = true;
                    } elseif ($permission == $user_per) {
                        $is_can_view = true;
                    }
                }
                if ($is_can_view == false) {
                    $field_skipped++;
                    $value = '***********';
                }
                if (empty($value) || $field['name'] == 'portfolio') continue;

                if (($field['type'] == 'single_tax_location') || ($field['type'] == 'single_tax_location_input')) {
                    $field['type'] = 'select';
                }
                ?>
                <li class="<?php echo esc_attr($field_id).' '.$class_item; ?>">
                    <?php noo_display_field($field, $field_id, $value, $args_display); ?>
                </li>

            <?php } ?>

        <?php endforeach;
            if ($field_skipped >= 1):?>

                <?php
                $package_page_id = Noo_Job_Package::get_setting('package_page_id');
                $link = get_permalink($package_page_id);
                $link = '<a href="' . esc_url($link) . '" class="upgrade">' . esc_html__('Upgrade', 'jmcore') . '</a>';
                ?>
                <?php if (Noo_Member::get_user_role(get_current_user_id()) == 'administrator' || Noo_Member::is_employer(get_current_user_id())) { ?>
                    <div class="noo-message noo-message-error pt10">
                        <?php echo sprintf(esc_html__('Please %s the package to view more fields.', 'jmcore'), $link) ?>
                    </div>
                <?php } else { ?>
                    <div class="noo-message noo-message-error pt10">
                        <?php echo esc_html__('Please login with Employer account to view more fields.', 'jmcore') ?>
                    </div>
                <?php } ?>

            <?php endif;
        endif;
    }
endif;
add_action( 'jm_general_information_resume_detail', 'noo_get_general_info_resume_detail', 10 ,3);

if(!function_exists('jm_about_candidate_resume_detail')):
    function jm_about_candidate_resume_detail($candidate,$class_item,$args_display)
    {
        if(empty($candidate)){
            return;
        }
        $fields_candidate = jm_get_candidate_custom_fields();
        $email = $candidate ? $candidate->user_email : '';
        $user_per = noo_get_user_permission();
        if (!empty($fields_candidate)) {
            foreach ($fields_candidate as $field) {

                if (isset($field['is_default'])) {
                    if (in_array($field['name'], array('first_name', 'last_name', 'full_name')))
                        continue; // don't display WordPress default user fields
                }
                $field_id = jm_candidate_custom_fields_name($field['name'], $field);
                $value = get_user_meta($candidate->ID, $field_id, true);
                $value = noo_convert_custom_field_value($field, $value);
                if ($field['name'] == 'email') {
                    $value = $email;
                }
                if (is_array($value)) {
                    $value = implode(', ', $value);
                }
                $permission = isset($field['permission']) ? $field['permission'] : '';
                $is_can_view = false;
                if ($user_per == 'true') {
                    $is_can_view = true;
                } else {
                    if (empty($permission) or 'public' == $permission) {
                        $is_can_view = true;
                    } elseif ($permission == $user_per) {
                        $is_can_view = true;
                    }
                }
                if ($is_can_view == false) {
                    $value = '********';
                }
                if (!empty($value)) : ?>
                    <li class="<?php echo esc_attr($field_id).' '.$class_item; ?>">
                        <?php noo_display_field($field, $field_id, $value, $args_display); ?>
                    </li>
                <?php endif;

            }
        }
    }
endif;
add_action( 'jm_about_candidate_resume_detail', 'jm_about_candidate_resume_detail', 10 ,3);

